/*
 * This was automagically generated from arch/arm/tools/mach-types!
 * Do NOT edit
 */

#ifndef __ASM_ARM_MACH_TYPE_H
#define __ASM_ARM_MACH_TYPE_H

/* see arch/arm/kernel/arch.c for a description of these */
#define MACH_TYPE_EBSA110              0
#define MACH_TYPE_RISCPC               1
#define MACH_TYPE_NEXUSPCI             3
#define MACH_TYPE_EBSA285              4
#define MACH_TYPE_NETWINDER            5
#define MACH_TYPE_CATS                 6
#define MACH_TYPE_TBOX                 7
#define MACH_TYPE_CO285                8
#define MACH_TYPE_CLPS7110             9
#define MACH_TYPE_ARCHIMEDES           10
#define MACH_TYPE_A5K                  11
#define MACH_TYPE_ETOILE               12
#define MACH_TYPE_LACIE_NAS            13
#define MACH_TYPE_CLPS7500             14
#define MACH_TYPE_SHARK                15
#define MACH_TYPE_BRUTUS               16
#define MACH_TYPE_PERSONAL_SERVER      17
#define MACH_TYPE_ITSY                 18
#define MACH_TYPE_L7200                19
#define MACH_TYPE_PLEB                 20
#define MACH_TYPE_INTEGRATOR           21
#define MACH_TYPE_H3600                22
#define MACH_TYPE_IXP1200              23
#define MACH_TYPE_P720T                24
#define MACH_TYPE_ASSABET              25
#define MACH_TYPE_VICTOR               26
#define MACH_TYPE_LART                 27
#define MACH_TYPE_RANGER               28
#define MACH_TYPE_GRAPHICSCLIENT       29
#define MACH_TYPE_XP860                30
#define MACH_TYPE_CERF                 31
#define MACH_TYPE_NANOENGINE           32
#define MACH_TYPE_FPIC                 33
#define MACH_TYPE_EXTENEX1             34
#define MACH_TYPE_SHERMAN              35
#define MACH_TYPE_ACCELENT_SA          36
#define MACH_TYPE_ACCELENT_L7200       37
#define MACH_TYPE_NETPORT              38
#define MACH_TYPE_PANGOLIN             39
#define MACH_TYPE_YOPY                 40
#define MACH_TYPE_COOLIDGE             41
#define MACH_TYPE_HUW_WEBPANEL         42
#define MACH_TYPE_SPOTME               43
#define MACH_TYPE_FREEBIRD             44
#define MACH_TYPE_TI925                45
#define MACH_TYPE_RISCSTATION          46
#define MACH_TYPE_CAVY                 47
#define MACH_TYPE_JORNADA720           48
#define MACH_TYPE_OMNIMETER            49
#define MACH_TYPE_EDB7211              50
#define MACH_TYPE_CITYGO               51
#define MACH_TYPE_PFS168               52
#define MACH_TYPE_SPOT                 53
#define MACH_TYPE_FLEXANET             54
#define MACH_TYPE_WEBPAL               55
#define MACH_TYPE_LINPDA               56
#define MACH_TYPE_ANAKIN               57
#define MACH_TYPE_MVI                  58
#define MACH_TYPE_JUPITER              59
#define MACH_TYPE_PSIONW               60
#define MACH_TYPE_ALN                  61
#define MACH_TYPE_CAMELOT              62
#define MACH_TYPE_GDS2200              63
#define MACH_TYPE_PSION_SERIES7        64
#define MACH_TYPE_XFILE                65
#define MACH_TYPE_ACCELENT_EP9312      66
#define MACH_TYPE_IC200                67
#define MACH_TYPE_CREDITLART           68
#define MACH_TYPE_HTM                  69
#define MACH_TYPE_IQ80310              70
#define MACH_TYPE_FREEBOT              71
#define MACH_TYPE_ENTEL                72
#define MACH_TYPE_ENP3510              73
#define MACH_TYPE_TRIZEPS              74
#define MACH_TYPE_NESA                 75
#define MACH_TYPE_VENUS                76
#define MACH_TYPE_TARDIS               77
#define MACH_TYPE_MERCURY              78
#define MACH_TYPE_EMPEG                79
#define MACH_TYPE_I80200FCC            80
#define MACH_TYPE_ITT_CPB              81
#define MACH_TYPE_SVC                  82
#define MACH_TYPE_ALPHA2               84
#define MACH_TYPE_ALPHA1               85
#define MACH_TYPE_NETARM               86
#define MACH_TYPE_SIMPAD               87
#define MACH_TYPE_PDA1                 88
#define MACH_TYPE_LUBBOCK              89
#define MACH_TYPE_ANIKO                90
#define MACH_TYPE_CLEP7212             91
#define MACH_TYPE_CS89712              92
#define MACH_TYPE_WEARARM              93
#define MACH_TYPE_POSSIO_PX            94
#define MACH_TYPE_SIDEARM              95
#define MACH_TYPE_STORK                96
#define MACH_TYPE_SHANNON              97
#define MACH_TYPE_ACE                  98
#define MACH_TYPE_BALLYARM             99
#define MACH_TYPE_SIMPUTER             100
#define MACH_TYPE_NEXTERM              101
#define MACH_TYPE_SA1100_ELF           102
#define MACH_TYPE_GATOR                103
#define MACH_TYPE_GRANITE              104
#define MACH_TYPE_CONSUS               105
#define MACH_TYPE_AAED2000             106
#define MACH_TYPE_CDB89712             107
#define MACH_TYPE_GRAPHICSMASTER       108
#define MACH_TYPE_ADSBITSY             109
#define MACH_TYPE_PXA_IDP              110
#define MACH_TYPE_PLCE                 111
#define MACH_TYPE_PT_SYSTEM3           112
#define MACH_TYPE_MEDALB               113
#define MACH_TYPE_EAGLE                114
#define MACH_TYPE_DSC21                115
#define MACH_TYPE_DSC24                116
#define MACH_TYPE_TI5472               117
#define MACH_TYPE_AUTCPU12             118
#define MACH_TYPE_UENGINE              119
#define MACH_TYPE_BLUESTEM             120
#define MACH_TYPE_XINGU8               121
#define MACH_TYPE_BUSHSTB              122
#define MACH_TYPE_EPSILON1             123
#define MACH_TYPE_BALLOON              124
#define MACH_TYPE_PUPPY                125
#define MACH_TYPE_ELROY                126
#define MACH_TYPE_GMS720               127
#define MACH_TYPE_S24X                 128
#define MACH_TYPE_JTEL_CLEP7312        129
#define MACH_TYPE_CX821XX              130
#define MACH_TYPE_EDB7312              131
#define MACH_TYPE_BSA1110              132
#define MACH_TYPE_POWERPIN             133
#define MACH_TYPE_OPENARM              134
#define MACH_TYPE_WHITECHAPEL          135
#define MACH_TYPE_H3100                136
#define MACH_TYPE_H3800                137
#define MACH_TYPE_BLUE_V1              138
#define MACH_TYPE_PXA_CERF             139
#define MACH_TYPE_ARM7TEVB             140
#define MACH_TYPE_D7400                141
#define MACH_TYPE_PIRANHA              142
#define MACH_TYPE_SBCAMELOT            143
#define MACH_TYPE_KINGS                144
#define MACH_TYPE_SMDK2400             145
#define MACH_TYPE_COLLIE               146
#define MACH_TYPE_IDR                  147
#define MACH_TYPE_BADGE4               148
#define MACH_TYPE_WEBNET               149
#define MACH_TYPE_D7300                150
#define MACH_TYPE_CEP                  151
#define MACH_TYPE_FORTUNET             152
#define MACH_TYPE_VC547X               153
#define MACH_TYPE_FILEWALKER           154
#define MACH_TYPE_NETGATEWAY           155
#define MACH_TYPE_SYMBOL2800           156
#define MACH_TYPE_SUNS                 157
#define MACH_TYPE_FRODO                158
#define MACH_TYPE_MACH_TYTE_MS301      159
#define MACH_TYPE_MX1ADS               160
#define MACH_TYPE_H7201                161
#define MACH_TYPE_H7202                162
#define MACH_TYPE_AMICO                163
#define MACH_TYPE_IAM                  164
#define MACH_TYPE_TT530                165
#define MACH_TYPE_SAM2400              166
#define MACH_TYPE_JORNADA56X           167
#define MACH_TYPE_ACTIVE               168
#define MACH_TYPE_IQ80321              169
#define MACH_TYPE_WID                  170
#define MACH_TYPE_SABINAL              171
#define MACH_TYPE_IXP425_MATACUMBE     172
#define MACH_TYPE_MINIPRINT            173
#define MACH_TYPE_ADM510X              174
#define MACH_TYPE_SVS200               175
#define MACH_TYPE_ATG_TCU              176
#define MACH_TYPE_JORNADA820           177
#define MACH_TYPE_S3C44B0              178
#define MACH_TYPE_MARGIS2              179
#define MACH_TYPE_KS8695               180
#define MACH_TYPE_BRH                  181
#define MACH_TYPE_S3C2410              182
#define MACH_TYPE_POSSIO_PX30          183
#define MACH_TYPE_S3C2800              184
#define MACH_TYPE_FLEETWOOD            185
#define MACH_TYPE_OMAHA                186
#define MACH_TYPE_TA7                  187
#define MACH_TYPE_NOVA                 188
#define MACH_TYPE_HMK                  189
#define MACH_TYPE_KARO                 190
#define MACH_TYPE_FESTER               191
#define MACH_TYPE_GPI                  192
#define MACH_TYPE_SMDK2410             193
#define MACH_TYPE_I519                 194
#define MACH_TYPE_NEXIO                195
#define MACH_TYPE_BITBOX               196
#define MACH_TYPE_G200                 197
#define MACH_TYPE_GILL                 198
#define MACH_TYPE_PXA_MERCURY          199
#define MACH_TYPE_CEIVA                200
#define MACH_TYPE_FRET                 201
#define MACH_TYPE_EMAILPHONE           202
#define MACH_TYPE_H3900                203
#define MACH_TYPE_PXA1                 204
#define MACH_TYPE_KOAN369              205
#define MACH_TYPE_COGENT               206
#define MACH_TYPE_ESL_SIMPUTER         207
#define MACH_TYPE_ESL_SIMPUTER_CLR     208
#define MACH_TYPE_ESL_SIMPUTER_BW      209
#define MACH_TYPE_HHP_CRADLE           210
#define MACH_TYPE_HE500                211
#define MACH_TYPE_INHANDELF2           212
#define MACH_TYPE_INHANDFTIP           213
#define MACH_TYPE_DNP1110              214
#define MACH_TYPE_PNP1110              215
#define MACH_TYPE_CSB226               216
#define MACH_TYPE_ARNOLD               217
#define MACH_TYPE_VOICEBLUE            218
#define MACH_TYPE_JZ8028               219
#define MACH_TYPE_H5400                220
#define MACH_TYPE_FORTE                221
#define MACH_TYPE_ACAM                 222
#define MACH_TYPE_ABOX                 223
#define MACH_TYPE_ATMEL                224
#define MACH_TYPE_SITSANG              225
#define MACH_TYPE_CPU1110LCDNET        226
#define MACH_TYPE_MPL_VCMA9            227
#define MACH_TYPE_OPUS_A1              228
#define MACH_TYPE_DAYTONA              229
#define MACH_TYPE_KILLBEAR             230
#define MACH_TYPE_YOHO                 231
#define MACH_TYPE_JASPER               232
#define MACH_TYPE_DSC25                233
#define MACH_TYPE_OMAP_INNOVATOR       234
#define MACH_TYPE_RAMSES               235
#define MACH_TYPE_S28X                 236
#define MACH_TYPE_MPORT3               237
#define MACH_TYPE_PXA_EAGLE250         238
#define MACH_TYPE_PDB                  239
#define MACH_TYPE_BLUE_2G              240
#define MACH_TYPE_BLUEARCH             241
#define MACH_TYPE_IXDP2400             242
#define MACH_TYPE_IXDP2800             243
#define MACH_TYPE_EXPLORER             244
#define MACH_TYPE_IXDP425              245
#define MACH_TYPE_CHIMP                246
#define MACH_TYPE_STORK_NEST           247
#define MACH_TYPE_STORK_EGG            248
#define MACH_TYPE_WISMO                249
#define MACH_TYPE_EZLINX               250
#define MACH_TYPE_AT91RM9200           251
#define MACH_TYPE_ADTECH_ORION         252
#define MACH_TYPE_NEPTUNE              253
#define MACH_TYPE_HACKKIT              254
#define MACH_TYPE_PXA_WINS30           255
#define MACH_TYPE_LAVINNA              256
#define MACH_TYPE_PXA_UENGINE          257
#define MACH_TYPE_INNOKOM              258
#define MACH_TYPE_BMS                  259
#define MACH_TYPE_IXCDP1100            260
#define MACH_TYPE_PRPMC1100            261
#define MACH_TYPE_AT91RM9200DK         262
#define MACH_TYPE_ARMSTICK             263
#define MACH_TYPE_ARMONIE              264
#define MACH_TYPE_MPORT1               265
#define MACH_TYPE_S3C5410              266
#define MACH_TYPE_ZCP320A              267
#define MACH_TYPE_I_BOX                268
#define MACH_TYPE_STLC1502             269
#define MACH_TYPE_SIREN                270
#define MACH_TYPE_GREENLAKE            271
#define MACH_TYPE_ARGUS                272
#define MACH_TYPE_COMBADGE             273
#define MACH_TYPE_ROKEPXA              274
#define MACH_TYPE_CINTEGRATOR          275
#define MACH_TYPE_GUIDEA07             276
#define MACH_TYPE_TAT257               277
#define MACH_TYPE_IGP2425              278
#define MACH_TYPE_BLUEGRAMMA           279
#define MACH_TYPE_IPOD                 280
#define MACH_TYPE_ADSBITSYX            281
#define MACH_TYPE_TRIZEPS2             282
#define MACH_TYPE_VIPER                283
#define MACH_TYPE_ADSBITSYPLUS         284
#define MACH_TYPE_ADSAGC               285
#define MACH_TYPE_STP7312              286
#define MACH_TYPE_NX_PHNX              287
#define MACH_TYPE_WEP_EP250            288
#define MACH_TYPE_INHANDELF3           289
#define MACH_TYPE_ADI_COYOTE           290
#define MACH_TYPE_IYONIX               291
#define MACH_TYPE_DAMICAM_SA1110       292
#define MACH_TYPE_MEG03                293
#define MACH_TYPE_PXA_WHITECHAPEL      294
#define MACH_TYPE_NWSC                 295
#define MACH_TYPE_NWLARM               296
#define MACH_TYPE_IXP425_MGUARD        297
#define MACH_TYPE_PXA_NETDCU4          298
#define MACH_TYPE_IXDP2401             299
#define MACH_TYPE_IXDP2801             300
#define MACH_TYPE_ZODIAC               301
#define MACH_TYPE_ARMMODUL             302
#define MACH_TYPE_KETOP                303
#define MACH_TYPE_AV7200               304
#define MACH_TYPE_ARCH_TI925           305
#define MACH_TYPE_ACQ200               306
#define MACH_TYPE_PT_DAFIT             307
#define MACH_TYPE_IHBA                 308
#define MACH_TYPE_QUINQUE              309
#define MACH_TYPE_NIMBRAONE            310
#define MACH_TYPE_NIMBRA29X            311
#define MACH_TYPE_NIMBRA210            312
#define MACH_TYPE_HHP_D95XX            313
#define MACH_TYPE_LABARM               314
#define MACH_TYPE_M825XX               315
#define MACH_TYPE_M7100                316
#define MACH_TYPE_NIPC2                317
#define MACH_TYPE_FU7202               318
#define MACH_TYPE_ADSAGX               319
#define MACH_TYPE_PXA_POOH             320
#define MACH_TYPE_BANDON               321
#define MACH_TYPE_PCM7210              322
#define MACH_TYPE_NMS9200              323
#define MACH_TYPE_LOGODL               324
#define MACH_TYPE_M7140                325
#define MACH_TYPE_KOREBOT              326
#define MACH_TYPE_IQ31244              327
#define MACH_TYPE_KOAN393              328
#define MACH_TYPE_INHANDFTIP3          329
#define MACH_TYPE_GONZO                330
#define MACH_TYPE_BAST                 331
#define MACH_TYPE_SCANPASS             332
#define MACH_TYPE_EP7312_POOH          333
#define MACH_TYPE_TA7S                 334
#define MACH_TYPE_TA7V                 335
#define MACH_TYPE_ICARUS               336
#define MACH_TYPE_H1900                337
#define MACH_TYPE_GEMINI               338
#define MACH_TYPE_AXIM                 339
#define MACH_TYPE_AUDIOTRON            340
#define MACH_TYPE_H2200                341
#define MACH_TYPE_LOOX600              342
#define MACH_TYPE_NIOP                 343
#define MACH_TYPE_DM310                344
#define MACH_TYPE_SEEDPXA_C2           345
#define MACH_TYPE_IXP4XX_MGUARD_PCI    346
#define MACH_TYPE_H1940                347
#define MACH_TYPE_SCORPIO              348
#define MACH_TYPE_VIVA                 349
#define MACH_TYPE_PXA_XCARD            350
#define MACH_TYPE_CSB335               351
#define MACH_TYPE_IXRD425              352
#define MACH_TYPE_IQ80315              353
#define MACH_TYPE_NMP7312              354
#define MACH_TYPE_CX861XX              355
#define MACH_TYPE_ENP2611              356
#define MACH_TYPE_XDA                  357
#define MACH_TYPE_CSIR_IMS             358
#define MACH_TYPE_IXP421_DNAEETH       359
#define MACH_TYPE_POCKETSERV9200       360
#define MACH_TYPE_TOTO                 361
#define MACH_TYPE_S3C2440              362
#define MACH_TYPE_KS8695P              363
#define MACH_TYPE_SE4000               364
#define MACH_TYPE_QUADRICEPS           365
#define MACH_TYPE_BRONCO               366
#define MACH_TYPE_ESL_WIRELESS_TAB     367
#define MACH_TYPE_ESL_SOFCOMP          368
#define MACH_TYPE_S5C7375              369
#define MACH_TYPE_SPEARHEAD            370
#define MACH_TYPE_PANTERA              371
#define MACH_TYPE_PRAYOGLITE           372
#define MACH_TYPE_GUMSTIX              373
#define MACH_TYPE_RCUBE                374
#define MACH_TYPE_REA_OLV              375
#define MACH_TYPE_PXA_IPHONE           376
#define MACH_TYPE_S3C3410              377
#define MACH_TYPE_ESPD_4510B           378
#define MACH_TYPE_MP1X                 379
#define MACH_TYPE_AT91RM9200TB         380
#define MACH_TYPE_ADSVGX               381
#define MACH_TYPE_OMAP_H2              382
#define MACH_TYPE_PELEE                383
#define MACH_TYPE_E740                 384
#define MACH_TYPE_IQ80331              385
#define MACH_TYPE_VERSATILE_PB         387
#define MACH_TYPE_KEV7A400             388
#define MACH_TYPE_LPD7A400             389
#define MACH_TYPE_LPD7A404             390
#define MACH_TYPE_FUJITSU_CAMELOT      391
#define MACH_TYPE_JANUS2M              392
#define MACH_TYPE_EMBTF                393
#define MACH_TYPE_HPM                  394
#define MACH_TYPE_SMDK2410TK           395
#define MACH_TYPE_SMDK2410AJ           396
#define MACH_TYPE_STREETRACER          397
#define MACH_TYPE_EFRAME               398
#define MACH_TYPE_CSB337               399
#define MACH_TYPE_PXA_LARK             400
#define MACH_TYPE_PNP2110              401
#define MACH_TYPE_TCC72X               402
#define MACH_TYPE_ALTAIR               403
#define MACH_TYPE_KC3                  404
#define MACH_TYPE_SINTEFTD             405
#define MACH_TYPE_MAINSTONE            406
#define MACH_TYPE_ADAY4X               407
#define MACH_TYPE_LITE300              408
#define MACH_TYPE_S5C7376              409
#define MACH_TYPE_MT02                 410
#define MACH_TYPE_MPORT3S              411
#define MACH_TYPE_RA_ALPHA             412
#define MACH_TYPE_XCEP                 413
#define MACH_TYPE_ARCOM_VULCAN         414
#define MACH_TYPE_STARGATE             415
#define MACH_TYPE_ARMADILLOJ           416
#define MACH_TYPE_ELROY_JACK           417
#define MACH_TYPE_BACKEND              418
#define MACH_TYPE_S5LINBOX             419
#define MACH_TYPE_NOMADIK              420
#define MACH_TYPE_IA_CPU_9200          421
#define MACH_TYPE_AT91_BJA1            422
#define MACH_TYPE_CORGI                423
#define MACH_TYPE_POODLE               424
#define MACH_TYPE_TEN                  425
#define MACH_TYPE_ROVERP5P             426
#define MACH_TYPE_SC2700               427
#define MACH_TYPE_EX_EAGLE             428
#define MACH_TYPE_NX_PXA12             429
#define MACH_TYPE_NX_PXA5              430
#define MACH_TYPE_BLACKBOARD2          431
#define MACH_TYPE_I819                 432
#define MACH_TYPE_IXMB995E             433
#define MACH_TYPE_SKYRIDER             434
#define MACH_TYPE_SKYHAWK              435
#define MACH_TYPE_ENTERPRISE           436
#define MACH_TYPE_DEP2410              437
#define MACH_TYPE_ARMCORE              438
#define MACH_TYPE_HOBBIT               439
#define MACH_TYPE_H7210                440
#define MACH_TYPE_PXA_NETDCU5          441
#define MACH_TYPE_ACC                  442
#define MACH_TYPE_ESL_SARVA            443
#define MACH_TYPE_XM250                444
#define MACH_TYPE_T6TC1XB              445
#define MACH_TYPE_ESS710               446
#define MACH_TYPE_MX31ADS              447
#define MACH_TYPE_HIMALAYA             448
#define MACH_TYPE_BOLFENK              449
#define MACH_TYPE_AT91RM9200KR         450
#define MACH_TYPE_EDB9312              451
#define MACH_TYPE_OMAP_GENERIC         452
#define MACH_TYPE_AXIMX3               453
#define MACH_TYPE_EB67XDIP             454
#define MACH_TYPE_WEBTXS               455
#define MACH_TYPE_HAWK                 456
#define MACH_TYPE_CCAT91SBC001         457
#define MACH_TYPE_EXPRESSO             458
#define MACH_TYPE_H4000                459
#define MACH_TYPE_DINO                 460
#define MACH_TYPE_ML675K               461
#define MACH_TYPE_EDB9301              462
#define MACH_TYPE_EDB9315              463
#define MACH_TYPE_RECIVA_TT            464
#define MACH_TYPE_CSTCB01              465
#define MACH_TYPE_CSTCB1               466
#define MACH_TYPE_SHADWELL             467
#define MACH_TYPE_GOEPEL263            468
#define MACH_TYPE_ACQ100               469
#define MACH_TYPE_MX1FS2               470
#define MACH_TYPE_HIPTOP_G1            471
#define MACH_TYPE_SPARKY               472
#define MACH_TYPE_NS9750               473
#define MACH_TYPE_PHOENIX              474
#define MACH_TYPE_VR1000               475
#define MACH_TYPE_DEISTERPXA           476
#define MACH_TYPE_BCM1160              477
#define MACH_TYPE_PCM022               478
#define MACH_TYPE_ADSGCX               479
#define MACH_TYPE_DREADNAUGHT          480
#define MACH_TYPE_DM320                481
#define MACH_TYPE_MARKOV               482
#define MACH_TYPE_COS7A400             483
#define MACH_TYPE_MILANO               484
#define MACH_TYPE_UE9328               485
#define MACH_TYPE_UEX255               486
#define MACH_TYPE_UE2410               487
#define MACH_TYPE_A620                 488
#define MACH_TYPE_OCELOT               489
#define MACH_TYPE_CHEETAH              490
#define MACH_TYPE_OMAP_PERSEUS2        491
#define MACH_TYPE_ZVUE                 492
#define MACH_TYPE_ROVERP1              493
#define MACH_TYPE_ASIDIAL2             494
#define MACH_TYPE_S3C24A0              495
#define MACH_TYPE_E800                 496
#define MACH_TYPE_E750                 497
#define MACH_TYPE_S3C5500              498
#define MACH_TYPE_SMDK5500             499
#define MACH_TYPE_SIGNALSYNC           500
#define MACH_TYPE_NBC                  501
#define MACH_TYPE_KODIAK               502
#define MACH_TYPE_NETBOOKPRO           503
#define MACH_TYPE_HW90200              504
#define MACH_TYPE_CONDOR               505
#define MACH_TYPE_CUP                  506
#define MACH_TYPE_KITE                 507
#define MACH_TYPE_SCB9328              508
#define MACH_TYPE_OMAP_H3              509
#define MACH_TYPE_OMAP_H4              510
#define MACH_TYPE_N10                  511
#define MACH_TYPE_MONTAJADE            512
#define MACH_TYPE_SG560                513
#define MACH_TYPE_DP1000               514
#define MACH_TYPE_OMAP_OSK             515
#define MACH_TYPE_RG100V3              516
#define MACH_TYPE_MX2ADS               517
#define MACH_TYPE_PXA_KILO             518
#define MACH_TYPE_IXP4XX_EAGLE         519
#define MACH_TYPE_TOSA                 520
#define MACH_TYPE_MB2520F              521
#define MACH_TYPE_EMC1000              522
#define MACH_TYPE_TIDSC25              523
#define MACH_TYPE_AKCPMXL              524
#define MACH_TYPE_AV3XX                525
#define MACH_TYPE_AVILA                526
#define MACH_TYPE_PXA_MPM10            527
#define MACH_TYPE_PXA_KYANITE          528
#define MACH_TYPE_SGOLD                529
#define MACH_TYPE_OSCAR                530
#define MACH_TYPE_EPXA4USB2            531
#define MACH_TYPE_XSENGINE             532
#define MACH_TYPE_IP600                533
#define MACH_TYPE_MCAN2                534
#define MACH_TYPE_DDI_BLUERIDGE        535
#define MACH_TYPE_SKYMINDER            536
#define MACH_TYPE_LPD79520             537
#define MACH_TYPE_EDB9302              538
#define MACH_TYPE_HW90340              539
#define MACH_TYPE_CIP_BOX              540
#define MACH_TYPE_IVPN                 541
#define MACH_TYPE_RSOC2                542
#define MACH_TYPE_HUSKY                543
#define MACH_TYPE_BOXER                544
#define MACH_TYPE_SHEPHERD             545
#define MACH_TYPE_AML42800AA           546
#define MACH_TYPE_LPC2294              548
#define MACH_TYPE_SWITCHGRASS          549
#define MACH_TYPE_ENS_CMU              550
#define MACH_TYPE_MM6_SDB              551
#define MACH_TYPE_SATURN               552
#define MACH_TYPE_I30030EVB            553
#define MACH_TYPE_MXC27530EVB          554
#define MACH_TYPE_SMDK2800             555
#define MACH_TYPE_MTWILSON             556
#define MACH_TYPE_ZITI                 557
#define MACH_TYPE_GRANDFATHER          558
#define MACH_TYPE_TENGINE              559
#define MACH_TYPE_S3C2460              560
#define MACH_TYPE_PDM                  561
#define MACH_TYPE_H4700                562
#define MACH_TYPE_H6300                563
#define MACH_TYPE_RZ1700               564
#define MACH_TYPE_A716                 565
#define MACH_TYPE_ESTK2440A            566
#define MACH_TYPE_ATWIXP425            567
#define MACH_TYPE_CSB336               568
#define MACH_TYPE_RIRM2                569
#define MACH_TYPE_CX23518              570
#define MACH_TYPE_CX2351X              571
#define MACH_TYPE_COMPUTIME            572
#define MACH_TYPE_IZARUS               573
#define MACH_TYPE_RTS                  574
#define MACH_TYPE_SE5100               575
#define MACH_TYPE_S3C2510              576
#define MACH_TYPE_CSB437TL             577
#define MACH_TYPE_SLAUSON              578
#define MACH_TYPE_PEARLRIVER           579
#define MACH_TYPE_TDC_P210             580
#define MACH_TYPE_SG580                581
#define MACH_TYPE_WRSBCARM7            582
#define MACH_TYPE_IPD                  583
#define MACH_TYPE_PXA_DNP2110          584
#define MACH_TYPE_XAENIAX              585
#define MACH_TYPE_SOMN4250             586
#define MACH_TYPE_PLEB2                587
#define MACH_TYPE_CORNWALLIS           588
#define MACH_TYPE_GURNEY_DRV           589
#define MACH_TYPE_CHAFFEE              590
#define MACH_TYPE_RMS101               591
#define MACH_TYPE_RX3715               592
#define MACH_TYPE_SWIFT                593
#define MACH_TYPE_ROVERP7              594
#define MACH_TYPE_PR818S               595
#define MACH_TYPE_TRXPRO               596
#define MACH_TYPE_NSLU2                597
#define MACH_TYPE_E400                 598
#define MACH_TYPE_TRAB                 599
#define MACH_TYPE_CMC_PU2              600
#define MACH_TYPE_FULCRUM              601
#define MACH_TYPE_NETGATE42X           602
#define MACH_TYPE_STR710               603
#define MACH_TYPE_IXDPG425             604
#define MACH_TYPE_TOMTOMGO             605
#define MACH_TYPE_VERSATILE_AB         606
#define MACH_TYPE_EDB9307              607
#define MACH_TYPE_SG565                608
#define MACH_TYPE_LPD79524             609
#define MACH_TYPE_LPD79525             610
#define MACH_TYPE_RMS100               611
#define MACH_TYPE_KB9200               612
#define MACH_TYPE_SX1                  613
#define MACH_TYPE_HMS39C7092           614
#define MACH_TYPE_ARMADILLO            615
#define MACH_TYPE_IPCU                 616
#define MACH_TYPE_LOOX720              617
#define MACH_TYPE_IXDP465              618
#define MACH_TYPE_IXDP2351             619
#define MACH_TYPE_ADSVIX               620
#define MACH_TYPE_DM270                621
#define MACH_TYPE_SOCLTPLUS            622
#define MACH_TYPE_ECIA                 623
#define MACH_TYPE_CM4008               624
#define MACH_TYPE_P2001                625
#define MACH_TYPE_MUDSHARK             627
#define MACH_TYPE_HB2                  628
#define MACH_TYPE_IQ80332              629
#define MACH_TYPE_SENDT                630
#define MACH_TYPE_MX2JAZZ              631
#define MACH_TYPE_MULTIIO              632
#define MACH_TYPE_HRDISPLAY            633
#define MACH_TYPE_MXC27530ADS          634
#define MACH_TYPE_TRIZEPS3             635
#define MACH_TYPE_ZEFEERDZA            636
#define MACH_TYPE_ZEFEERDZB            637
#define MACH_TYPE_ZEFEERDZG            638
#define MACH_TYPE_ZEFEERDZN            639
#define MACH_TYPE_ZEFEERDZQ            640
#define MACH_TYPE_GTWX5715             641
#define MACH_TYPE_ASTRO_JACK           643
#define MACH_TYPE_TIP03                644
#define MACH_TYPE_A9200EC              645
#define MACH_TYPE_PNX0105              646
#define MACH_TYPE_ADCPOECPU            647
#define MACH_TYPE_CSB637               648
#define MACH_TYPE_MB9200               650
#define MACH_TYPE_KULUN                651
#define MACH_TYPE_SNAPPER              652
#define MACH_TYPE_OPTIMA               653
#define MACH_TYPE_DLHSBC               654
#define MACH_TYPE_X30                  655
#define MACH_TYPE_N30                  656
#define MACH_TYPE_MANGA_KS8695         657
#define MACH_TYPE_AJAX                 658
#define MACH_TYPE_NEC_MP900            659
#define MACH_TYPE_VVTK1000             661
#define MACH_TYPE_KAFA                 662
#define MACH_TYPE_VVTK3000             663
#define MACH_TYPE_PIMX1                664
#define MACH_TYPE_OLLIE                665
#define MACH_TYPE_SKYMAX               666
#define MACH_TYPE_JAZZ                 667
#define MACH_TYPE_TEL_T3               668
#define MACH_TYPE_AISINO_FCR255        669
#define MACH_TYPE_BTWEB                670
#define MACH_TYPE_DBG_LH79520          671
#define MACH_TYPE_CM41XX               672
#define MACH_TYPE_TS72XX               673
#define MACH_TYPE_NGGPXA               674
#define MACH_TYPE_CSB535               675
#define MACH_TYPE_CSB536               676
#define MACH_TYPE_PXA_TRAKPOD          677
#define MACH_TYPE_PRAXIS               678
#define MACH_TYPE_LH75411              679
#define MACH_TYPE_OTOM                 680
#define MACH_TYPE_NEXCODER_2440        681
#define MACH_TYPE_LOOX410              682
#define MACH_TYPE_WESTLAKE             683
#define MACH_TYPE_NSB                  684
#define MACH_TYPE_ESL_SARVA_STN        685
#define MACH_TYPE_ESL_SARVA_TFT        686
#define MACH_TYPE_ESL_SARVA_IAD        687
#define MACH_TYPE_ESL_SARVA_ACC        688
#define MACH_TYPE_TYPHOON              689
#define MACH_TYPE_CNAV                 690
#define MACH_TYPE_A730                 691
#define MACH_TYPE_NETSTAR              692
#define MACH_TYPE_PHASEFALE_SUPERCON   693
#define MACH_TYPE_SHIVA1100            694
#define MACH_TYPE_ETEXSC               695
#define MACH_TYPE_IXDPG465             696
#define MACH_TYPE_A9M2410              697
#define MACH_TYPE_A9M2440              698
#define MACH_TYPE_A9M9750              699
#define MACH_TYPE_A9M9360              700
#define MACH_TYPE_UNC90                701
#define MACH_TYPE_ECO920               702
#define MACH_TYPE_SATVIEW              703
#define MACH_TYPE_ROADRUNNER           704
#define MACH_TYPE_AT91RM9200EK         705
#define MACH_TYPE_GP32                 706
#define MACH_TYPE_GEM                  707
#define MACH_TYPE_I858                 708
#define MACH_TYPE_HX2750               709
#define MACH_TYPE_MXC91131EVB          710
#define MACH_TYPE_P700                 711
#define MACH_TYPE_CPE                  712
#define MACH_TYPE_SPITZ                713
#define MACH_TYPE_NIMBRA340            714
#define MACH_TYPE_LPC22XX              715
#define MACH_TYPE_COMET3               716
#define MACH_TYPE_COMET4               717
#define MACH_TYPE_CSB625               718
#define MACH_TYPE_FORTUNET2            719
#define MACH_TYPE_S5H2200              720
#define MACH_TYPE_OPTORM920            721
#define MACH_TYPE_ADSBITSYXB           722
#define MACH_TYPE_ADSSPHERE            723
#define MACH_TYPE_ADSPORTAL            724
#define MACH_TYPE_LN2410SBC            725
#define MACH_TYPE_CB3RUFC              726
#define MACH_TYPE_MP2USB               727
#define MACH_TYPE_NTNP425C             728
#define MACH_TYPE_COLIBRI              729
#define MACH_TYPE_PCM7220              730
#define MACH_TYPE_GATEWAY7001          731
#define MACH_TYPE_PCM027               732
#define MACH_TYPE_CMPXA                733
#define MACH_TYPE_ANUBIS               734
#define MACH_TYPE_ITE8152              735
#define MACH_TYPE_LPC3XXX              736
#define MACH_TYPE_PUPPETEER            737
#define MACH_TYPE_E570                 739
#define MACH_TYPE_X50                  740
#define MACH_TYPE_RECON                741
#define MACH_TYPE_XBOARDGP8            742
#define MACH_TYPE_FPIC2                743
#define MACH_TYPE_AKITA                744
#define MACH_TYPE_A81                  745
#define MACH_TYPE_SVM_SC25X            746
#define MACH_TYPE_VADATECH020          747
#define MACH_TYPE_TLI                  748
#define MACH_TYPE_EDB9315LC            749
#define MACH_TYPE_PASSEC               750
#define MACH_TYPE_DS_TIGER             751
#define MACH_TYPE_E310                 752
#define MACH_TYPE_E330                 753
#define MACH_TYPE_RT3000               754
#define MACH_TYPE_NOKIA770             755
#define MACH_TYPE_PNX0106              756
#define MACH_TYPE_HX21XX               757
#define MACH_TYPE_FARADAY              758
#define MACH_TYPE_SBC9312              759
#define MACH_TYPE_BATMAN               760
#define MACH_TYPE_JPD201               761
#define MACH_TYPE_MIPSA                762
#define MACH_TYPE_KACOM                763
#define MACH_TYPE_SWARCOCPU            764
#define MACH_TYPE_SWARCODSL            765
#define MACH_TYPE_BLUEANGEL            766
#define MACH_TYPE_HAIRYGRAMA           767
#define MACH_TYPE_BANFF                768
#define MACH_TYPE_CARMEVA              769
#define MACH_TYPE_SAM255               770
#define MACH_TYPE_PPM10                771
#define MACH_TYPE_EDB9315A             772
#define MACH_TYPE_SUNSET               773
#define MACH_TYPE_STARGATE2            774
#define MACH_TYPE_INTELMOTE2           775
#define MACH_TYPE_TRIZEPS4             776
#define MACH_TYPE_MAINSTONE2           777
#define MACH_TYPE_EZ_IXP42X            778
#define MACH_TYPE_TAPWAVE_ZODIAC       779
#define MACH_TYPE_UNIVERSALMETER       780
#define MACH_TYPE_HICOARM9             781
#define MACH_TYPE_PNX4008              782
#define MACH_TYPE_KWS6000              783
#define MACH_TYPE_PORTUX920T           784
#define MACH_TYPE_EZ_X5                785
#define MACH_TYPE_OMAP_RUDOLPH         786
#define MACH_TYPE_CPUAT91              787
#define MACH_TYPE_REA9200              788
#define MACH_TYPE_ACTS_PUNE_SA1110     789
#define MACH_TYPE_IXP425               790
#define MACH_TYPE_I30030ADS            791
#define MACH_TYPE_PERCH                792
#define MACH_TYPE_EIS05R1              793
#define MACH_TYPE_PEPPERPAD            794
#define MACH_TYPE_SB3010               795
#define MACH_TYPE_RM9200               796
#define MACH_TYPE_DMA03                797
#define MACH_TYPE_ROAD_S101            798
#define MACH_TYPE_IQ81340SC            799
#define MACH_TYPE_IQ_NEXTGEN_B         800
#define MACH_TYPE_IQ81340MC            801
#define MACH_TYPE_IQ_NEXTGEN_D         802
#define MACH_TYPE_IQ_NEXTGEN_E         803
#define MACH_TYPE_MALLOW_AT91          804
#define MACH_TYPE_CYBERTRACKER_I       805
#define MACH_TYPE_GESBC931X            806
#define MACH_TYPE_CENTIPAD             807
#define MACH_TYPE_ARMSOC               808
#define MACH_TYPE_SE4200               809
#define MACH_TYPE_EMS197A              810
#define MACH_TYPE_MICRO9               811
#define MACH_TYPE_MICRO9L              812
#define MACH_TYPE_UC5471DSP            813
#define MACH_TYPE_SJ5471ENG            814
#define MACH_TYPE_CMPXA26X             815
#define MACH_TYPE_NC                   816
#define MACH_TYPE_OMAP_PALMTE          817
#define MACH_TYPE_AJAX52X              818
#define MACH_TYPE_SIRIUSTAR            819
#define MACH_TYPE_IODATA_HDLG          820
#define MACH_TYPE_AT91RM9200UTL        821
#define MACH_TYPE_BIOSAFE              822
#define MACH_TYPE_MP1000               823
#define MACH_TYPE_PARSY                824
#define MACH_TYPE_CCXP                 825
#define MACH_TYPE_OMAP_GSAMPLE         826
#define MACH_TYPE_REALVIEW_EB          827
#define MACH_TYPE_SAMOA                828
#define MACH_TYPE_PALMT3               829
#define MACH_TYPE_I878                 830
#define MACH_TYPE_BORZOI               831
#define MACH_TYPE_GECKO                832
#define MACH_TYPE_DS101                833
#define MACH_TYPE_OMAP_PALMTT2         834
#define MACH_TYPE_PALMLD               835
#define MACH_TYPE_CC9C                 836
#define MACH_TYPE_SBC1670              837
#define MACH_TYPE_IXDP28X5             838
#define MACH_TYPE_OMAP_PALMTT          839
#define MACH_TYPE_ML696K               840
#define MACH_TYPE_ARCOM_ZEUS           841
#define MACH_TYPE_OSIRIS               842
#define MACH_TYPE_MAESTRO              843
#define MACH_TYPE_PALMTE2              844
#define MACH_TYPE_IXBBM                845
#define MACH_TYPE_MX27ADS              846
#define MACH_TYPE_AX8004               847
#define MACH_TYPE_AT91SAM9261EK        848
#define MACH_TYPE_LOFT                 849
#define MACH_TYPE_MAGPIE               850
#define MACH_TYPE_MX21ADS              851
#define MACH_TYPE_MB87M3400            852
#define MACH_TYPE_MGUARD_DELTA         853
#define MACH_TYPE_DAVINCI_DVDP         854
#define MACH_TYPE_HTCUNIVERSAL         855
#define MACH_TYPE_TPAD                 856
#define MACH_TYPE_ROVERP3              857
#define MACH_TYPE_JORNADA928           858
#define MACH_TYPE_MV88FXX81            859
#define MACH_TYPE_STMP36XX             860
#define MACH_TYPE_SXNI79524            861
#define MACH_TYPE_AMS_DELTA            862
#define MACH_TYPE_URANIUM              863
#define MACH_TYPE_UCON                 864
#define MACH_TYPE_NAS100D              865
#define MACH_TYPE_L083_1000            866
#define MACH_TYPE_EZX                  867
#define MACH_TYPE_PNX5220              868
#define MACH_TYPE_BUTTE                869
#define MACH_TYPE_SRM2                 870
#define MACH_TYPE_DSBR                 871
#define MACH_TYPE_CRYSTALBALL          872
#define MACH_TYPE_TINYPXA27X           873
#define MACH_TYPE_HERBIE               874
#define MACH_TYPE_MAGICIAN             875
#define MACH_TYPE_CM4002               876
#define MACH_TYPE_B4                   877
#define MACH_TYPE_MAUI                 878
#define MACH_TYPE_CYBERTRACKER_G       879
#define MACH_TYPE_NXDKN                880
#define MACH_TYPE_MIO8390              881
#define MACH_TYPE_OMI_BOARD            882
#define MACH_TYPE_MX21CIV              883
#define MACH_TYPE_MAHI_CDAC            884
#define MACH_TYPE_PALMTX               885
#define MACH_TYPE_S3C2413              887
#define MACH_TYPE_SAMSYS_EP0           888
#define MACH_TYPE_WG302V1              889
#define MACH_TYPE_WG302V2              890
#define MACH_TYPE_EB42X                891
#define MACH_TYPE_IQ331ES              892
#define MACH_TYPE_COSYDSP              893
#define MACH_TYPE_UPLAT7D              894
#define MACH_TYPE_PTDAVINCI            895
#define MACH_TYPE_MBUS                 896
#define MACH_TYPE_NADIA2VB             897
#define MACH_TYPE_R1000                898
#define MACH_TYPE_HW90250              899
#define MACH_TYPE_OMAP_2430SDP         900
#define MACH_TYPE_DAVINCI_EVM          901
#define MACH_TYPE_OMAP_TORNADO         902
#define MACH_TYPE_OLOCREEK             903
#define MACH_TYPE_PALMZ72              904
#define MACH_TYPE_NXDB500              905
#define MACH_TYPE_APF9328              906
#define MACH_TYPE_OMAP_WIPOQ           907
#define MACH_TYPE_OMAP_TWIP            908
#define MACH_TYPE_TREO650              909
#define MACH_TYPE_ACUMEN               910
#define MACH_TYPE_XP100                911
#define MACH_TYPE_FS2410               912
#define MACH_TYPE_PXA270_CERF          913
#define MACH_TYPE_SQ2FTLPALM           914
#define MACH_TYPE_BSEMSERVER           915
#define MACH_TYPE_NETCLIENT            916
#define MACH_TYPE_PALMT5               917
#define MACH_TYPE_PALMTC               918
#define MACH_TYPE_OMAP_APOLLON         919
#define MACH_TYPE_MXC30030EVB          920
#define MACH_TYPE_REA_2D               921
#define MACH_TYPE_TI3E524              922
#define MACH_TYPE_ATEB9200             923
#define MACH_TYPE_AUCKLAND             924
#define MACH_TYPE_AK3320M              925
#define MACH_TYPE_DURAMAX              926
#define MACH_TYPE_N35                  927
#define MACH_TYPE_PRONGHORN            928
#define MACH_TYPE_FUNDY                929
#define MACH_TYPE_LOGICPD_PXA270       930
#define MACH_TYPE_CPU777               931
#define MACH_TYPE_SIMICON9201          932
#define MACH_TYPE_LEAP2_HPM            933
#define MACH_TYPE_CM922TXA10           934
#define MACH_TYPE_PXA                  935
#define MACH_TYPE_SANDGATE2            936
#define MACH_TYPE_SANDGATE2G           937
#define MACH_TYPE_SANDGATE2P           938
#define MACH_TYPE_FRED_JACK            939
#define MACH_TYPE_TTG_COLOR1           940
#define MACH_TYPE_NXEB500HMI           941
#define MACH_TYPE_NETDCU8              942
#define MACH_TYPE_NG_FVX538            944
#define MACH_TYPE_NG_FVS338            945
#define MACH_TYPE_PNX4103              946
#define MACH_TYPE_HESDB                947
#define MACH_TYPE_XSILO                948
#define MACH_TYPE_ESPRESSO             949
#define MACH_TYPE_EMLC                 950
#define MACH_TYPE_SISTERON             951
#define MACH_TYPE_RX1950               952
#define MACH_TYPE_TSC_VENUS            953
#define MACH_TYPE_DS101J               954
#define MACH_TYPE_MXC30030ADS          955
#define MACH_TYPE_FUJITSU_WIMAXSOC     956
#define MACH_TYPE_DUALPCMODEM          957
#define MACH_TYPE_GESBC9312            958
#define MACH_TYPE_HTCAPACHE            959
#define MACH_TYPE_IXDP435              960
#define MACH_TYPE_CATPROVT100          961
#define MACH_TYPE_PICOTUX1XX           962
#define MACH_TYPE_PICOTUX2XX           963
#define MACH_TYPE_DSMG600              964
#define MACH_TYPE_EMPC2                965
#define MACH_TYPE_VENTURA              966
#define MACH_TYPE_PHIDGET_SBC          967
#define MACH_TYPE_IJ3K                 968
#define MACH_TYPE_PISGAH               969
#define MACH_TYPE_OMAP_FSAMPLE         970
#define MACH_TYPE_SG720                971
#define MACH_TYPE_REDFOX               972
#define MACH_TYPE_MYSH_EP9315_1        973
#define MACH_TYPE_TPF106               974
#define MACH_TYPE_AT91RM9200KG         975
#define MACH_TYPE_SLEDB                976
#define MACH_TYPE_ONTRACK              977
#define MACH_TYPE_PM1200               978
#define MACH_TYPE_ESS24XXX             979
#define MACH_TYPE_COREMP7              980
#define MACH_TYPE_NEXCODER_6446        981
#define MACH_TYPE_STVC8380             982
#define MACH_TYPE_TEKLYNX              983
#define MACH_TYPE_CARBONADO            984
#define MACH_TYPE_SYSMOS_MP730         985
#define MACH_TYPE_SNAPPER_CL15         986
#define MACH_TYPE_PGIGIM               987
#define MACH_TYPE_PTX9160P2            988
#define MACH_TYPE_DCORE1               989
#define MACH_TYPE_VICTORPXA            990
#define MACH_TYPE_MX2DTB               991
#define MACH_TYPE_PXA_IREX_ER0100      992
#define MACH_TYPE_OMAP_PALMZ71         993
#define MACH_TYPE_BARTEC_DEG           994
#define MACH_TYPE_HW50251              995
#define MACH_TYPE_IBOX                 996
#define MACH_TYPE_ATLASLH7A404         997
#define MACH_TYPE_PT2026               998
#define MACH_TYPE_HTCALPINE            999
#define MACH_TYPE_BARTEC_VTU           1000
#define MACH_TYPE_VCOREII              1001
#define MACH_TYPE_PDNB3                1002
#define MACH_TYPE_HTCBEETLES           1003
#define MACH_TYPE_S3C6400              1004
#define MACH_TYPE_S3C2443              1005
#define MACH_TYPE_OMAP_LDK             1006
#define MACH_TYPE_SMDK2460             1007
#define MACH_TYPE_SMDK2440             1008
#define MACH_TYPE_SMDK2412             1009
#define MACH_TYPE_WEBBOX               1010
#define MACH_TYPE_CWWNDP               1011
#define MACH_TYPE_DRAGON               1012
#define MACH_TYPE_OPENDO_CPU_BOARD     1013
#define MACH_TYPE_CCM2200              1014
#define MACH_TYPE_ETWARM               1015
#define MACH_TYPE_M93030               1016
#define MACH_TYPE_CC7U                 1017
#define MACH_TYPE_MTT_RANGER           1018
#define MACH_TYPE_NEXUS                1019
#define MACH_TYPE_DESMAN               1020
#define MACH_TYPE_BKDE303              1021
#define MACH_TYPE_SMDK2413             1022
#define MACH_TYPE_AML_M7200            1023
#define MACH_TYPE_AML_M5900            1024
#define MACH_TYPE_SG640                1025
#define MACH_TYPE_EDG79524             1026
#define MACH_TYPE_AI2410               1027
#define MACH_TYPE_IXP465               1028
#define MACH_TYPE_BALLOON3             1029
#define MACH_TYPE_HEINS                1030
#define MACH_TYPE_MPLUSEVA             1031
#define MACH_TYPE_RT042                1032
#define MACH_TYPE_CWIEM                1033
#define MACH_TYPE_CM_X270              1034
#define MACH_TYPE_CM_X255              1035
#define MACH_TYPE_ESH_AT91             1036
#define MACH_TYPE_SANDGATE3            1037
#define MACH_TYPE_PRIMO                1038
#define MACH_TYPE_GEMSTONE             1039
#define MACH_TYPE_PRONGHORNMETRO       1040
#define MACH_TYPE_SIDEWINDER           1041
#define MACH_TYPE_PICOMOD1             1042
#define MACH_TYPE_SG590                1043
#define MACH_TYPE_AKAI9307             1044
#define MACH_TYPE_FONTAINE             1045
#define MACH_TYPE_WOMBAT               1046
#define MACH_TYPE_ACQ300               1047
#define MACH_TYPE_MOD_270              1048
#define MACH_TYPE_VC0820               1049
#define MACH_TYPE_ANI_AIM              1050
#define MACH_TYPE_JELLYFISH            1051
#define MACH_TYPE_AMANITA              1052
#define MACH_TYPE_VLINK                1053
#define MACH_TYPE_DEXFLEX              1054
#define MACH_TYPE_EIGEN_TTQ            1055
#define MACH_TYPE_ARCOM_TITAN          1056
#define MACH_TYPE_TABLA                1057
#define MACH_TYPE_MDIRAC3              1058
#define MACH_TYPE_MRHFBP2              1059
#define MACH_TYPE_AT91RM9200RB         1060
#define MACH_TYPE_ANI_APM              1061
#define MACH_TYPE_ELLA1                1062
#define MACH_TYPE_INHAND_PXA27X        1063
#define MACH_TYPE_INHAND_PXA25X        1064
#define MACH_TYPE_EMPOS_XM             1065
#define MACH_TYPE_EMPOS                1066
#define MACH_TYPE_EMPOS_TINY           1067
#define MACH_TYPE_EMPOS_SM             1068
#define MACH_TYPE_EGRET                1069
#define MACH_TYPE_OSTRICH              1070
#define MACH_TYPE_N50                  1071
#define MACH_TYPE_ECBAT91              1072
#define MACH_TYPE_STAREAST             1073
#define MACH_TYPE_DSPG_DW              1074
#define MACH_TYPE_ONEARM               1075
#define MACH_TYPE_MRG110_6             1076
#define MACH_TYPE_WRT300NV2            1077
#define MACH_TYPE_XM_BULVERDE          1078
#define MACH_TYPE_MSM6100              1079
#define MACH_TYPE_ETI_B1               1080
#define MACH_TYPE_ZILOG_ZA9L           1081
#define MACH_TYPE_BIT2440              1082
#define MACH_TYPE_NBI                  1083
#define MACH_TYPE_SMDK2443             1084
#define MACH_TYPE_VDAVINCI             1085
#define MACH_TYPE_ATC6                 1086
#define MACH_TYPE_MULTMDW              1087
#define MACH_TYPE_MBA2440              1088
#define MACH_TYPE_ECSD                 1089
#define MACH_TYPE_PALMZ31              1090
#define MACH_TYPE_FSG                  1091
#define MACH_TYPE_RAZOR101             1092
#define MACH_TYPE_OPERA_TDM            1093
#define MACH_TYPE_COMCERTO             1094
#define MACH_TYPE_TB0319               1095
#define MACH_TYPE_KWS8000              1096
#define MACH_TYPE_B2                   1097
#define MACH_TYPE_LCL54                1098
#define MACH_TYPE_AT91SAM9260EK        1099
#define MACH_TYPE_GLANTANK             1100
#define MACH_TYPE_N2100                1101
#define MACH_TYPE_N4100                1102
#define MACH_TYPE_VERTICAL_RSC4        1103
#define MACH_TYPE_SG8100               1104
#define MACH_TYPE_IM42XX               1105
#define MACH_TYPE_FTXX                 1106
#define MACH_TYPE_LWFUSION             1107
#define MACH_TYPE_QT2410               1108
#define MACH_TYPE_KIXRP435             1109
#define MACH_TYPE_CCW9C                1110
#define MACH_TYPE_DABHS                1111
#define MACH_TYPE_GZMX                 1112
#define MACH_TYPE_IPNW100AP            1113
#define MACH_TYPE_CC9P9360DEV          1114
#define MACH_TYPE_CC9P9750DEV          1115
#define MACH_TYPE_CC9P9360VAL          1116
#define MACH_TYPE_CC9P9750VAL          1117
#define MACH_TYPE_NX70V                1118
#define MACH_TYPE_AT91RM9200DF         1119
#define MACH_TYPE_SE_PILOT2            1120
#define MACH_TYPE_MTCN_T800            1121
#define MACH_TYPE_VCMX212              1122
#define MACH_TYPE_LYNX                 1123
#define MACH_TYPE_AT91SAM9260ID        1124
#define MACH_TYPE_HW86052              1125
#define MACH_TYPE_PILZ_PMI3            1126
#define MACH_TYPE_EDB9302A             1127
#define MACH_TYPE_EDB9307A             1128
#define MACH_TYPE_CT_DFS               1129
#define MACH_TYPE_PILZ_PMI4            1130
#define MACH_TYPE_XCEEDNP_IXP          1131
#define MACH_TYPE_SMDK2442B            1132
#define MACH_TYPE_XNODE                1133
#define MACH_TYPE_AIDX270              1134
#define MACH_TYPE_REMA                 1135
#define MACH_TYPE_BPS1000              1136
#define MACH_TYPE_HW90350              1137
#define MACH_TYPE_OMAP_3430SDP         1138
#define MACH_TYPE_BLUETOUCH            1139
#define MACH_TYPE_VSTMS                1140
#define MACH_TYPE_XSBASE270            1141
#define MACH_TYPE_AT91SAM9260EK_CN     1142
#define MACH_TYPE_ADSTURBOXB           1143
#define MACH_TYPE_OTI4110              1144
#define MACH_TYPE_HME_PXA              1145
#define MACH_TYPE_DEISTERDCA           1146
#define MACH_TYPE_CES_SSEM2            1147
#define MACH_TYPE_CES_MTR              1148
#define MACH_TYPE_TDS_AVNG_SBC         1149
#define MACH_TYPE_EVEREST              1150
#define MACH_TYPE_PNX4010              1151
#define MACH_TYPE_OXNAS                1152
#define MACH_TYPE_FIORI                1153
#define MACH_TYPE_ML1200               1154
#define MACH_TYPE_PECOS                1155
#define MACH_TYPE_NB2XXX               1156
#define MACH_TYPE_HW6900               1157
#define MACH_TYPE_CDCS_QUOLL           1158
#define MACH_TYPE_QUICKSILVER          1159
#define MACH_TYPE_UPLAT926             1160
#define MACH_TYPE_DEP2410_THOMAS       1161
#define MACH_TYPE_DTK2410              1162
#define MACH_TYPE_CHILI                1163
#define MACH_TYPE_DEMETER              1164
#define MACH_TYPE_DIONYSUS             1165
#define MACH_TYPE_AS352X               1166
#define MACH_TYPE_SERVICE              1167
#define MACH_TYPE_CS_E9301             1168
#define MACH_TYPE_MICRO9M              1169
#define MACH_TYPE_IA_MOSPCK            1170
#define MACH_TYPE_QL201B               1171
#define MACH_TYPE_BBM                  1174
#define MACH_TYPE_EXXX                 1175
#define MACH_TYPE_WMA11B               1176
#define MACH_TYPE_PELCO_ATLAS          1177
#define MACH_TYPE_G500                 1178
#define MACH_TYPE_BUG                  1179
#define MACH_TYPE_MX33ADS              1180
#define MACH_TYPE_CHUB                 1181
#define MACH_TYPE_NEO1973_GTA01        1182
#define MACH_TYPE_W90N740              1183
#define MACH_TYPE_MEDALLION_SA2410     1184
#define MACH_TYPE_IA_CPU_9200_2        1185
#define MACH_TYPE_DIMMRM9200           1186
#define MACH_TYPE_PM9261               1187
#define MACH_TYPE_ML7304               1189
#define MACH_TYPE_UCP250               1190
#define MACH_TYPE_INTBOARD             1191
#define MACH_TYPE_GULFSTREAM           1192
#define MACH_TYPE_LABQUEST             1193
#define MACH_TYPE_VCMX313              1194
#define MACH_TYPE_URG200               1195
#define MACH_TYPE_CPUX255LCDNET        1196
#define MACH_TYPE_NETDCU9              1197
#define MACH_TYPE_NETDCU10             1198
#define MACH_TYPE_DSPG_DGA             1199
#define MACH_TYPE_DSPG_DVW             1200
#define MACH_TYPE_SOLOS                1201
#define MACH_TYPE_AT91SAM9263EK        1202
#define MACH_TYPE_OSSTBOX              1203
#define MACH_TYPE_KBAT9261             1204
#define MACH_TYPE_CT1100               1205
#define MACH_TYPE_AKCPPXA              1206
#define MACH_TYPE_OCHAYA1020           1207
#define MACH_TYPE_HITRACK              1208
#define MACH_TYPE_SYME1                1209
#define MACH_TYPE_SYHL1                1210
#define MACH_TYPE_EMPCA400             1211
#define MACH_TYPE_EM7210               1212
#define MACH_TYPE_HTCHERMES            1213
#define MACH_TYPE_ETI_C1               1214
#define MACH_TYPE_AC100                1216
#define MACH_TYPE_SNEETCH              1217
#define MACH_TYPE_STUDENTMATE          1218
#define MACH_TYPE_ZIR2410              1219
#define MACH_TYPE_ZIR2413              1220
#define MACH_TYPE_DLONIP3              1221
#define MACH_TYPE_INSTREAM             1222
#define MACH_TYPE_AMBARELLA            1223
#define MACH_TYPE_NEVIS                1224
#define MACH_TYPE_HTC_TRINITY          1225
#define MACH_TYPE_QL202B               1226
#define MACH_TYPE_VPAC270              1227
#define MACH_TYPE_RD129                1228
#define MACH_TYPE_HTCWIZARD            1229
#define MACH_TYPE_TREO680              1230
#define MACH_TYPE_TECON_TMEZON         1231
#define MACH_TYPE_ZYLONITE             1233
#define MACH_TYPE_GENE1270             1234
#define MACH_TYPE_ZIR2412              1235
#define MACH_TYPE_MX31LITE             1236
#define MACH_TYPE_T700WX               1237
#define MACH_TYPE_VF100                1238
#define MACH_TYPE_NSB2                 1239
#define MACH_TYPE_NXHMI_BB             1240
#define MACH_TYPE_NXHMI_RE             1241
#define MACH_TYPE_N4100PRO             1242
#define MACH_TYPE_SAM9260              1243
#define MACH_TYPE_OMAP_TREO600         1244
#define MACH_TYPE_INDY2410             1245
#define MACH_TYPE_NELT_A               1246
#define MACH_TYPE_N311                 1248
#define MACH_TYPE_AT91SAM9260VGK       1249
#define MACH_TYPE_AT91LEPPE            1250
#define MACH_TYPE_AT91LEPCCN           1251
#define MACH_TYPE_APC7100              1252
#define MACH_TYPE_STARGAZER            1253
#define MACH_TYPE_SONATA               1254
#define MACH_TYPE_SCHMOOGIE            1255
#define MACH_TYPE_AZTOOL               1256
#define MACH_TYPE_MIOA701              1257
#define MACH_TYPE_SXNI9260             1258
#define MACH_TYPE_MXC27520EVB          1259
#define MACH_TYPE_ARMADILLO5X0         1260
#define MACH_TYPE_MB9260               1261
#define MACH_TYPE_MB9263               1262
#define MACH_TYPE_IPAC9302             1263
#define MACH_TYPE_CC9P9360JS           1264
#define MACH_TYPE_GALLIUM              1265
#define MACH_TYPE_MSC2410              1266
#define MACH_TYPE_GHI270               1267
#define MACH_TYPE_DAVINCI_LEONARDO     1268
#define MACH_TYPE_OIAB                 1269
#define MACH_TYPE_SMDK6400             1270
#define MACH_TYPE_NOKIA_N800           1271
#define MACH_TYPE_GREENPHONE           1272
#define MACH_TYPE_COMPEXWP18           1273
#define MACH_TYPE_XMATE                1274
#define MACH_TYPE_ENERGIZER            1275
#define MACH_TYPE_IME1                 1276
#define MACH_TYPE_SWEDATMS             1277
#define MACH_TYPE_NTNP435C             1278
#define MACH_TYPE_SPECTRO2             1279
#define MACH_TYPE_H6039                1280
#define MACH_TYPE_EP80219              1281
#define MACH_TYPE_SAMOA_II             1282
#define MACH_TYPE_CWMXL                1283
#define MACH_TYPE_AS9200               1284
#define MACH_TYPE_SFX1149              1285
#define MACH_TYPE_NAVI010              1286
#define MACH_TYPE_MULTMDP              1287
#define MACH_TYPE_SCB9520              1288
#define MACH_TYPE_HTCATHENA            1289
#define MACH_TYPE_XP179                1290
#define MACH_TYPE_H4300                1291
#define MACH_TYPE_GORAMO_MLR           1292
#define MACH_TYPE_MXC30020EVB          1293
#define MACH_TYPE_ADSBITSYG5           1294
#define MACH_TYPE_ADSPORTALPLUS        1295
#define MACH_TYPE_MMSP2PLUS            1296
#define MACH_TYPE_EM_X270              1297
#define MACH_TYPE_TPP302               1298
#define MACH_TYPE_TPM104               1299
#define MACH_TYPE_TPM102               1300
#define MACH_TYPE_TPM109               1301
#define MACH_TYPE_FBXO1                1302
#define MACH_TYPE_HXD8                 1303
#define MACH_TYPE_NEO1973_GTA02        1304
#define MACH_TYPE_EMTEST               1305
#define MACH_TYPE_AD6900               1306
#define MACH_TYPE_EUROPA               1307
#define MACH_TYPE_METROCONNECT         1308
#define MACH_TYPE_EZ_S2410             1309
#define MACH_TYPE_EZ_S2440             1310
#define MACH_TYPE_EZ_EP9312            1311
#define MACH_TYPE_EZ_EP9315            1312
#define MACH_TYPE_EZ_X7                1313
#define MACH_TYPE_GODOTDB              1314
#define MACH_TYPE_MISTRAL              1315
#define MACH_TYPE_MSM                  1316
#define MACH_TYPE_CT5910               1317
#define MACH_TYPE_CT5912               1318
#define MACH_TYPE_HYNET_INE            1319
#define MACH_TYPE_HYNET_APP            1320
#define MACH_TYPE_MSM7200              1321
#define MACH_TYPE_MSM7600              1322
#define MACH_TYPE_CEB255               1323
#define MACH_TYPE_CIEL                 1324
#define MACH_TYPE_SLM5650              1325
#define MACH_TYPE_AT91SAM9RLEK         1326
#define MACH_TYPE_COMTECH_ROUTER       1327
#define MACH_TYPE_SBC2410X             1328
#define MACH_TYPE_AT4X0BD              1329
#define MACH_TYPE_CBIFR                1330
#define MACH_TYPE_ARCOM_QUANTUM        1331
#define MACH_TYPE_MATRIX520            1332
#define MACH_TYPE_MATRIX510            1333
#define MACH_TYPE_MATRIX500            1334
#define MACH_TYPE_M501                 1335
#define MACH_TYPE_AAEON1270            1336
#define MACH_TYPE_MATRIX500EV          1337
#define MACH_TYPE_PAC500               1338
#define MACH_TYPE_PNX8181              1339
#define MACH_TYPE_COLIBRI320           1340
#define MACH_TYPE_AZTOOLBB             1341
#define MACH_TYPE_AZTOOLG2             1342
#define MACH_TYPE_DVLHOST              1343
#define MACH_TYPE_ZIR9200              1344
#define MACH_TYPE_ZIR9260              1345
#define MACH_TYPE_COCOPAH              1346
#define MACH_TYPE_NDS                  1347
#define MACH_TYPE_ROSENCRANTZ          1348
#define MACH_TYPE_FTTX_ODSC            1349
#define MACH_TYPE_CLASSE_R6904         1350
#define MACH_TYPE_CAM60                1351
#define MACH_TYPE_MXC30031ADS          1352
#define MACH_TYPE_DATACALL             1353
#define MACH_TYPE_AT91EB01             1354
#define MACH_TYPE_RTY                  1355
#define MACH_TYPE_DWL2100              1356
#define MACH_TYPE_VINSI                1357
#define MACH_TYPE_DB88F5281            1358
#define MACH_TYPE_CSB726               1359
#define MACH_TYPE_TIK27                1360
#define MACH_TYPE_MX_UC7420            1361
#define MACH_TYPE_RIRM3                1362
#define MACH_TYPE_PELCO_ODYSSEY        1363
#define MACH_TYPE_ADX_ABOX             1365
#define MACH_TYPE_ADX_TPID             1366
#define MACH_TYPE_MINICHECK            1367
#define MACH_TYPE_IDAM                 1368
#define MACH_TYPE_MARIO_MX             1369
#define MACH_TYPE_VI1888               1370
#define MACH_TYPE_ZR4230               1371
#define MACH_TYPE_T1_IX_BLUE           1372
#define MACH_TYPE_SYHQ2                1373
#define MACH_TYPE_COMPUTIME_R3         1374
#define MACH_TYPE_ORATIS               1375
#define MACH_TYPE_MIKKO                1376
#define MACH_TYPE_HOLON                1377
#define MACH_TYPE_OLIP8                1378
#define MACH_TYPE_GHI270HG             1379
#define MACH_TYPE_DAVINCI_DM6467_EVM   1380
#define MACH_TYPE_DAVINCI_DM355_EVM    1381
#define MACH_TYPE_BLACKRIVER           1383
#define MACH_TYPE_SANDGATEWP           1384
#define MACH_TYPE_CDOTBWSG             1385
#define MACH_TYPE_QUARK963             1386
#define MACH_TYPE_CSB735               1387
#define MACH_TYPE_LITTLETON            1388
#define MACH_TYPE_MIO_P550             1389
#define MACH_TYPE_MOTION2440           1390
#define MACH_TYPE_IMM500               1391
#define MACH_TYPE_HOMEMATIC            1392
#define MACH_TYPE_ERMINE               1393
#define MACH_TYPE_KB9202B              1394
#define MACH_TYPE_HS1XX                1395
#define MACH_TYPE_STUDENTMATE2440      1396
#define MACH_TYPE_ARVOO_L1_Z1          1397
#define MACH_TYPE_DEP2410K             1398
#define MACH_TYPE_XXSVIDEO             1399
#define MACH_TYPE_IM4004               1400
#define MACH_TYPE_OCHAYA1050           1401
#define MACH_TYPE_LEP9261              1402
#define MACH_TYPE_SVENMEB              1403
#define MACH_TYPE_FORTUNET2NE          1404
#define MACH_TYPE_NXHX                 1406
#define MACH_TYPE_REALVIEW_PB11MP      1407
#define MACH_TYPE_IDS500               1408
#define MACH_TYPE_ORS_N725             1409
#define MACH_TYPE_HSDARM               1410
#define MACH_TYPE_SHA_PON003           1411
#define MACH_TYPE_SHA_PON004           1412
#define MACH_TYPE_SHA_PON007           1413
#define MACH_TYPE_SHA_PON011           1414
#define MACH_TYPE_H6042                1415
#define MACH_TYPE_H6043                1416
#define MACH_TYPE_LOOXC550             1417
#define MACH_TYPE_CNTY_TITAN           1418
#define MACH_TYPE_APP3XX               1419
#define MACH_TYPE_SIDEOATSGRAMA        1420
#define MACH_TYPE_TREO700P             1421
#define MACH_TYPE_TREO700W             1422
#define MACH_TYPE_TREO750              1423
#define MACH_TYPE_TREO755P             1424
#define MACH_TYPE_EZREGANUT9200        1425
#define MACH_TYPE_SARGE                1426
#define MACH_TYPE_A696                 1427
#define MACH_TYPE_TURTLE               1428
#define MACH_TYPE_MX27_3DS             1430
#define MACH_TYPE_BISHOP               1431
#define MACH_TYPE_PXX                  1432
#define MACH_TYPE_REDWOOD              1433
#define MACH_TYPE_OMAP_2430DLP         1436
#define MACH_TYPE_OMAP_2430OSK         1437
#define MACH_TYPE_SARDINE              1438
#define MACH_TYPE_HALIBUT              1439
#define MACH_TYPE_TROUT                1440
#define MACH_TYPE_GOLDFISH             1441
#define MACH_TYPE_GESBC2440            1442
#define MACH_TYPE_NOMAD                1443
#define MACH_TYPE_ROSALIND             1444
#define MACH_TYPE_CC9P9215             1445
#define MACH_TYPE_CC9P9210             1446
#define MACH_TYPE_CC9P9215JS           1447
#define MACH_TYPE_CC9P9210JS           1448
#define MACH_TYPE_NASFFE               1449
#define MACH_TYPE_TN2X0BD              1450
#define MACH_TYPE_GWMPXA               1451
#define MACH_TYPE_EXYPLUS              1452
#define MACH_TYPE_JADOO21              1453
#define MACH_TYPE_LOOXN560             1454
#define MACH_TYPE_BONSAI               1455
#define MACH_TYPE_ADSMILGATO           1456
#define MACH_TYPE_GBA                  1457
#define MACH_TYPE_H6044                1458
#define MACH_TYPE_APP                  1459
#define MACH_TYPE_TCT_HAMMER           1460
#define MACH_TYPE_HERALD               1461
#define MACH_TYPE_ARTEMIS              1462
#define MACH_TYPE_HTCTITAN             1463
#define MACH_TYPE_QRANIUM              1464
#define MACH_TYPE_ADX_WSC2             1465
#define MACH_TYPE_ADX_MEDCOM           1466
#define MACH_TYPE_BBOARD               1467
#define MACH_TYPE_CAMBRIA              1468
#define MACH_TYPE_MT7XXX               1469
#define MACH_TYPE_MATRIX512            1470
#define MACH_TYPE_MATRIX522            1471
#define MACH_TYPE_IPAC5010             1472
#define MACH_TYPE_SAKURA               1473
#define MACH_TYPE_GROCX                1474
#define MACH_TYPE_PM9263               1475
#define MACH_TYPE_SIM_ONE              1476
#define MACH_TYPE_ACQ132               1477
#define MACH_TYPE_DATR                 1478
#define MACH_TYPE_ACTUX1               1479
#define MACH_TYPE_ACTUX2               1480
#define MACH_TYPE_ACTUX3               1481
#define MACH_TYPE_FLEXIT               1482
#define MACH_TYPE_BH2X0BD              1483
#define MACH_TYPE_ATB2002              1484
#define MACH_TYPE_XENON                1485
#define MACH_TYPE_FM607                1486
#define MACH_TYPE_MATRIX514            1487
#define MACH_TYPE_MATRIX524            1488
#define MACH_TYPE_INPOD                1489
#define MACH_TYPE_JIVE                 1490
#define MACH_TYPE_TLL_MX21             1491
#define MACH_TYPE_SBC2800              1492
#define MACH_TYPE_CC7UCAMRY            1493
#define MACH_TYPE_UBISYS_P9_SC15       1494
#define MACH_TYPE_UBISYS_P9_SSC2D10    1495
#define MACH_TYPE_UBISYS_P9_RCU3       1496
#define MACH_TYPE_AML_M8000            1497
#define MACH_TYPE_SNAPPER_270          1498
#define MACH_TYPE_OMAP_BBX             1499
#define MACH_TYPE_UCN2410              1500
#define MACH_TYPE_SAM9_L9260           1501
#define MACH_TYPE_ETI_C2               1502
#define MACH_TYPE_AVALANCHE            1503
#define MACH_TYPE_REALVIEW_PB1176      1504
#define MACH_TYPE_DP1500               1505
#define MACH_TYPE_APPLE_IPHONE         1506
#define MACH_TYPE_YL9200               1507
#define MACH_TYPE_RD88F5182            1508
#define MACH_TYPE_KUROBOX_PRO          1509
#define MACH_TYPE_SE_POET              1510
#define MACH_TYPE_MX31_3DS             1511
#define MACH_TYPE_R270                 1512
#define MACH_TYPE_ARMOUR21             1513
#define MACH_TYPE_DT2                  1514
#define MACH_TYPE_VT4                  1515
#define MACH_TYPE_TYCO320              1516
#define MACH_TYPE_ADMA                 1517
#define MACH_TYPE_WP188                1518
#define MACH_TYPE_CORSICA              1519
#define MACH_TYPE_BIGEYE               1520
#define MACH_TYPE_TLL5000              1522
#define MACH_TYPE_BEBOT                1523
#define MACH_TYPE_QONG                 1524
#define MACH_TYPE_TCOMPACT             1525
#define MACH_TYPE_PUMA5                1526
#define MACH_TYPE_ELARA                1527
#define MACH_TYPE_ELLINGTON            1528
#define MACH_TYPE_XDA_ATOM             1529
#define MACH_TYPE_ENERGIZER2           1530
#define MACH_TYPE_ODIN                 1531
#define MACH_TYPE_ACTUX4               1532
#define MACH_TYPE_ESL_OMAP             1533
#define MACH_TYPE_OMAP2EVM             1534
#define MACH_TYPE_OMAP3EVM             1535
#define MACH_TYPE_ADX_PCU57            1536
#define MACH_TYPE_MONACO               1537
#define MACH_TYPE_LEVANTE              1538
#define MACH_TYPE_TMXIPX425            1539
#define MACH_TYPE_LEEP                 1540
#define MACH_TYPE_RAAD                 1541
#define MACH_TYPE_DNS323               1542
#define MACH_TYPE_AP1000               1543
#define MACH_TYPE_A9SAM6432            1544
#define MACH_TYPE_SHINY                1545
#define MACH_TYPE_OMAP3_BEAGLE         1546
#define MACH_TYPE_CSR_BDB2             1547
#define MACH_TYPE_NOKIA_N810           1548
#define MACH_TYPE_C270                 1549
#define MACH_TYPE_SENTRY               1550
#define MACH_TYPE_PCM038               1551
#define MACH_TYPE_ANC300               1552
#define MACH_TYPE_HTCKAISER            1553
#define MACH_TYPE_SBAT100              1554
#define MACH_TYPE_MODUNORM             1555
#define MACH_TYPE_PELOS_TWARM          1556
#define MACH_TYPE_FLANK                1557
#define MACH_TYPE_SIRLOIN              1558
#define MACH_TYPE_BRISKET              1559
#define MACH_TYPE_CHUCK                1560
#define MACH_TYPE_OTTER                1561
#define MACH_TYPE_DAVINCI_LDK          1562
#define MACH_TYPE_PHREEDOM             1563
#define MACH_TYPE_SG310                1564
#define MACH_TYPE_TS209                1565
#define MACH_TYPE_AT91CAP9ADK          1566
#define MACH_TYPE_TION9315             1567
#define MACH_TYPE_MAST                 1568
#define MACH_TYPE_PFW                  1569
#define MACH_TYPE_YL_P2440             1570
#define MACH_TYPE_ZSBC32               1571
#define MACH_TYPE_OMAP_PACE2           1572
#define MACH_TYPE_IMX_PACE2            1573
#define MACH_TYPE_MX31MOBOARD          1574
#define MACH_TYPE_MX37_3DS             1575
#define MACH_TYPE_RCC                  1576
#define MACH_TYPE_ARM9                 1577
#define MACH_TYPE_VISION_EP9307        1578
#define MACH_TYPE_SCLY1000             1579
#define MACH_TYPE_FONTEL_EP            1580
#define MACH_TYPE_VOICEBLUE3G          1581
#define MACH_TYPE_TT9200               1582
#define MACH_TYPE_DIGI2410             1583
#define MACH_TYPE_TERASTATION_PRO2     1584
#define MACH_TYPE_LINKSTATION_PRO      1585
#define MACH_TYPE_MOTOROLA_A780        1587
#define MACH_TYPE_MOTOROLA_E6          1588
#define MACH_TYPE_MOTOROLA_E2          1589
#define MACH_TYPE_MOTOROLA_E680        1590
#define MACH_TYPE_UR2410               1591
#define MACH_TYPE_TAS9261              1592
#define MACH_TYPE_HERMES_HD            1593
#define MACH_TYPE_PERSEO_HD            1594
#define MACH_TYPE_STARGAZER2           1595
#define MACH_TYPE_E350                 1596
#define MACH_TYPE_WPCM450              1597
#define MACH_TYPE_CARTESIO             1598
#define MACH_TYPE_TOYBOX               1599
#define MACH_TYPE_TX27                 1600
#define MACH_TYPE_TS409                1601
#define MACH_TYPE_P300                 1602
#define MACH_TYPE_XDACOMET             1603
#define MACH_TYPE_DEXFLEX2             1604
#define MACH_TYPE_OW                   1605
#define MACH_TYPE_ARMEBS3              1606
#define MACH_TYPE_U3                   1607
#define MACH_TYPE_SMDK2450             1608
#define MACH_TYPE_RSI_EWS              1609
#define MACH_TYPE_TNB                  1610
#define MACH_TYPE_TOEPATH              1611
#define MACH_TYPE_KB9263               1612
#define MACH_TYPE_MT7108               1613
#define MACH_TYPE_SMTR2440             1614
#define MACH_TYPE_MANAO                1615
#define MACH_TYPE_CM_X300              1616
#define MACH_TYPE_GULFSTREAM_KP        1617
#define MACH_TYPE_LANREADYFN522        1618
#define MACH_TYPE_ARMA37               1619
#define MACH_TYPE_MENDEL               1620
#define MACH_TYPE_PELCO_ILIAD          1621
#define MACH_TYPE_UNIT2P               1622
#define MACH_TYPE_INC20OTTER           1623
#define MACH_TYPE_AT91SAM9G20EK        1624
#define MACH_TYPE_STORCENTER           1625
#define MACH_TYPE_SMDK6410             1626
#define MACH_TYPE_U300                 1627
#define MACH_TYPE_U500                 1628
#define MACH_TYPE_DS9260               1629
#define MACH_TYPE_RIVERROCK            1630
#define MACH_TYPE_SCIBATH              1631
#define MACH_TYPE_AT91SAM7SE512EK      1632
#define MACH_TYPE_WRT350N_V2           1633
#define MACH_TYPE_MULTIMEDIA           1634
#define MACH_TYPE_MARVIN               1635
#define MACH_TYPE_X500                 1636
#define MACH_TYPE_AWLUG4LCU            1637
#define MACH_TYPE_PALERMOC             1638
#define MACH_TYPE_OMAP_LDP             1639
#define MACH_TYPE_IP500                1640
#define MACH_TYPE_ASE2                 1642
#define MACH_TYPE_MX35EVB              1643
#define MACH_TYPE_AML_M8050            1644
#define MACH_TYPE_MX35_3DS             1645
#define MACH_TYPE_MARS                 1646
#define MACH_TYPE_NEUROS_OSD2          1647
#define MACH_TYPE_BADGER               1648
#define MACH_TYPE_TRIZEPS4WL           1649
#define MACH_TYPE_TRIZEPS5             1650
#define MACH_TYPE_MARLIN               1651
#define MACH_TYPE_TS78XX               1652
#define MACH_TYPE_HPIPAQ214            1653
#define MACH_TYPE_AT572D940DCM         1654
#define MACH_TYPE_NE1BOARD             1655
#define MACH_TYPE_ZANTE                1656
#define MACH_TYPE_SFFSDR               1657
#define MACH_TYPE_TW2662               1658
#define MACH_TYPE_VF10XX               1659
#define MACH_TYPE_ZORAN43XX            1660
#define MACH_TYPE_SONIX926             1661
#define MACH_TYPE_CELESTIALSEMI        1662
#define MACH_TYPE_CC9M2443JS           1663
#define MACH_TYPE_TW5334               1664
#define MACH_TYPE_HTCARTEMIS           1665
#define MACH_TYPE_NAL_HLITE            1666
#define MACH_TYPE_HTCVOGUE             1667
#define MACH_TYPE_SMARTWEB             1668
#define MACH_TYPE_MV86XX               1669
#define MACH_TYPE_MV87XX               1670
#define MACH_TYPE_SONGYOUNGHO          1671
#define MACH_TYPE_YOUNGHOTEMA          1672
#define MACH_TYPE_PCM037               1673
#define MACH_TYPE_MMVP                 1674
#define MACH_TYPE_MMAP                 1675
#define MACH_TYPE_PTID2410             1676
#define MACH_TYPE_JAMES_926            1677
#define MACH_TYPE_FM6000               1678
#define MACH_TYPE_DB88F6281_BP         1680
#define MACH_TYPE_RD88F6192_NAS        1681
#define MACH_TYPE_RD88F6281            1682
#define MACH_TYPE_DB78X00_BP           1683
#define MACH_TYPE_SMDK2416             1685
#define MACH_TYPE_OCE_SPIDER_SI        1686
#define MACH_TYPE_OCE_SPIDER_SK        1687
#define MACH_TYPE_ROVERN6              1688
#define MACH_TYPE_PELCO_EVOLUTION      1689
#define MACH_TYPE_WBD111               1690
#define MACH_TYPE_ELARACPE             1691
#define MACH_TYPE_MABV3                1692
#define MACH_TYPE_MV2120               1693
#define MACH_TYPE_CSB737               1695
#define MACH_TYPE_MX51_3DS             1696
#define MACH_TYPE_G900                 1697
#define MACH_TYPE_APF27                1698
#define MACH_TYPE_GGUS2000             1699
#define MACH_TYPE_OMAP_2430_MIMIC      1700
#define MACH_TYPE_IMX27LITE            1701
#define MACH_TYPE_ALMEX                1702
#define MACH_TYPE_CONTROL              1703
#define MACH_TYPE_MBA2410              1704
#define MACH_TYPE_VOLCANO              1705
#define MACH_TYPE_ZENITH               1706
#define MACH_TYPE_MUCHIP               1707
#define MACH_TYPE_MAGELLAN             1708
#define MACH_TYPE_USB_A9260            1709
#define MACH_TYPE_USB_A9263            1710
#define MACH_TYPE_QIL_A9260            1711
#define MACH_TYPE_CME9210              1712
#define MACH_TYPE_HCZH4                1713
#define MACH_TYPE_SPEARBASIC           1714
#define MACH_TYPE_DEP2440              1715
#define MACH_TYPE_HDL_GXR              1716
#define MACH_TYPE_HDL_GT               1717
#define MACH_TYPE_HDL_4G               1718
#define MACH_TYPE_S3C6000              1719
#define MACH_TYPE_MMSP2_MDK            1720
#define MACH_TYPE_MPX220               1721
#define MACH_TYPE_KZM_ARM11_01         1722
#define MACH_TYPE_HTC_POLARIS          1723
#define MACH_TYPE_HTC_KAISER           1724
#define MACH_TYPE_LG_KS20              1725
#define MACH_TYPE_HHGPS                1726
#define MACH_TYPE_NOKIA_N810_WIMAX     1727
#define MACH_TYPE_INSIGHT              1728
#define MACH_TYPE_SAPPHIRE             1729
#define MACH_TYPE_CSB637XO             1730
#define MACH_TYPE_EVISIONG             1731
#define MACH_TYPE_STMP37XX             1732
#define MACH_TYPE_STMP378X             1733
#define MACH_TYPE_TNT                  1734
#define MACH_TYPE_TBXT                 1735
#define MACH_TYPE_PLAYMATE             1736
#define MACH_TYPE_PNS10                1737
#define MACH_TYPE_EZNAVI               1738
#define MACH_TYPE_PS4000               1739
#define MACH_TYPE_EZX_A780             1740
#define MACH_TYPE_EZX_E680             1741
#define MACH_TYPE_EZX_A1200            1742
#define MACH_TYPE_EZX_E6               1743
#define MACH_TYPE_EZX_E2               1744
#define MACH_TYPE_EZX_A910             1745
#define MACH_TYPE_CWMX31               1746
#define MACH_TYPE_SL2312               1747
#define MACH_TYPE_BLENNY               1748
#define MACH_TYPE_DS107                1749
#define MACH_TYPE_DSX07                1750
#define MACH_TYPE_PICOCOM1             1751
#define MACH_TYPE_LYNX_WOLVERINE       1752
#define MACH_TYPE_UBISYS_P9_SC19       1753
#define MACH_TYPE_KRATOS_LOW           1754
#define MACH_TYPE_M700                 1755
#define MACH_TYPE_EDMINI_V2            1756
#define MACH_TYPE_ZIPIT2               1757
#define MACH_TYPE_HSLFEMTOCELL         1758
#define MACH_TYPE_DAINTREE_AT91        1759
#define MACH_TYPE_SG560USB             1760
#define MACH_TYPE_OMAP3_PANDORA        1761
#define MACH_TYPE_USR8200              1762
#define MACH_TYPE_S1S65K               1763
#define MACH_TYPE_S2S65A               1764
#define MACH_TYPE_ICORE                1765
#define MACH_TYPE_MSS2                 1766
#define MACH_TYPE_BELMONT              1767
#define MACH_TYPE_ASUSP525             1768
#define MACH_TYPE_LB88RC8480           1769
#define MACH_TYPE_HIPXA                1770
#define MACH_TYPE_MX25_3DS             1771
#define MACH_TYPE_M800                 1772
#define MACH_TYPE_OMAP3530_LV_SOM      1773
#define MACH_TYPE_PRIMA_EVB            1774
#define MACH_TYPE_MX31BT1              1775
#define MACH_TYPE_ATLAS4_EVB           1776
#define MACH_TYPE_MX31CICADA           1777
#define MACH_TYPE_MI424WR              1778
#define MACH_TYPE_AXS_ULTRAX           1779
#define MACH_TYPE_AT572D940DEB         1780
#define MACH_TYPE_DAVINCI_DA830_EVM    1781
#define MACH_TYPE_EP9302               1782
#define MACH_TYPE_AT572D940HFEB        1783
#define MACH_TYPE_CYBOOK3              1784
#define MACH_TYPE_WDG002               1785
#define MACH_TYPE_SG560ADSL            1786
#define MACH_TYPE_NEXTIO_N2800_ICA     1787
#define MACH_TYPE_DOVE_DB              1788
#define MACH_TYPE_VANDIHUD             1790
#define MACH_TYPE_MAGX_E8              1791
#define MACH_TYPE_MAGX_Z6              1792
#define MACH_TYPE_MAGX_V8              1793
#define MACH_TYPE_MAGX_U9              1794
#define MACH_TYPE_TOUGHCF08            1795
#define MACH_TYPE_ZW4400               1796
#define MACH_TYPE_MARAT91              1797
#define MACH_TYPE_OVERO                1798
#define MACH_TYPE_AT2440EVB            1799
#define MACH_TYPE_NEOCORE926           1800
#define MACH_TYPE_WNR854T              1801
#define MACH_TYPE_IMX27                1802
#define MACH_TYPE_MOOSE_DB             1803
#define MACH_TYPE_FAB4                 1804
#define MACH_TYPE_HTCDIAMOND           1805
#define MACH_TYPE_FIONA                1806
#define MACH_TYPE_MXC30030_X           1807
#define MACH_TYPE_BMP1000              1808
#define MACH_TYPE_LOGI9200             1809
#define MACH_TYPE_TQMA31               1810
#define MACH_TYPE_CCW9P9215JS          1811
#define MACH_TYPE_RD88F5181L_GE        1812
#define MACH_TYPE_SIFMAIN              1813
#define MACH_TYPE_SAM9_L9261           1814
#define MACH_TYPE_CC9M2443             1815
#define MACH_TYPE_XARIA300             1816
#define MACH_TYPE_IT9200               1817
#define MACH_TYPE_RD88F5181L_FXO       1818
#define MACH_TYPE_KRISS_SENSOR         1819
#define MACH_TYPE_PILZ_PMI5            1820
#define MACH_TYPE_JADE                 1821
#define MACH_TYPE_KS8695_SOFTPLC       1822
#define MACH_TYPE_GPRISC3              1823
#define MACH_TYPE_STAMP9G20            1824
#define MACH_TYPE_SMDK6430             1825
#define MACH_TYPE_SMDKC100             1826
#define MACH_TYPE_TAVOREVB             1827
#define MACH_TYPE_SAAR                 1828
#define MACH_TYPE_DEISTER_EYECAM       1829
#define MACH_TYPE_AT91SAM9M10G45EK     1830
#define MACH_TYPE_LINKSTATION_PRODUO   1831
#define MACH_TYPE_HIT_B0               1832
#define MACH_TYPE_ADX_RMU              1833
#define MACH_TYPE_XG_CPE_MAIN          1834
#define MACH_TYPE_EDB9407A             1835
#define MACH_TYPE_DTB9608              1836
#define MACH_TYPE_EM104V1              1837
#define MACH_TYPE_DEMO                 1838
#define MACH_TYPE_LOGI9260             1839
#define MACH_TYPE_MX31_EXM32           1840
#define MACH_TYPE_USB_A9G20            1841
#define MACH_TYPE_PICPROJE2008         1842
#define MACH_TYPE_CS_E9315             1843
#define MACH_TYPE_QIL_A9G20            1844
#define MACH_TYPE_SHA_PON020           1845
#define MACH_TYPE_NAD                  1846
#define MACH_TYPE_SBC35_A9260          1847
#define MACH_TYPE_SBC35_A9G20          1848
#define MACH_TYPE_DAVINCI_BEGINNING    1849
#define MACH_TYPE_UWC                  1850
#define MACH_TYPE_MXLADS               1851
#define MACH_TYPE_HTCNIKE              1852
#define MACH_TYPE_DEISTER_PXA270       1853
#define MACH_TYPE_CME9210JS            1854
#define MACH_TYPE_CC9P9360             1855
#define MACH_TYPE_MOCHA                1856
#define MACH_TYPE_WAPD170AG            1857
#define MACH_TYPE_LINKSTATION_MINI     1858
#define MACH_TYPE_AFEB9260             1859
#define MACH_TYPE_W90X900              1860
#define MACH_TYPE_W90X700              1861
#define MACH_TYPE_KT300IP              1862
#define MACH_TYPE_KT300IP_G20          1863
#define MACH_TYPE_SRCM                 1864
#define MACH_TYPE_WLNX_9260            1865
#define MACH_TYPE_OPENMOKO_GTA03       1866
#define MACH_TYPE_OSPREY2              1867
#define MACH_TYPE_KBIO9260             1868
#define MACH_TYPE_GINZA                1869
#define MACH_TYPE_A636N                1870
#define MACH_TYPE_IMX27IPCAM           1871
#define MACH_TYPE_NEMOC                1872
#define MACH_TYPE_GENEVA               1873
#define MACH_TYPE_HTCPHAROS            1874
#define MACH_TYPE_NEONC                1875
#define MACH_TYPE_NAS7100              1876
#define MACH_TYPE_TEUPHONE             1877
#define MACH_TYPE_ANNAX_ETH2           1878
#define MACH_TYPE_CSB733               1879
#define MACH_TYPE_BK3                  1880
#define MACH_TYPE_OMAP_EM32            1881
#define MACH_TYPE_ET9261CP             1882
#define MACH_TYPE_JASPERC              1883
#define MACH_TYPE_ISSI_ARM9            1884
#define MACH_TYPE_UED                  1885
#define MACH_TYPE_ESIBLADE             1886
#define MACH_TYPE_EYE02                1887
#define MACH_TYPE_IMX27KBD             1888
#define MACH_TYPE_KIXVP435             1890
#define MACH_TYPE_KIXNP435             1891
#define MACH_TYPE_AFRICA               1892
#define MACH_TYPE_NH233                1893
#define MACH_TYPE_RD88F6183AP_GE       1894
#define MACH_TYPE_BCM4760              1895
#define MACH_TYPE_EDDY_V2              1896
#define MACH_TYPE_REALVIEW_PBA8        1897
#define MACH_TYPE_HID_A7               1898
#define MACH_TYPE_HERO                 1899
#define MACH_TYPE_OMAP_POSEIDON        1900
#define MACH_TYPE_REALVIEW_PBX         1901
#define MACH_TYPE_MICRO9S              1902
#define MACH_TYPE_MAKO                 1903
#define MACH_TYPE_XDAFLAME             1904
#define MACH_TYPE_PHIDGET_SBC2         1905
#define MACH_TYPE_LIMESTONE            1906
#define MACH_TYPE_IPROBE_C32           1907
#define MACH_TYPE_RUT100               1908
#define MACH_TYPE_ASUSP535             1909
#define MACH_TYPE_HTCRAPHAEL           1910
#define MACH_TYPE_SYGDG1               1911
#define MACH_TYPE_SYGDG2               1912
#define MACH_TYPE_SEOUL                1913
#define MACH_TYPE_SALERNO              1914
#define MACH_TYPE_UCN_S3C64XX          1915
#define MACH_TYPE_MSM7201A             1916
#define MACH_TYPE_LPR1                 1917
#define MACH_TYPE_ARMADILLO500FX       1918
#define MACH_TYPE_G3EVM                1919
#define MACH_TYPE_Z3_DM355             1920
#define MACH_TYPE_W90P910EVB           1921
#define MACH_TYPE_W90P920EVB           1922
#define MACH_TYPE_W90P950EVB           1923
#define MACH_TYPE_W90N960EVB           1924
#define MACH_TYPE_CAMHD                1925
#define MACH_TYPE_MVC100               1926
#define MACH_TYPE_ELECTRUM_200         1927
#define MACH_TYPE_HTCJADE              1928
#define MACH_TYPE_MEMPHIS              1929
#define MACH_TYPE_IMX27SBC             1930
#define MACH_TYPE_LEXTAR               1931
#define MACH_TYPE_MV88F6281GTW_GE      1932
#define MACH_TYPE_NCP                  1933
#define MACH_TYPE_Z32AN                1934
#define MACH_TYPE_TMQ_CAPD             1935
#define MACH_TYPE_OMAP3_WL             1936
#define MACH_TYPE_CHUMBY               1937
#define MACH_TYPE_ATSARM9              1938
#define MACH_TYPE_DAVINCI_DM365_EVM    1939
#define MACH_TYPE_BAHAMAS              1940
#define MACH_TYPE_DAS                  1941
#define MACH_TYPE_MINIDAS              1942
#define MACH_TYPE_VK1000               1943
#define MACH_TYPE_CENTRO               1944
#define MACH_TYPE_CTERA_2BAY           1945
#define MACH_TYPE_EDGECONNECT          1946
#define MACH_TYPE_ND27000              1947
#define MACH_TYPE_GEMALTO_COBRA        1948
#define MACH_TYPE_INGELABS_COMET       1949
#define MACH_TYPE_POLLUX_WIZ           1950
#define MACH_TYPE_BLACKSTONE           1951
#define MACH_TYPE_TOPAZ                1952
#define MACH_TYPE_AIXLE                1953
#define MACH_TYPE_MW998                1954
#define MACH_TYPE_NOKIA_RX51           1955
#define MACH_TYPE_VSC5605EV            1956
#define MACH_TYPE_NT98700DK            1957
#define MACH_TYPE_ICONTACT             1958
#define MACH_TYPE_SWARCO_FRCPU         1959
#define MACH_TYPE_SWARCO_SCPU          1960
#define MACH_TYPE_BBOX_P16             1961
#define MACH_TYPE_BSTD                 1962
#define MACH_TYPE_SBC2440II            1963
#define MACH_TYPE_PCM034               1964
#define MACH_TYPE_NESO                 1965
#define MACH_TYPE_WLNX_9G20            1966
#define MACH_TYPE_OMAP_ZOOM2           1967
#define MACH_TYPE_TOTEMNOVA            1968
#define MACH_TYPE_C5000                1969
#define MACH_TYPE_UNIPO_AT91SAM9263    1970
#define MACH_TYPE_ETHERNUT5            1971
#define MACH_TYPE_ARM11                1972
#define MACH_TYPE_CPUAT9260            1973
#define MACH_TYPE_CPUPXA255            1974
#define MACH_TYPE_EUKREA_CPUIMX27      1975
#define MACH_TYPE_CHEFLUX              1976
#define MACH_TYPE_EB_CPUX9K2           1977
#define MACH_TYPE_OPCOTEC              1978
#define MACH_TYPE_YT                   1979
#define MACH_TYPE_MOTOQ                1980
#define MACH_TYPE_BSB1                 1981
#define MACH_TYPE_ACS5K                1982
#define MACH_TYPE_MILAN                1983
#define MACH_TYPE_QUARTZV2             1984
#define MACH_TYPE_RSVP                 1985
#define MACH_TYPE_RMP200               1986
#define MACH_TYPE_SNAPPER_9260         1987
#define MACH_TYPE_DSM320               1988
#define MACH_TYPE_ADSGCM               1989
#define MACH_TYPE_ASE2_400             1990
#define MACH_TYPE_PIZZA                1991
#define MACH_TYPE_SPOT_NGPL            1992
#define MACH_TYPE_ARMATA               1993
#define MACH_TYPE_EXEDA                1994
#define MACH_TYPE_MX31SF005            1995
#define MACH_TYPE_F5D8231_4_V2         1996
#define MACH_TYPE_Q2440                1997
#define MACH_TYPE_QQ2440               1998
#define MACH_TYPE_MINI2440             1999
#define MACH_TYPE_COLIBRI300           2000
#define MACH_TYPE_JADES                2001
#define MACH_TYPE_SPARK                2002
#define MACH_TYPE_BENZINA              2003
#define MACH_TYPE_BLAZE                2004
#define MACH_TYPE_LINKSTATION_LS_HGL   2005
#define MACH_TYPE_HTCKOVSKY            2006
#define MACH_TYPE_SONY_PRS505          2007
#define MACH_TYPE_HANLIN_V3            2008
#define MACH_TYPE_SAPPHIRA             2009
#define MACH_TYPE_DACK_SDA_01          2010
#define MACH_TYPE_ARMBOX               2011
#define MACH_TYPE_HARRIS_RVP           2012
#define MACH_TYPE_RIBALDO              2013
#define MACH_TYPE_AGORA                2014
#define MACH_TYPE_OMAP3_MINI           2015
#define MACH_TYPE_A9SAM6432_B          2016
#define MACH_TYPE_USG2410              2017
#define MACH_TYPE_PC72052_I10_REVB     2018
#define MACH_TYPE_MX35_EXM32           2019
#define MACH_TYPE_TOPAS910             2020
#define MACH_TYPE_HYENA                2021
#define MACH_TYPE_POSPAX               2022
#define MACH_TYPE_HDL_GX               2023
#define MACH_TYPE_CTERA_4BAY           2024
#define MACH_TYPE_CTERA_PLUG_C         2025
#define MACH_TYPE_CRWEA_PLUG_I         2026
#define MACH_TYPE_EGAUGE2              2027
#define MACH_TYPE_DIDJ                 2028
#define MACH_TYPE_MEISTER              2029
#define MACH_TYPE_HTCBLACKSTONE        2030
#define MACH_TYPE_CPUAT9G20            2031
#define MACH_TYPE_SMDK6440             2032
#define MACH_TYPE_OMAP_35XX_MVP        2033
#define MACH_TYPE_CTERA_PLUG_I         2034
#define MACH_TYPE_PVG610               2035
#define MACH_TYPE_HPRW6815             2036
#define MACH_TYPE_OMAP3_OSWALD         2037
#define MACH_TYPE_NAS4220B             2038
#define MACH_TYPE_HTCRAPHAEL_CDMA      2039
#define MACH_TYPE_HTCDIAMOND_CDMA      2040
#define MACH_TYPE_SCALER               2041
#define MACH_TYPE_ZYLONITE2            2042
#define MACH_TYPE_ASPENITE             2043
#define MACH_TYPE_TETON                2044
#define MACH_TYPE_TTC_DKB              2045
#define MACH_TYPE_BISHOP2              2046
#define MACH_TYPE_IPPV5                2047
#define MACH_TYPE_FARM926              2048
#define MACH_TYPE_MMCCPU               2049
#define MACH_TYPE_SGMSFL               2050
#define MACH_TYPE_TT8000               2051
#define MACH_TYPE_ZRN4300LP            2052
#define MACH_TYPE_MPTC                 2053
#define MACH_TYPE_H6051                2054
#define MACH_TYPE_PVG610_101           2055
#define MACH_TYPE_STAMP9261_PC_EVB     2056
#define MACH_TYPE_PELCO_ODYSSEUS       2057
#define MACH_TYPE_TNY_A9260            2058
#define MACH_TYPE_TNY_A9G20            2059
#define MACH_TYPE_AESOP_MP2530F        2060
#define MACH_TYPE_DX900                2061
#define MACH_TYPE_CPODC2               2062
#define MACH_TYPE_TILT_8925            2063
#define MACH_TYPE_DAVINCI_DM357_EVM    2064
#define MACH_TYPE_SWORDFISH            2065
#define MACH_TYPE_CORVUS               2066
#define MACH_TYPE_TAURUS               2067
#define MACH_TYPE_AXM                  2068
#define MACH_TYPE_AXC                  2069
#define MACH_TYPE_BABY                 2070
#define MACH_TYPE_MP200                2071
#define MACH_TYPE_PCM043               2072
#define MACH_TYPE_HANLIN_V3C           2073
#define MACH_TYPE_KBK9G20              2074
#define MACH_TYPE_ADSTURBOG5           2075
#define MACH_TYPE_AVENGER_LITE1        2076
#define MACH_TYPE_SUC                  2077
#define MACH_TYPE_AT91SAM7S256         2078
#define MACH_TYPE_MENDOZA              2079
#define MACH_TYPE_KIRA                 2080
#define MACH_TYPE_MX1HBM               2081
#define MACH_TYPE_QUATRO43XX           2082
#define MACH_TYPE_QUATRO4230           2083
#define MACH_TYPE_NSB400               2084
#define MACH_TYPE_DRP255               2085
#define MACH_TYPE_THOTH                2086
#define MACH_TYPE_FIRESTONE            2087
#define MACH_TYPE_ASUSP750             2088
#define MACH_TYPE_CTERA_DL             2089
#define MACH_TYPE_SOCR                 2090
#define MACH_TYPE_HTCOXYGEN            2091
#define MACH_TYPE_HEROC                2092
#define MACH_TYPE_ZENO6800             2093
#define MACH_TYPE_SC2MCS               2094
#define MACH_TYPE_GENE100              2095
#define MACH_TYPE_AS353X               2096
#define MACH_TYPE_SHEEVAPLUG           2097
#define MACH_TYPE_AT91SAM9G20          2098
#define MACH_TYPE_MV88F6192GTW_FE      2099
#define MACH_TYPE_CC9200               2100
#define MACH_TYPE_SM9200               2101
#define MACH_TYPE_TP9200               2102
#define MACH_TYPE_SNAPPERDV            2103
#define MACH_TYPE_AVENGERS_LITE        2104
#define MACH_TYPE_AVENGERS_LITE1       2105
#define MACH_TYPE_OMAP3AXON            2106
#define MACH_TYPE_MA8XX                2107
#define MACH_TYPE_MP201EK              2108
#define MACH_TYPE_DAVINCI_TUX          2109
#define MACH_TYPE_MPA1600              2110
#define MACH_TYPE_PELCO_TROY           2111
#define MACH_TYPE_NSB667               2112
#define MACH_TYPE_ROVERS5_4MPIX        2113
#define MACH_TYPE_TWOCOM               2114
#define MACH_TYPE_UBISYS_P9_RCU3R2     2115
#define MACH_TYPE_HERO_ESPRESSO        2116
#define MACH_TYPE_AFEUSB               2117
#define MACH_TYPE_T830                 2118
#define MACH_TYPE_SPD8020_CC           2119
#define MACH_TYPE_OM_3D7K              2120
#define MACH_TYPE_PICOCOM2             2121
#define MACH_TYPE_UWG4MX27             2122
#define MACH_TYPE_UWG4MX31             2123
#define MACH_TYPE_CHERRY               2124
#define MACH_TYPE_MX51_BABBAGE         2125
#define MACH_TYPE_S3C2440TURKIYE       2126
#define MACH_TYPE_TX37                 2127
#define MACH_TYPE_SBC2800_9G20         2128
#define MACH_TYPE_BENZGLB              2129
#define MACH_TYPE_BENZTD               2130
#define MACH_TYPE_CARTESIO_PLUS        2131
#define MACH_TYPE_SOLRAD_G20           2132
#define MACH_TYPE_MX27WALLACE          2133
#define MACH_TYPE_FMZWEBMODUL          2134
#define MACH_TYPE_RD78X00_MASA         2135
#define MACH_TYPE_SMALLOGGER           2136
#define MACH_TYPE_CCW9P9215            2137
#define MACH_TYPE_DM355_LEOPARD        2138
#define MACH_TYPE_TS219                2139
#define MACH_TYPE_TNY_A9263            2140
#define MACH_TYPE_APOLLO               2141
#define MACH_TYPE_AT91CAP9STK          2142
#define MACH_TYPE_SPC300               2143
#define MACH_TYPE_EKO                  2144
#define MACH_TYPE_CCW9M2443            2145
#define MACH_TYPE_CCW9M2443JS          2146
#define MACH_TYPE_M2M_ROUTER_DEVICE    2147
#define MACH_TYPE_STAR9104NAS          2148
#define MACH_TYPE_PCA100               2149
#define MACH_TYPE_Z3_DM365_MOD_01      2150
#define MACH_TYPE_HIPOX                2151
#define MACH_TYPE_OMAP3_PITEDS         2152
#define MACH_TYPE_BM150R               2153
#define MACH_TYPE_TBONE                2154
#define MACH_TYPE_MERLIN               2155
#define MACH_TYPE_FALCON               2156
#define MACH_TYPE_DAVINCI_DA850_EVM    2157
#define MACH_TYPE_S5P6440              2158
#define MACH_TYPE_AT91SAM9G10EK        2159
#define MACH_TYPE_OMAP_4430SDP         2160
#define MACH_TYPE_LPC313X              2161
#define MACH_TYPE_MAGX_ZN5             2162
#define MACH_TYPE_MAGX_EM30            2163
#define MACH_TYPE_MAGX_VE66            2164
#define MACH_TYPE_MEESC                2165
#define MACH_TYPE_OTC570               2166
#define MACH_TYPE_BCU2412              2167
#define MACH_TYPE_BEACON               2168
#define MACH_TYPE_ACTIA_TGW            2169
#define MACH_TYPE_E4430                2170
#define MACH_TYPE_QL300                2171
#define MACH_TYPE_BTMAVB101            2172
#define MACH_TYPE_BTMAWB101            2173
#define MACH_TYPE_SQ201                2174
#define MACH_TYPE_QUATRO45XX           2175
#define MACH_TYPE_OPENPAD              2176
#define MACH_TYPE_TX25                 2177
#define MACH_TYPE_OMAP3_TORPEDO        2178
#define MACH_TYPE_HTCRAPHAEL_K         2179
#define MACH_TYPE_LAL43                2181
#define MACH_TYPE_HTCRAPHAEL_CDMA500   2182
#define MACH_TYPE_ANW6410              2183
#define MACH_TYPE_HTCPROPHET           2185
#define MACH_TYPE_CFA_10022            2186
#define MACH_TYPE_IMX27_VISSTRIM_M10   2187
#define MACH_TYPE_PX2IMX27             2188
#define MACH_TYPE_STM3210E_EVAL        2189
#define MACH_TYPE_DVS10                2190
#define MACH_TYPE_PORTUXG20            2191
#define MACH_TYPE_ARM_SPV              2192
#define MACH_TYPE_SMDKC110             2193
#define MACH_TYPE_CABESPRESSO          2194
#define MACH_TYPE_HMC800               2195
#define MACH_TYPE_SHOLES               2196
#define MACH_TYPE_BTMXC31              2197
#define MACH_TYPE_DT501                2198
#define MACH_TYPE_KTX                  2199
#define MACH_TYPE_OMAP3517EVM          2200
#define MACH_TYPE_NETSPACE_V2          2201
#define MACH_TYPE_NETSPACE_MAX_V2      2202
#define MACH_TYPE_D2NET_V2             2203
#define MACH_TYPE_NET2BIG_V2           2204
#define MACH_TYPE_NET4BIG_V2           2205
#define MACH_TYPE_NET5BIG_V2           2206
#define MACH_TYPE_ENDB2443             2207
#define MACH_TYPE_INETSPACE_V2         2208
#define MACH_TYPE_TROS                 2209
#define MACH_TYPE_PELCO_HOMER          2210
#define MACH_TYPE_OFSP8                2211
#define MACH_TYPE_AT91SAM9G45EKES      2212
#define MACH_TYPE_GUF_CUPID            2213
#define MACH_TYPE_EAB1R                2214
#define MACH_TYPE_DESIREC              2215
#define MACH_TYPE_CORDOBA              2216
#define MACH_TYPE_IRVINE               2217
#define MACH_TYPE_SFF772               2218
#define MACH_TYPE_PELCO_MILANO         2219
#define MACH_TYPE_PC7302               2220
#define MACH_TYPE_BIP6000              2221
#define MACH_TYPE_SILVERMOON           2222
#define MACH_TYPE_VC0830               2223
#define MACH_TYPE_DT430                2224
#define MACH_TYPE_JI42PF               2225
#define MACH_TYPE_GNET_KSM             2226
#define MACH_TYPE_GNET_SGM             2227
#define MACH_TYPE_GNET_SGR             2228
#define MACH_TYPE_OMAP3_ICETEKEVM      2229
#define MACH_TYPE_PNP                  2230
#define MACH_TYPE_CTERA_2BAY_K         2231
#define MACH_TYPE_CTERA_2BAY_U         2232
#define MACH_TYPE_SAS_C                2233
#define MACH_TYPE_VMA2315              2234
#define MACH_TYPE_VCS                  2235
#define MACH_TYPE_SPEAR600             2236
#define MACH_TYPE_SPEAR300             2237
#define MACH_TYPE_SPEAR1300            2238
#define MACH_TYPE_LILLY1131            2239
#define MACH_TYPE_ARVOO_AX301          2240
#define MACH_TYPE_MAPPHONE             2241
#define MACH_TYPE_LEGEND               2242
#define MACH_TYPE_SALSA                2243
#define MACH_TYPE_LOUNGE               2244
#define MACH_TYPE_VISION               2245
#define MACH_TYPE_VMB20                2246
#define MACH_TYPE_HY2410               2247
#define MACH_TYPE_HY9315               2248
#define MACH_TYPE_BULLWINKLE           2249
#define MACH_TYPE_ARM_ULTIMATOR2       2250
#define MACH_TYPE_VS_V210              2252
#define MACH_TYPE_VS_V212              2253
#define MACH_TYPE_HMT                  2254
#define MACH_TYPE_KM_KIRKWOOD          2255
#define MACH_TYPE_VESPER               2256
#define MACH_TYPE_STR9                 2257
#define MACH_TYPE_OMAP3_WL_FF          2258
#define MACH_TYPE_SIMCOM               2259
#define MACH_TYPE_MCWEBIO              2260
#define MACH_TYPE_OMAP3_PHRAZER        2261
#define MACH_TYPE_DARWIN               2262
#define MACH_TYPE_ORATISCOMU           2263
#define MACH_TYPE_RTSBC20              2264
#define MACH_TYPE_I780                 2265
#define MACH_TYPE_GEMINI324            2266
#define MACH_TYPE_ORATISLAN            2267
#define MACH_TYPE_ORATISALOG           2268
#define MACH_TYPE_ORATISMADI           2269
#define MACH_TYPE_ORATISOT16           2270
#define MACH_TYPE_ORATISDESK           2271
#define MACH_TYPE_VEXPRESS             2272
#define MACH_TYPE_SINTEXO              2273
#define MACH_TYPE_CM3389               2274
#define MACH_TYPE_OMAP3_CIO            2275
#define MACH_TYPE_SGH_I900             2276
#define MACH_TYPE_BST100               2277
#define MACH_TYPE_PASSION              2278
#define MACH_TYPE_INDESIGN_AT91SAM     2279
#define MACH_TYPE_C4_BADGER            2280
#define MACH_TYPE_C4_VIPER             2281
#define MACH_TYPE_D2NET                2282
#define MACH_TYPE_BIGDISK              2283
#define MACH_TYPE_NOTALVISION          2284
#define MACH_TYPE_OMAP3_KBOC           2285
#define MACH_TYPE_CYCLONE              2286
#define MACH_TYPE_NINJA                2287
#define MACH_TYPE_AT91SAM9G20EK_2MMC   2288
#define MACH_TYPE_BCMRING              2289
#define MACH_TYPE_RESOL_DL2            2290
#define MACH_TYPE_IFOSW                2291
#define MACH_TYPE_HTCRHODIUM           2292
#define MACH_TYPE_HTCTOPAZ             2293
#define MACH_TYPE_MATRIX504            2294
#define MACH_TYPE_MRFSA                2295
#define MACH_TYPE_SC_P270              2296
#define MACH_TYPE_ATLAS5_EVB           2297
#define MACH_TYPE_PELCO_LOBOX          2298
#define MACH_TYPE_DILAX_PCU200         2299
#define MACH_TYPE_LEONARDO             2300
#define MACH_TYPE_ZORAN_APPROACH7      2301
#define MACH_TYPE_DP6XX                2302
#define MACH_TYPE_BCM2153_VESPER       2303
#define MACH_TYPE_MAHIMAHI             2304
#define MACH_TYPE_CLICKC               2305
#define MACH_TYPE_ZB_GATEWAY           2306
#define MACH_TYPE_TAZCARD              2307
#define MACH_TYPE_TAZDEV               2308
#define MACH_TYPE_ANNAX_CB_ARM         2309
#define MACH_TYPE_ANNAX_DM3            2310
#define MACH_TYPE_CEREBRIC             2311
#define MACH_TYPE_ORCA                 2312
#define MACH_TYPE_PC9260               2313
#define MACH_TYPE_EMS285A              2314
#define MACH_TYPE_GEC2410              2315
#define MACH_TYPE_GEC2440              2316
#define MACH_TYPE_ARCH_MW903           2317
#define MACH_TYPE_MW2440               2318
#define MACH_TYPE_ECAC2378             2319
#define MACH_TYPE_TAZKIOSK             2320
#define MACH_TYPE_WHITERABBIT_MCH      2321
#define MACH_TYPE_SBOX9263             2322
#define MACH_TYPE_SMDK6442             2324
#define MACH_TYPE_OPENRD_BASE          2325
#define MACH_TYPE_INCREDIBLE           2326
#define MACH_TYPE_INCREDIBLEC          2327
#define MACH_TYPE_HEROCT               2328
#define MACH_TYPE_MMNET1000            2329
#define MACH_TYPE_DEVKIT8000           2330
#define MACH_TYPE_DEVKIT9000           2331
#define MACH_TYPE_MX31TXTR             2332
#define MACH_TYPE_U380                 2333
#define MACH_TYPE_HUALU_BOARD          2334
#define MACH_TYPE_NPCMX50              2335
#define MACH_TYPE_MX51_EFIKAMX         2336
#define MACH_TYPE_MX51_LANGE52         2337
#define MACH_TYPE_RIOM                 2338
#define MACH_TYPE_COMCAS               2339
#define MACH_TYPE_WSI_MX27             2340
#define MACH_TYPE_CM_T35               2341
#define MACH_TYPE_NET2BIG              2342
#define MACH_TYPE_MOTOROLA_A1600       2343
#define MACH_TYPE_IGEP0020             2344
#define MACH_TYPE_IGEP0010             2345
#define MACH_TYPE_MV6281GTWGE2         2346
#define MACH_TYPE_SCAT100              2347
#define MACH_TYPE_SANMINA              2348
#define MACH_TYPE_MOMENTO              2349
#define MACH_TYPE_NUC9XX               2350
#define MACH_TYPE_NUC910EVB            2351
#define MACH_TYPE_NUC920EVB            2352
#define MACH_TYPE_NUC950EVB            2353
#define MACH_TYPE_NUC945EVB            2354
#define MACH_TYPE_NUC960EVB            2355
#define MACH_TYPE_NUC932EVB            2356
#define MACH_TYPE_NUC900               2357
#define MACH_TYPE_SD1SOC               2358
#define MACH_TYPE_LN2440BC             2359
#define MACH_TYPE_RSBC                 2360
#define MACH_TYPE_OPENRD_CLIENT        2361
#define MACH_TYPE_HPIPAQ11X            2362
#define MACH_TYPE_WAYLAND              2363
#define MACH_TYPE_ACNBSX102            2364
#define MACH_TYPE_HWAT91               2365
#define MACH_TYPE_AT91SAM9263CS        2366
#define MACH_TYPE_CSB732               2367
#define MACH_TYPE_U8500                2368
#define MACH_TYPE_HUQIU                2369
#define MACH_TYPE_MX51_EFIKASB         2370
#define MACH_TYPE_PMT1G                2371
#define MACH_TYPE_HTCELF               2372
#define MACH_TYPE_ARMADILLO420         2373
#define MACH_TYPE_ARMADILLO440         2374
#define MACH_TYPE_U_CHIP_DUAL_ARM      2375
#define MACH_TYPE_CSR_BDB3             2376
#define MACH_TYPE_DOLBY_CAT1018        2377
#define MACH_TYPE_HY9307               2378
#define MACH_TYPE_A_ES                 2379
#define MACH_TYPE_DAVINCI_IRIF         2380
#define MACH_TYPE_AGAMA9263            2381
#define MACH_TYPE_MARVELL_JASPER       2382
#define MACH_TYPE_FLINT                2383
#define MACH_TYPE_TAVOREVB3            2384
#define MACH_TYPE_SCH_M490             2386
#define MACH_TYPE_RBL01                2387
#define MACH_TYPE_OMNIFI               2388
#define MACH_TYPE_OTAVALO              2389
#define MACH_TYPE_HTC_EXCALIBUR_S620   2391
#define MACH_TYPE_HTC_OPAL             2392
#define MACH_TYPE_TOUCHBOOK            2393
#define MACH_TYPE_LATTE                2394
#define MACH_TYPE_XA200                2395
#define MACH_TYPE_NIMROD               2396
#define MACH_TYPE_CC9P9215_3G          2397
#define MACH_TYPE_CC9P9215_3GJS        2398
#define MACH_TYPE_TK71                 2399
#define MACH_TYPE_COMHAM3525           2400
#define MACH_TYPE_MX31EREBUS           2401
#define MACH_TYPE_MCARDMX27            2402
#define MACH_TYPE_PARADISE             2403
#define MACH_TYPE_TIDE                 2404
#define MACH_TYPE_WZL2440              2405
#define MACH_TYPE_SDRDEMO              2406
#define MACH_TYPE_ETHERCAN2            2407
#define MACH_TYPE_ECMIMG20             2408
#define MACH_TYPE_OMAP_DRAGON          2409
#define MACH_TYPE_HALO                 2410
#define MACH_TYPE_HUANGSHAN            2411
#define MACH_TYPE_VL_MA2SC             2412
#define MACH_TYPE_RAUMFELD_RC          2413
#define MACH_TYPE_RAUMFELD_CONNECTOR   2414
#define MACH_TYPE_RAUMFELD_SPEAKER     2415
#define MACH_TYPE_MULTIBUS_MASTER      2416
#define MACH_TYPE_MULTIBUS_PBK         2417
#define MACH_TYPE_TNETV107X            2418
#define MACH_TYPE_SNAKE                2419
#define MACH_TYPE_CWMX27               2420
#define MACH_TYPE_SCH_M480             2421
#define MACH_TYPE_PLATYPUS             2422
#define MACH_TYPE_PSS2                 2423
#define MACH_TYPE_DAVINCI_APM150       2424
#define MACH_TYPE_STR9100              2425
#define MACH_TYPE_NET5BIG              2426
#define MACH_TYPE_SEABED9263           2427
#define MACH_TYPE_MX51_M2ID            2428
#define MACH_TYPE_OCTVOCPLUS_EB        2429
#define MACH_TYPE_KLK_FIREFOX          2430
#define MACH_TYPE_KLK_WIRMA_MODULE     2431
#define MACH_TYPE_KLK_WIRMA_MMI        2432
#define MACH_TYPE_SUPERSONIC           2433
#define MACH_TYPE_LIBERTY              2434
#define MACH_TYPE_MH355                2435
#define MACH_TYPE_PC7802               2436
#define MACH_TYPE_GNET_SGC             2437
#define MACH_TYPE_EINSTEIN15           2438
#define MACH_TYPE_CMPD                 2439
#define MACH_TYPE_DAVINCI_HASE1        2440
#define MACH_TYPE_LGEINCITEPHONE       2441
#define MACH_TYPE_EA313X               2442
#define MACH_TYPE_FWBD_39064           2443
#define MACH_TYPE_FWBD_390128          2444
#define MACH_TYPE_PELCO_MOE            2445
#define MACH_TYPE_MINIMIX27            2446
#define MACH_TYPE_OMAP3_THUNDER        2447
#define MACH_TYPE_PASSIONC             2448
#define MACH_TYPE_MX27AMATA            2449
#define MACH_TYPE_BGAT1                2450
#define MACH_TYPE_BUZZ                 2451
#define MACH_TYPE_MB9G20               2452
#define MACH_TYPE_YUSHAN               2453
#define MACH_TYPE_LIZARD               2454
#define MACH_TYPE_OMAP3POLYCOM         2455
#define MACH_TYPE_SMDKV210             2456
#define MACH_TYPE_BRAVO                2457
#define MACH_TYPE_SIOGENTOO1           2458
#define MACH_TYPE_SIOGENTOO2           2459
#define MACH_TYPE_SM3K                 2460
#define MACH_TYPE_ACER_TEMPO_F900      2461
#define MACH_TYPE_GLITTERTIND          2463
#define MACH_TYPE_OMAP_ZOOM3           2464
#define MACH_TYPE_OMAP_3630SDP         2465
#define MACH_TYPE_CYBOOK2440           2466
#define MACH_TYPE_TORINO_S             2467
#define MACH_TYPE_HAVANA               2468
#define MACH_TYPE_BEAUMONT_11          2469
#define MACH_TYPE_VANGUARD             2470
#define MACH_TYPE_S5PC110_DRACO        2471
#define MACH_TYPE_CARTESIO_TWO         2472
#define MACH_TYPE_ASTER                2473
#define MACH_TYPE_VOGUESV210           2474
#define MACH_TYPE_ACM500X              2475
#define MACH_TYPE_KM9260               2476
#define MACH_TYPE_NIDEFLEXG1           2477
#define MACH_TYPE_CTERA_PLUG_IO        2478
#define MACH_TYPE_SMARTQ7              2479
#define MACH_TYPE_AT91SAM9G10EK2       2480
#define MACH_TYPE_ASUSP527             2481
#define MACH_TYPE_AT91SAM9G20MPM2      2482
#define MACH_TYPE_TOPASA900            2483
#define MACH_TYPE_ELECTRUM_100         2484
#define MACH_TYPE_MX51GRB              2485
#define MACH_TYPE_XEA300               2486
#define MACH_TYPE_HTCSTARTREK          2487
#define MACH_TYPE_LIMA                 2488
#define MACH_TYPE_CSB740               2489
#define MACH_TYPE_USB_S8815            2490
#define MACH_TYPE_WATSON_EFM_PLUGIN    2491
#define MACH_TYPE_MILKYWAY             2492
#define MACH_TYPE_G4EVM                2493
#define MACH_TYPE_PICOMOD6             2494
#define MACH_TYPE_OMAPL138_HAWKBOARD   2495
#define MACH_TYPE_IP6000               2496
#define MACH_TYPE_IP6010               2497
#define MACH_TYPE_UTM400               2498
#define MACH_TYPE_OMAP3_ZYBEX          2499
#define MACH_TYPE_WIRELESS_SPACE       2500
#define MACH_TYPE_SX560                2501
#define MACH_TYPE_TS41X                2502
#define MACH_TYPE_ELPHEL10373          2503
#define MACH_TYPE_RHOBOT               2504
#define MACH_TYPE_MX51_REFRESH         2505
#define MACH_TYPE_LS9260               2506
#define MACH_TYPE_SHANK                2507
#define MACH_TYPE_QSD8X50_ST1          2508
#define MACH_TYPE_AT91SAM9M10EKES      2509
#define MACH_TYPE_HIRAM                2510
#define MACH_TYPE_PHY3250              2511
#define MACH_TYPE_EA3250               2512
#define MACH_TYPE_FDI3250              2513
#define MACH_TYPE_AT91SAM9263NIT       2515
#define MACH_TYPE_CCMX51               2516
#define MACH_TYPE_CCMX51JS             2517
#define MACH_TYPE_CCWMX51              2518
#define MACH_TYPE_CCWMX51JS            2519
#define MACH_TYPE_MINI6410             2520
#define MACH_TYPE_TINY6410             2521
#define MACH_TYPE_NANO6410             2522
#define MACH_TYPE_AT572D940HFNLDB      2523
#define MACH_TYPE_HTCLEO               2524
#define MACH_TYPE_AVP13                2525
#define MACH_TYPE_XXSVIDEOD            2526
#define MACH_TYPE_VPNEXT               2527
#define MACH_TYPE_SWARCO_ITC3          2528
#define MACH_TYPE_TX51                 2529
#define MACH_TYPE_DOLBY_CAT1021        2530
#define MACH_TYPE_MX28EVK              2531
#define MACH_TYPE_PHOENIX260           2532
#define MACH_TYPE_UVACA_STORK          2533
#define MACH_TYPE_SMARTQ5              2534
#define MACH_TYPE_ALL3078              2535
#define MACH_TYPE_CTERA_2BAY_DS        2536
#define MACH_TYPE_SIOGENTOO3           2537
#define MACH_TYPE_EPB5000              2538
#define MACH_TYPE_HY9263               2539
#define MACH_TYPE_ACER_TEMPO_M900      2540
#define MACH_TYPE_ACER_TEMPO_DX900     2541
#define MACH_TYPE_ACER_TEMPO_X960      2542
#define MACH_TYPE_ACER_ETEN_V900       2543
#define MACH_TYPE_ACER_ETEN_X900       2544
#define MACH_TYPE_BONNELL              2545
#define MACH_TYPE_OHT_MX27             2546
#define MACH_TYPE_HTCQUARTZ            2547
#define MACH_TYPE_DAVINCI_DM6467TEVM   2548
#define MACH_TYPE_C3AX03               2549
#define MACH_TYPE_MXT_TD60             2550
#define MACH_TYPE_ESYX                 2551
#define MACH_TYPE_DOVE_DB2             2552
#define MACH_TYPE_BULLDOG              2553
#define MACH_TYPE_DERELL_ME2000        2554
#define MACH_TYPE_BCMRING_BASE         2555
#define MACH_TYPE_BCMRING_EVM          2556
#define MACH_TYPE_BCMRING_EVM_JAZZ     2557
#define MACH_TYPE_BCMRING_SP           2558
#define MACH_TYPE_BCMRING_SV           2559
#define MACH_TYPE_BCMRING_SV_JAZZ      2560
#define MACH_TYPE_BCMRING_TABLET       2561
#define MACH_TYPE_BCMRING_VP           2562
#define MACH_TYPE_BCMRING_EVM_SEIKOR   2563
#define MACH_TYPE_BCMRING_SP_WQVGA     2564
#define MACH_TYPE_BCMRING_CUSTOM       2565
#define MACH_TYPE_ACER_S200            2566
#define MACH_TYPE_BT270                2567
#define MACH_TYPE_ISEO                 2568
#define MACH_TYPE_CEZANNE              2569
#define MACH_TYPE_LUCCA                2570
#define MACH_TYPE_SUPERSMART           2571
#define MACH_TYPE_CS_MISANO            2572
#define MACH_TYPE_MAGNOLIA2            2573
#define MACH_TYPE_EMXX                 2574
#define MACH_TYPE_OUTLAW               2575
#define MACH_TYPE_RIOT_BEI2            2576
#define MACH_TYPE_RIOT_VOX             2577
#define MACH_TYPE_RIOT_X37             2578
#define MACH_TYPE_MEGA25MX             2579
#define MACH_TYPE_BENZINA2             2580
#define MACH_TYPE_IGNITE               2581
#define MACH_TYPE_FOGGIA               2582
#define MACH_TYPE_AREZZO               2583
#define MACH_TYPE_LEICA_SKYWALKER      2584
#define MACH_TYPE_JACINTO2_JAMR        2585
#define MACH_TYPE_GTS_NOVA             2586
#define MACH_TYPE_P3600                2587
#define MACH_TYPE_DLT2                 2588
#define MACH_TYPE_DF3120               2589
#define MACH_TYPE_ECUCORE_9G20         2590
#define MACH_TYPE_NAUTEL_LPC3240       2591
#define MACH_TYPE_GLACIER              2592
#define MACH_TYPE_PHRAZER_BULLDOG      2593
#define MACH_TYPE_OMAP3_BULLDOG        2594
#define MACH_TYPE_PCA101               2595
#define MACH_TYPE_BUZZC                2596
#define MACH_TYPE_SASIE2               2597
#define MACH_TYPE_SMARTMETER_DL        2599
#define MACH_TYPE_WZL6410              2600
#define MACH_TYPE_WZL6410M             2601
#define MACH_TYPE_WZL6410F             2602
#define MACH_TYPE_WZL6410I             2603
#define MACH_TYPE_SPACECOM1            2604
#define MACH_TYPE_PINGU920             2605
#define MACH_TYPE_BRAVOC               2606
#define MACH_TYPE_VDSSW                2608
#define MACH_TYPE_ROMULUS              2609
#define MACH_TYPE_OMAP_MAGIC           2610
#define MACH_TYPE_ELTD100              2611
#define MACH_TYPE_CAPC7117             2612
#define MACH_TYPE_SWAN                 2613
#define MACH_TYPE_VEU                  2614
#define MACH_TYPE_RM2                  2615
#define MACH_TYPE_TT2100               2616
#define MACH_TYPE_VENICE               2617
#define MACH_TYPE_PC7323               2618
#define MACH_TYPE_MASP                 2619
#define MACH_TYPE_FUJITSU_TVSTBSOC     2620
#define MACH_TYPE_FUJITSU_TVSTBSOC1    2621
#define MACH_TYPE_LEXIKON              2622
#define MACH_TYPE_MINI2440V2           2623
#define MACH_TYPE_ICONTROL             2624
#define MACH_TYPE_GPLUGD               2625
#define MACH_TYPE_QSD8X50A_ST1_1       2626
#define MACH_TYPE_QSD8X50A_ST1_5       2627
#define MACH_TYPE_BEE                  2628
#define MACH_TYPE_MX23EVK              2629
#define MACH_TYPE_AP4EVB               2630
#define MACH_TYPE_STOCKHOLM            2631
#define MACH_TYPE_LPC_H3131            2632
#define MACH_TYPE_STINGRAY             2633
#define MACH_TYPE_KRAKEN               2634
#define MACH_TYPE_GW2388               2635
#define MACH_TYPE_JADECPU              2636
#define MACH_TYPE_CARLISLE             2637
#define MACH_TYPE_LUX_SF9              2638
#define MACH_TYPE_NEMID_TB             2639
#define MACH_TYPE_TERRIER              2640
#define MACH_TYPE_TURBOT               2641
#define MACH_TYPE_SANDDAB              2642
#define MACH_TYPE_MX35_CICADA          2643
#define MACH_TYPE_GHI2703D             2644
#define MACH_TYPE_LUX_SFX9             2645
#define MACH_TYPE_LUX_SF9G             2646
#define MACH_TYPE_LUX_EDK9             2647
#define MACH_TYPE_HW90240              2648
#define MACH_TYPE_DM365_LEOPARD        2649
#define MACH_TYPE_MITYOMAPL138         2650
#define MACH_TYPE_SCAT110              2651
#define MACH_TYPE_ACER_A1              2652
#define MACH_TYPE_CMCONTROL            2653
#define MACH_TYPE_PELCO_LAMAR          2654
#define MACH_TYPE_RFP43                2655
#define MACH_TYPE_SK86R0301            2656
#define MACH_TYPE_CTPXA                2657
#define MACH_TYPE_EPB_ARM9_A           2658
#define MACH_TYPE_GURUPLUG             2659
#define MACH_TYPE_SPEAR310             2660
#define MACH_TYPE_SPEAR320             2661
#define MACH_TYPE_ROBOTX               2662
#define MACH_TYPE_LSXHL                2663
#define MACH_TYPE_SMARTLITE            2664
#define MACH_TYPE_CWS2                 2665
#define MACH_TYPE_M619                 2666
#define MACH_TYPE_SMARTVIEW            2667
#define MACH_TYPE_LSA_SALSA            2668
#define MACH_TYPE_KIZBOX               2669
#define MACH_TYPE_HTCCHARMER           2670
#define MACH_TYPE_GUF_NESO_LT          2671
#define MACH_TYPE_PM9G45               2672
#define MACH_TYPE_HTCPANTHER           2673
#define MACH_TYPE_HTCPANTHER_CDMA      2674
#define MACH_TYPE_REB01                2675
#define MACH_TYPE_AQUILA               2676
#define MACH_TYPE_SPARK_SLS_HW2        2677
#define MACH_TYPE_ESATA_SHEEVAPLUG     2678
#define MACH_TYPE_MSM7X30_SURF         2679
#define MACH_TYPE_MICRO2440            2680
#define MACH_TYPE_AM2440               2681
#define MACH_TYPE_TQ2440               2682
#define MACH_TYPE_EA2478DEVKIT         2683
#define MACH_TYPE_AK880X               2684
#define MACH_TYPE_COBRA3530            2685
#define MACH_TYPE_PMPPB                2686
#define MACH_TYPE_U6715                2687
#define MACH_TYPE_AXAR1500_SENDER      2688
#define MACH_TYPE_G30_DVB              2689
#define MACH_TYPE_VC088X               2690
#define MACH_TYPE_MIOA702              2691
#define MACH_TYPE_HPMIN                2692
#define MACH_TYPE_AK880XAK             2693
#define MACH_TYPE_ARM926TOMAP850       2694
#define MACH_TYPE_LKEVM                2695
#define MACH_TYPE_MW6410               2696
#define MACH_TYPE_TERASTATION_WXL      2697
#define MACH_TYPE_CPU8000E             2698
#define MACH_TYPE_TOKYO                2700
#define MACH_TYPE_MSM7201A_SURF        2701
#define MACH_TYPE_MSM7201A_FFA         2702
#define MACH_TYPE_MSM7X25_SURF         2703
#define MACH_TYPE_MSM7X25_FFA          2704
#define MACH_TYPE_MSM7X27_SURF         2705
#define MACH_TYPE_MSM7X27_FFA          2706
#define MACH_TYPE_MSM7X30_FFA          2707
#define MACH_TYPE_QSD8X50_SURF         2708
#define MACH_TYPE_QSD8X50_COMET        2709
#define MACH_TYPE_QSD8X50_FFA          2710
#define MACH_TYPE_QSD8X50A_SURF        2711
#define MACH_TYPE_QSD8X50A_FFA         2712
#define MACH_TYPE_ADX_XGCP10           2713
#define MACH_TYPE_MCGWUMTS2A           2714
#define MACH_TYPE_MOBIKT               2715
#define MACH_TYPE_MX53_EVK             2716
#define MACH_TYPE_IGEP0030             2717
#define MACH_TYPE_AXELL_H40_H50_CTRL   2718
#define MACH_TYPE_DTCOMMOD             2719
#define MACH_TYPE_GOULD                2720
#define MACH_TYPE_SIBERIA              2721
#define MACH_TYPE_SBC3530              2722
#define MACH_TYPE_QARM                 2723
#define MACH_TYPE_MIPS                 2724
#define MACH_TYPE_MX27GRB              2725
#define MACH_TYPE_SBC8100              2726
#define MACH_TYPE_SAARB                2727
#define MACH_TYPE_OMAP3MINI            2728
#define MACH_TYPE_CNMBOOK7SE           2729
#define MACH_TYPE_CATAN                2730
#define MACH_TYPE_HARMONY              2731
#define MACH_TYPE_TONGA                2732
#define MACH_TYPE_CYBOOK_ORIZON        2733
#define MACH_TYPE_HTCRHODIUMCDMA       2734
#define MACH_TYPE_EPC_G45              2735
#define MACH_TYPE_EPC_LPC3250          2736
#define MACH_TYPE_MXC91341EVB          2737
#define MACH_TYPE_RTW1000              2738
#define MACH_TYPE_BOBCAT               2739
#define MACH_TYPE_TRIZEPS6             2740
#define MACH_TYPE_MSM7X30_FLUID        2741
#define MACH_TYPE_NEDAP9263            2742
#define MACH_TYPE_NETGEAR_MS2110       2743
#define MACH_TYPE_BMX                  2744
#define MACH_TYPE_NETSTREAM            2745
#define MACH_TYPE_VPNEXT_RCU           2746
#define MACH_TYPE_VPNEXT_MPU           2747
#define MACH_TYPE_BCMRING_TABLET_V1    2748
#define MACH_TYPE_SGARM10              2749
#define MACH_TYPE_OMAP3_CPS            2751
#define MACH_TYPE_AXAR1500_RECEIVER    2752
#define MACH_TYPE_WBD222               2753
#define MACH_TYPE_MT65XX               2754
#define MACH_TYPE_MSM8X60_SURF         2755
#define MACH_TYPE_MSM8X60_SIM          2756
#define MACH_TYPE_TCC8000_SDK          2758
#define MACH_TYPE_NANOS                2759
#define MACH_TYPE_STAMP9G10            2760
#define MACH_TYPE_STAMP9G45            2761
#define MACH_TYPE_H6053                2762
#define MACH_TYPE_SMINT01              2763
#define MACH_TYPE_PRTLVT2              2764
#define MACH_TYPE_AP420                2765
#define MACH_TYPE_DAVINCI_DM365_FC     2767
#define MACH_TYPE_MSM8X55_SURF         2768
#define MACH_TYPE_MSM8X55_FFA          2769
#define MACH_TYPE_ESL_VAMANA           2770
#define MACH_TYPE_SBC35                2771
#define MACH_TYPE_MPX6446              2772
#define MACH_TYPE_OREO_CONTROLLER      2773
#define MACH_TYPE_KOPIN_MODELS         2774
#define MACH_TYPE_TTC_VISION2          2775
#define MACH_TYPE_CNS3420VB            2776
#define MACH_TYPE_LPC2                 2777
#define MACH_TYPE_OLYMPUS              2778
#define MACH_TYPE_VORTEX               2779
#define MACH_TYPE_S5PC200              2780
#define MACH_TYPE_ECUCORE_9263         2781
#define MACH_TYPE_SMDKC200             2782
#define MACH_TYPE_EMSISO_SX27          2783
#define MACH_TYPE_APX_SOM9G45_EK       2784
#define MACH_TYPE_SONGSHAN             2785
#define MACH_TYPE_TIANSHAN             2786
#define MACH_TYPE_VPX500               2787
#define MACH_TYPE_AM3517SAM            2788
#define MACH_TYPE_SKAT91_SIM508        2789
#define MACH_TYPE_SKAT91_S3E           2790
#define MACH_TYPE_OMAP4_PANDA          2791
#define MACH_TYPE_DF7220               2792
#define MACH_TYPE_NEMINI               2793
#define MACH_TYPE_T8200                2794
#define MACH_TYPE_APF51                2795
#define MACH_TYPE_DR_RC_UNIT           2796
#define MACH_TYPE_BORDEAUX             2797
#define MACH_TYPE_CATANIA_B            2798
#define MACH_TYPE_MX51_OCEAN           2799
#define MACH_TYPE_TI8168EVM            2800
#define MACH_TYPE_NEOCOREOMAP          2801
#define MACH_TYPE_WITHINGS_WBP         2802
#define MACH_TYPE_DBPS                 2803
#define MACH_TYPE_PCBFP0001            2805
#define MACH_TYPE_SPEEDY               2806
#define MACH_TYPE_CHRYSAOR             2807
#define MACH_TYPE_TANGO                2808
#define MACH_TYPE_SYNOLOGY_DSX11       2809
#define MACH_TYPE_HANLIN_V3EXT         2810
#define MACH_TYPE_HANLIN_V5            2811
#define MACH_TYPE_HANLIN_V3PLUS        2812
#define MACH_TYPE_IRIVER_STORY         2813
#define MACH_TYPE_IREX_ILIAD           2814
#define MACH_TYPE_IREX_DR1000          2815
#define MACH_TYPE_TETON_BGA            2816
#define MACH_TYPE_SNAPPER9G45          2817
#define MACH_TYPE_TAM3517              2818
#define MACH_TYPE_PDC100               2819
#define MACH_TYPE_EUKREA_CPUIMX25SD    2820
#define MACH_TYPE_EUKREA_CPUIMX35SD    2821
#define MACH_TYPE_EUKREA_CPUIMX51SD    2822
#define MACH_TYPE_EUKREA_CPUIMX51      2823
#define MACH_TYPE_P565                 2824
#define MACH_TYPE_ACER_A4              2825
#define MACH_TYPE_DAVINCI_DM368_BIP    2826
#define MACH_TYPE_ESHARE               2827
#define MACH_TYPE_WLBARGN              2829
#define MACH_TYPE_BM170                2830
#define MACH_TYPE_NETSPACE_MINI_V2     2831
#define MACH_TYPE_NETSPACE_PLUG_V2     2832
#define MACH_TYPE_SIEMENS_L1           2833
#define MACH_TYPE_ELV_LCU1             2834
#define MACH_TYPE_MCU1                 2835
#define MACH_TYPE_OMAP3_TAO3530        2836
#define MACH_TYPE_OMAP3_PCUTOUCH       2837
#define MACH_TYPE_SMDKC210             2838
#define MACH_TYPE_OMAP3_BRAILLO        2839
#define MACH_TYPE_SPYPLUG              2840
#define MACH_TYPE_GINGER               2841
#define MACH_TYPE_TNY_T3530            2842
#define MACH_TYPE_PCAAL1               2843
#define MACH_TYPE_SPADE                2844
#define MACH_TYPE_MXC25_TOPAZ          2845
#define MACH_TYPE_T5325                2846
#define MACH_TYPE_GW2361               2847
#define MACH_TYPE_ELOG                 2848
#define MACH_TYPE_INCOME               2849
#define MACH_TYPE_BCM589X              2850
#define MACH_TYPE_ETNA                 2851
#define MACH_TYPE_HAWKS                2852
#define MACH_TYPE_MESON                2853
#define MACH_TYPE_XSBASE255            2854
#define MACH_TYPE_PVM2030              2855
#define MACH_TYPE_MIOA502              2856
#define MACH_TYPE_VVBOX_SDORIG2        2857
#define MACH_TYPE_VVBOX_SDLITE2        2858
#define MACH_TYPE_VVBOX_SDPRO4         2859
#define MACH_TYPE_HTC_SPV_M700         2860
#define MACH_TYPE_MX257SX              2861
#define MACH_TYPE_GONI                 2862
#define MACH_TYPE_MSM8X55_SVLTE_FFA    2863
#define MACH_TYPE_MSM8X55_SVLTE_SURF   2864
#define MACH_TYPE_QUICKSTEP            2865
#define MACH_TYPE_DMW96                2866
#define MACH_TYPE_HAMMERHEAD           2867
#define MACH_TYPE_TRIDENT              2868
#define MACH_TYPE_LIGHTNING            2869
#define MACH_TYPE_ICONNECT             2870
#define MACH_TYPE_AUTOBOT              2871
#define MACH_TYPE_COCONUT              2872
#define MACH_TYPE_DURIAN               2873
#define MACH_TYPE_CAYENNE              2874
#define MACH_TYPE_FUJI                 2875
#define MACH_TYPE_SYNOLOGY_6282        2876
#define MACH_TYPE_EM1SY                2877
#define MACH_TYPE_M502                 2878
#define MACH_TYPE_MATRIX518            2879
#define MACH_TYPE_TINY_GURNARD         2880
#define MACH_TYPE_SPEAR1310            2881
#define MACH_TYPE_BV07                 2882
#define MACH_TYPE_MXT_TD61             2883
#define MACH_TYPE_OPENRD_ULTIMATE      2884
#define MACH_TYPE_DEVIXP               2885
#define MACH_TYPE_MICCPT               2886
#define MACH_TYPE_MIC256               2887
#define MACH_TYPE_AS1167               2888
#define MACH_TYPE_OMAP3_IBIZA          2889
#define MACH_TYPE_U5500                2890
#define MACH_TYPE_DAVINCI_PICTO        2891
#define MACH_TYPE_MECHA                2892
#define MACH_TYPE_BUBBA3               2893
#define MACH_TYPE_PUPITRE              2894
#define MACH_TYPE_TEGRA_VOGUE          2896
#define MACH_TYPE_TEGRA_E1165          2897
#define MACH_TYPE_SIMPLENET            2898
#define MACH_TYPE_EC4350TBM            2899
#define MACH_TYPE_PEC_TC               2900
#define MACH_TYPE_PEC_HC2              2901
#define MACH_TYPE_ESL_MOBILIS_A        2902
#define MACH_TYPE_ESL_MOBILIS_B        2903
#define MACH_TYPE_ESL_WAVE_A           2904
#define MACH_TYPE_ESL_WAVE_B           2905
#define MACH_TYPE_UNISENSE_MMM         2906
#define MACH_TYPE_BLUESHARK            2907
#define MACH_TYPE_E10                  2908
#define MACH_TYPE_APP3K_ROBIN          2909
#define MACH_TYPE_POV15HD              2910
#define MACH_TYPE_STELLA               2911
#define MACH_TYPE_LINKSTATION_LSCHL    2913
#define MACH_TYPE_NETWALKER            2914
#define MACH_TYPE_ACSX106              2915
#define MACH_TYPE_ATLAS5_C1            2916
#define MACH_TYPE_NSB3AST              2917
#define MACH_TYPE_GNET_SLC             2918
#define MACH_TYPE_AF4000               2919
#define MACH_TYPE_ARK9431              2920
#define MACH_TYPE_FS_S5PC100           2921
#define MACH_TYPE_OMAP3505NOVA8        2922
#define MACH_TYPE_OMAP3621_EDP1        2923
#define MACH_TYPE_ORATISAES            2924
#define MACH_TYPE_SMDKV310             2925
#define MACH_TYPE_SIEMENS_L0           2926
#define MACH_TYPE_VENTANA              2927
#define MACH_TYPE_WM8505_7IN_NETBOOK   2928
#define MACH_TYPE_EC4350SDB            2929
#define MACH_TYPE_MIMAS                2930
#define MACH_TYPE_TITAN                2931
#define MACH_TYPE_CRANEBOARD           2932
#define MACH_TYPE_ES2440               2933
#define MACH_TYPE_NAJAY_A9263          2934
#define MACH_TYPE_HTCTORNADO           2935
#define MACH_TYPE_DIMM_MX257           2936
#define MACH_TYPE_JIGEN                2937
#define MACH_TYPE_SMDK6450             2938
#define MACH_TYPE_MENO_QNG             2939
#define MACH_TYPE_NS2416               2940
#define MACH_TYPE_RPC353               2941
#define MACH_TYPE_TQ6410               2942
#define MACH_TYPE_SKY6410              2943
#define MACH_TYPE_DYNASTY              2944
#define MACH_TYPE_VIVO                 2945
#define MACH_TYPE_BURY_BL7582          2946
#define MACH_TYPE_BURY_BPS5270         2947
#define MACH_TYPE_BASI                 2948
#define MACH_TYPE_TN200                2949
#define MACH_TYPE_C2MMI                2950
#define MACH_TYPE_MESON_6236M          2951
#define MACH_TYPE_MESON_8626M          2952
#define MACH_TYPE_TUBE                 2953
#define MACH_TYPE_MESSINA              2954
#define MACH_TYPE_MX50_ARM2            2955
#define MACH_TYPE_CETUS9263            2956
#define MACH_TYPE_BROWNSTONE           2957
#define MACH_TYPE_VMX25                2958
#define MACH_TYPE_VMX51                2959
#define MACH_TYPE_ABACUS               2960
#define MACH_TYPE_CM4745               2961
#define MACH_TYPE_ORATISLINK           2962
#define MACH_TYPE_DAVINCI_DM365_DVR    2963
#define MACH_TYPE_NETVIZ               2964
#define MACH_TYPE_FLEXIBITY            2965
#define MACH_TYPE_WLAN_COMPUTER        2966
#define MACH_TYPE_LPC24XX              2967
#define MACH_TYPE_SPICA                2968
#define MACH_TYPE_GPSDISPLAY           2969
#define MACH_TYPE_BIPNET               2970
#define MACH_TYPE_OVERO_CTU_INERTIAL   2971
#define MACH_TYPE_DAVINCI_DM355_MMM    2972
#define MACH_TYPE_PC9260_V2            2973
#define MACH_TYPE_PTX7545              2974
#define MACH_TYPE_TM_EFDC              2975
#define MACH_TYPE_OMAP3_WALDO1         2977
#define MACH_TYPE_FLYER                2978
#define MACH_TYPE_TORNADO3240          2979
#define MACH_TYPE_SOLI_01              2980
#define MACH_TYPE_OMAPL138_EUROPALC    2981
#define MACH_TYPE_HELIOS_V1            2982
#define MACH_TYPE_NETSPACE_LITE_V2     2983
#define MACH_TYPE_SSC                  2984
#define MACH_TYPE_PREMIERWAVE_EN       2985
#define MACH_TYPE_WASABI               2986
#define MACH_TYPE_MX50_RDP             2988
#define MACH_TYPE_UNIVERSAL_C210       2989
#define MACH_TYPE_REAL6410             2990
#define MACH_TYPE_SPX_SAKURA           2991
#define MACH_TYPE_IJ3K_2440            2992
#define MACH_TYPE_OMAP3_BC10           2993
#define MACH_TYPE_THEBE                2994
#define MACH_TYPE_RV082                2995
#define MACH_TYPE_ARMLGUEST            2996
#define MACH_TYPE_TJINC1000            2997
#define MACH_TYPE_DOCKSTAR             2998
#define MACH_TYPE_AX8008               2999
#define MACH_TYPE_GNET_SGCE            3000
#define MACH_TYPE_PXWNAS_500_1000      3001
#define MACH_TYPE_AWM2                 3003
#define MACH_TYPE_TI8148EVM            3004
#define MACH_TYPE_SEABOARD             3005
#define MACH_TYPE_LINKSTATION_CHLV2    3006
#define MACH_TYPE_TERA_PRO2_RACK       3007
#define MACH_TYPE_RUBYS                3008
#define MACH_TYPE_AQUARIUS             3009
#define MACH_TYPE_MX53_ARD             3010
#define MACH_TYPE_MX53_SMD             3011
#define MACH_TYPE_LSWXL                3012
#define MACH_TYPE_DOVE_AVNG_V3         3013
#define MACH_TYPE_SDI_ESS_9263         3014
#define MACH_TYPE_JOCPU550             3015
#define MACH_TYPE_MSM8X60_RUMI3        3016
#define MACH_TYPE_MSM8X60_FFA          3017
#define MACH_TYPE_YANOMAMI             3018
#define MACH_TYPE_GTA04                3019
#define MACH_TYPE_CM_A510              3020
#define MACH_TYPE_OMAP3_RFS200         3021
#define MACH_TYPE_KX33XX               3022
#define MACH_TYPE_PTX7510              3023
#define MACH_TYPE_TOP9000              3024
#define MACH_TYPE_TEENOTE              3025
#define MACH_TYPE_TS3                  3026
#define MACH_TYPE_A0                   3027
#define MACH_TYPE_FSM9XXX_SURF         3028
#define MACH_TYPE_FSM9XXX_FFA          3029
#define MACH_TYPE_FRRHWCDMA60W         3030
#define MACH_TYPE_REMUS                3031
#define MACH_TYPE_AT91CAP7XDK          3032
#define MACH_TYPE_AT91CAP7STK          3033
#define MACH_TYPE_KT_SBC_SAM9_1        3034
#define MACH_TYPE_ARMADA_XP_DB         3036
#define MACH_TYPE_SPDM                 3037
#define MACH_TYPE_GTIB                 3038
#define MACH_TYPE_DGM3240              3039
#define MACH_TYPE_ATLAS_I_LPE          3040
#define MACH_TYPE_HTCMEGA              3041
#define MACH_TYPE_TRICORDER            3042
#define MACH_TYPE_TX28                 3043
#define MACH_TYPE_BSTBRD               3044
#define MACH_TYPE_PWB3090              3045
#define MACH_TYPE_IDEA6410             3046
#define MACH_TYPE_QBC9263              3047
#define MACH_TYPE_BORABORA             3048
#define MACH_TYPE_VALDEZ               3049
#define MACH_TYPE_LS9G20               3050
#define MACH_TYPE_MIOS_V1              3051
#define MACH_TYPE_S5PC110_CRESPO       3052
#define MACH_TYPE_CONTROLTEK9G20       3053
#define MACH_TYPE_TIN307               3054
#define MACH_TYPE_TIN510               3055
#define MACH_TYPE_EP3517               3056
#define MACH_TYPE_BLUECHEESE           3057
#define MACH_TYPE_TEM3X30              3058
#define MACH_TYPE_HARVEST_DESOTO       3059
#define MACH_TYPE_MSM8X60_QRDC         3060
#define MACH_TYPE_SPEAR900             3061
#define MACH_TYPE_PCONTROL_G20         3062
#define MACH_TYPE_RDSTOR               3063
#define MACH_TYPE_USDLOADER            3064
#define MACH_TYPE_TSOPLOADER           3065
#define MACH_TYPE_KRONOS               3066
#define MACH_TYPE_FFCORE               3067
#define MACH_TYPE_MONE                 3068
#define MACH_TYPE_UNIT2S               3069
#define MACH_TYPE_ACER_A5              3070
#define MACH_TYPE_ETHERPRO_ISP         3071
#define MACH_TYPE_STRETCHS7000         3072
#define MACH_TYPE_P87_SMARTSIM         3073
#define MACH_TYPE_TULIP                3074
#define MACH_TYPE_SUNFLOWER            3075
#define MACH_TYPE_RIB                  3076
#define MACH_TYPE_CLOD                 3077
#define MACH_TYPE_RUMP                 3078
#define MACH_TYPE_TENDERLOIN           3079
#define MACH_TYPE_SHORTLOIN            3080
#define MACH_TYPE_ANTARES              3082
#define MACH_TYPE_WB40N                3083
#define MACH_TYPE_HERRING              3084
#define MACH_TYPE_NAXY400              3085
#define MACH_TYPE_NAXY1200             3086
#define MACH_TYPE_VPR200               3087
#define MACH_TYPE_BUG20                3088
#define MACH_TYPE_GOFLEXNET            3089
#define MACH_TYPE_TORBRECK             3090
#define MACH_TYPE_SAARB_MG1            3091
#define MACH_TYPE_CALLISTO             3092
#define MACH_TYPE_MULTHSU              3093
#define MACH_TYPE_SALUDA               3094
#define MACH_TYPE_PEMP_OMAP3_APOLLO    3095
#define MACH_TYPE_VC0718               3096
#define MACH_TYPE_MVBLX                3097
#define MACH_TYPE_INHAND_APEIRON       3098
#define MACH_TYPE_INHAND_FURY          3099
#define MACH_TYPE_INHAND_SIREN         3100
#define MACH_TYPE_HDNVP                3101
#define MACH_TYPE_SOFTWINNER           3102
#define MACH_TYPE_PRIMA2_EVB           3103
#define MACH_TYPE_NAS6210              3104
#define MACH_TYPE_UNISDEV              3105
#define MACH_TYPE_SBCA11               3106
#define MACH_TYPE_SAGA                 3107
#define MACH_TYPE_NS_K330              3108
#define MACH_TYPE_TANNA                3109
#define MACH_TYPE_IMATE8502            3110
#define MACH_TYPE_ASPEN                3111
#define MACH_TYPE_DAINTREE_CWAC        3112
#define MACH_TYPE_ZMX25                3113
#define MACH_TYPE_MAPLE1               3114
#define MACH_TYPE_QSD8X72_SURF         3115
#define MACH_TYPE_QSD8X72_FFA          3116
#define MACH_TYPE_ABILENE              3117
#define MACH_TYPE_EIGEN_TTR            3118
#define MACH_TYPE_IOMEGA_IX2_200       3119
#define MACH_TYPE_CORETEC_VCX7400      3120
#define MACH_TYPE_SANTIAGO             3121
#define MACH_TYPE_MX257SOL             3122
#define MACH_TYPE_STRASBOURG           3123
#define MACH_TYPE_MSM8X60_FLUID        3124
#define MACH_TYPE_SMARTQV5             3125
#define MACH_TYPE_SMARTQV3             3126
#define MACH_TYPE_SMARTQV7             3127
#define MACH_TYPE_PAZ00                3128
#define MACH_TYPE_ACMENETUSFOXG20      3129
#define MACH_TYPE_FWBD_0404            3131
#define MACH_TYPE_HDGU                 3132
#define MACH_TYPE_PYRAMID              3133
#define MACH_TYPE_EPIPHAN              3134
#define MACH_TYPE_OMAP_BENDER          3135
#define MACH_TYPE_GURNARD              3136
#define MACH_TYPE_GTL_IT5100           3137
#define MACH_TYPE_BCM2708              3138
#define MACH_TYPE_MX51_GGC             3139
#define MACH_TYPE_SHARESPACE           3140
#define MACH_TYPE_HABA_KNX_EXPLORER    3141
#define MACH_TYPE_SIMTEC_KIRKMOD       3142
#define MACH_TYPE_CRUX                 3143
#define MACH_TYPE_MX51_BRAVO           3144
#define MACH_TYPE_CHARON               3145
#define MACH_TYPE_PICOCOM3             3146
#define MACH_TYPE_PICOCOM4             3147
#define MACH_TYPE_SERRANO              3148
#define MACH_TYPE_DOUBLESHOT           3149
#define MACH_TYPE_EVSY                 3150
#define MACH_TYPE_HUASHAN              3151
#define MACH_TYPE_LAUSANNE             3152
#define MACH_TYPE_EMERALD              3153
#define MACH_TYPE_TQMA35               3154
#define MACH_TYPE_MARVEL               3155
#define MACH_TYPE_MANUAE               3156
#define MACH_TYPE_CHACHA               3157
#define MACH_TYPE_LEMON                3158
#define MACH_TYPE_CSC                  3159
#define MACH_TYPE_GIRA_KNXIP_ROUTER    3160
#define MACH_TYPE_T20                  3161
#define MACH_TYPE_HDMINI               3162
#define MACH_TYPE_SCIPHONE_G2          3163
#define MACH_TYPE_EXPRESS              3164
#define MACH_TYPE_EXPRESS_KT           3165
#define MACH_TYPE_MAXIMASP             3166
#define MACH_TYPE_NITROGEN_IMX51       3167
#define MACH_TYPE_NITROGEN_IMX53       3168
#define MACH_TYPE_SUNFIRE              3169
#define MACH_TYPE_AROWANA              3170
#define MACH_TYPE_TEGRA_DAYTONA        3171
#define MACH_TYPE_TEGRA_SWORDFISH      3172
#define MACH_TYPE_EDISON               3173
#define MACH_TYPE_SVP8500V1            3174
#define MACH_TYPE_SVP8500V2            3175
#define MACH_TYPE_SVP5500              3176
#define MACH_TYPE_B5500                3177
#define MACH_TYPE_S5500                3178
#define MACH_TYPE_ICON                 3179
#define MACH_TYPE_ELEPHANT             3180
#define MACH_TYPE_SHOOTER              3182
#define MACH_TYPE_SPADE_LTE            3183
#define MACH_TYPE_PHILHWANI            3184
#define MACH_TYPE_GSNCOMM              3185
#define MACH_TYPE_STRASBOURG_A2        3186
#define MACH_TYPE_MMM                  3187
#define MACH_TYPE_DAVINCI_DM365_BV     3188
#define MACH_TYPE_AG5EVM               3189
#define MACH_TYPE_SC575PLC             3190
#define MACH_TYPE_SC575IPC             3191
#define MACH_TYPE_OMAP3_TDM3730        3192
#define MACH_TYPE_TOP9000_EVAL         3194
#define MACH_TYPE_TOP9000_SU           3195
#define MACH_TYPE_UTM300               3196
#define MACH_TYPE_TSUNAGI              3197
#define MACH_TYPE_TS75XX               3198
#define MACH_TYPE_TS47XX               3200
#define MACH_TYPE_DA850_K5             3201
#define MACH_TYPE_AX502                3202
#define MACH_TYPE_IGEP0032             3203
#define MACH_TYPE_ANTERO               3204
#define MACH_TYPE_SYNERGY              3205
#define MACH_TYPE_ICS_IF_VOIP          3206
#define MACH_TYPE_WLF_CRAGG_6410       3207
#define MACH_TYPE_PUNICA               3208
#define MACH_TYPE_TRIMSLICE            3209
#define MACH_TYPE_MX27_WMULTRA         3210
#define MACH_TYPE_MACKEREL             3211
#define MACH_TYPE_FA9X27               3213
#define MACH_TYPE_NS2816TB             3214
#define MACH_TYPE_NS2816_NTPAD         3215
#define MACH_TYPE_NS2816_NTNB          3216
#define MACH_TYPE_KAEN                 3217
#define MACH_TYPE_NV1000               3218
#define MACH_TYPE_NUC950TS             3219
#define MACH_TYPE_NOKIA_RM680          3220
#define MACH_TYPE_AST2200              3221
#define MACH_TYPE_LEAD                 3222
#define MACH_TYPE_UNINO1               3223
#define MACH_TYPE_GREECO               3224
#define MACH_TYPE_VERDI                3225
#define MACH_TYPE_DM6446_ADBOX         3226
#define MACH_TYPE_QUAD_SALSA           3227
#define MACH_TYPE_ABB_GMA_1_1          3228
#define MACH_TYPE_SVCID                3229
#define MACH_TYPE_MSM8960_SIM          3230
#define MACH_TYPE_MSM8960_RUMI3        3231
#define MACH_TYPE_ICON_G               3232
#define MACH_TYPE_MB3                  3233
#define MACH_TYPE_GSIA18S              3234
#define MACH_TYPE_PIVICC               3235
#define MACH_TYPE_PCM048               3236
#define MACH_TYPE_DDS                  3237
#define MACH_TYPE_CHALTEN_XA1          3238
#define MACH_TYPE_TS48XX               3239
#define MACH_TYPE_TONGA2_TFTTIMER      3240
#define MACH_TYPE_WHISTLER             3241
#define MACH_TYPE_ASL_PHOENIX          3242
#define MACH_TYPE_AT91SAM9263OTLITE    3243
#define MACH_TYPE_DDPLUG               3244
#define MACH_TYPE_D2PLUG               3245
#define MACH_TYPE_KZM9D                3246
#define MACH_TYPE_VERDI_LTE            3247
#define MACH_TYPE_NANOZOOM             3248
#define MACH_TYPE_DM3730_SOM_LV        3249
#define MACH_TYPE_DM3730_TORPEDO       3250
#define MACH_TYPE_ANCHOVY              3251
#define MACH_TYPE_RE2REV20             3253
#define MACH_TYPE_RE2REV21             3254
#define MACH_TYPE_CNS21XX              3255
#define MACH_TYPE_RIDER                3257
#define MACH_TYPE_NSK330               3258
#define MACH_TYPE_CNS2133EVB           3259
#define MACH_TYPE_Z3_816X_MOD          3260
#define MACH_TYPE_Z3_814X_MOD          3261
#define MACH_TYPE_BEECT                3262
#define MACH_TYPE_DMA_THUNDERBUG       3263
#define MACH_TYPE_OMN_AT91SAM9G20      3264
#define MACH_TYPE_MX25_E2S_UC          3265
#define MACH_TYPE_MIONE                3266
#define MACH_TYPE_TOP9000_TCU          3267
#define MACH_TYPE_TOP9000_BSL          3268
#define MACH_TYPE_KINGDOM              3269
#define MACH_TYPE_ARMADILLO460         3270
#define MACH_TYPE_LQ2                  3271
#define MACH_TYPE_SWEDA_TMS2           3272
#define MACH_TYPE_MX53_LOCO            3273
#define MACH_TYPE_ACER_A8              3275
#define MACH_TYPE_ACER_GAUGUIN         3276
#define MACH_TYPE_GUPPY                3277
#define MACH_TYPE_MX61_ARD             3278
#define MACH_TYPE_TX53                 3279
#define MACH_TYPE_OMAPL138_CASE_A3     3280
#define MACH_TYPE_UEMD                 3281
#define MACH_TYPE_CCWMX51MUT           3282
#define MACH_TYPE_ROCKHOPPER           3283
#define MACH_TYPE_ENCORE               3284
#define MACH_TYPE_HKDKC100             3285
#define MACH_TYPE_TS42XX               3286
#define MACH_TYPE_AEBL                 3287
#define MACH_TYPE_WARIO                3288
#define MACH_TYPE_GFS_SPM              3289
#define MACH_TYPE_CM_T3730             3290
#define MACH_TYPE_ISC3                 3291
#define MACH_TYPE_RASCAL               3292
#define MACH_TYPE_HREFV60              3293
#define MACH_TYPE_TPT_2_0              3294
#define MACH_TYPE_PYRAMID_TD           3295
#define MACH_TYPE_SPLENDOR             3296
#define MACH_TYPE_GUF_PLANET           3297
#define MACH_TYPE_MSM8X60_QT           3298
#define MACH_TYPE_HTC_HD_MINI          3299
#define MACH_TYPE_ATHENE               3300
#define MACH_TYPE_DEEP_R_EK_1          3301
#define MACH_TYPE_VIVOW_CT             3302
#define MACH_TYPE_NERY_1000            3303
#define MACH_TYPE_RFL109145_SSRV       3304
#define MACH_TYPE_NMH                  3305
#define MACH_TYPE_WN802T               3306
#define MACH_TYPE_DRAGONET             3307
#define MACH_TYPE_GENEVA_B             3308
#define MACH_TYPE_AT91SAM9263DESK16L   3309
#define MACH_TYPE_BCMHANA_SV           3310
#define MACH_TYPE_BCMHANA_TABLET       3311
#define MACH_TYPE_KOI                  3312
#define MACH_TYPE_TS4800               3313
#define MACH_TYPE_TQMA9263             3314
#define MACH_TYPE_HOLIDAY              3315
#define MACH_TYPE_DMA6410              3316
#define MACH_TYPE_PCATS_OVERLAY        3317
#define MACH_TYPE_HWGW6410             3318
#define MACH_TYPE_SHENZHOU             3319
#define MACH_TYPE_CWME9210             3320
#define MACH_TYPE_CWME9210JS           3321
#define MACH_TYPE_PGS_SITARA           3322
#define MACH_TYPE_COLIBRI_TEGRA2       3323
#define MACH_TYPE_W21                  3324
#define MACH_TYPE_POLYSAT1             3325
#define MACH_TYPE_DATAWAY              3326
#define MACH_TYPE_COBRAL138            3327
#define MACH_TYPE_ROVERPCS8            3328
#define MACH_TYPE_MARVELC              3329
#define MACH_TYPE_NAVEFIHID            3330
#define MACH_TYPE_DM365_CV100          3331
#define MACH_TYPE_ABLE                 3332
#define MACH_TYPE_LEGACY               3333
#define MACH_TYPE_ICONG                3334
#define MACH_TYPE_ROVER_G8             3335
#define MACH_TYPE_T5388P               3336
#define MACH_TYPE_DINGO                3337
#define MACH_TYPE_GOFLEXHOME           3338
#define MACH_TYPE_LANREADYFN511        3340
#define MACH_TYPE_OMAP3_BAIA           3341
#define MACH_TYPE_OMAP3SMARTDISPLAY    3342
#define MACH_TYPE_XILINX               3343
#define MACH_TYPE_A2F                  3344
#define MACH_TYPE_SKY25                3345
#define MACH_TYPE_CCMX53               3346
#define MACH_TYPE_CCMX53JS             3347
#define MACH_TYPE_CCWMX53              3348
#define MACH_TYPE_CCWMX53JS            3349
#define MACH_TYPE_FRISMS               3350
#define MACH_TYPE_MSM7X27A_FFA         3351
#define MACH_TYPE_MSM7X27A_SURF        3352
#define MACH_TYPE_MSM7X27A_RUMI3       3353
#define MACH_TYPE_DIMMSAM9G20          3354
#define MACH_TYPE_DIMM_IMX28           3355
#define MACH_TYPE_AMK_A4               3356
#define MACH_TYPE_GNET_SGME            3357
#define MACH_TYPE_SHOOTER_U            3358
#define MACH_TYPE_VMX53                3359
#define MACH_TYPE_RHINO                3360
#define MACH_TYPE_ARMLEX4210           3361
#define MACH_TYPE_SWARCOEXTMODEM       3362
#define MACH_TYPE_SNOWBALL             3363
#define MACH_TYPE_PCM049               3364
#define MACH_TYPE_VIGOR                3365
#define MACH_TYPE_OSLO_AMUNDSEN        3366
#define MACH_TYPE_GSL_DIAMOND          3367
#define MACH_TYPE_CV2201               3368
#define MACH_TYPE_CV2202               3369
#define MACH_TYPE_CV2203               3370
#define MACH_TYPE_VIT_IBOX             3371
#define MACH_TYPE_DM6441_ESP           3372
#define MACH_TYPE_AT91SAM9X5EK         3373
#define MACH_TYPE_LIBRA                3374
#define MACH_TYPE_EASYCRRH             3375
#define MACH_TYPE_TRIPEL               3376
#define MACH_TYPE_ENDIAN_MINI          3377
#define MACH_TYPE_XILINX_EP107         3378
#define MACH_TYPE_NURI                 3379
#define MACH_TYPE_JANUS                3380
#define MACH_TYPE_DDNAS                3381
#define MACH_TYPE_TAG                  3382
#define MACH_TYPE_TAGW                 3383
#define MACH_TYPE_NITROGEN_VM_IMX51    3384
#define MACH_TYPE_VIPRINET             3385
#define MACH_TYPE_BOCKW                3386
#define MACH_TYPE_EVA2000              3387
#define MACH_TYPE_STEELYARD            3388
#define MACH_TYPE_LPC2468OEM           3389
#define MACH_TYPE_MACH_SDH001          3390
#define MACH_TYPE_LPC2478MICROBLOX     3391
#define MACH_TYPE_NSSLSBOARD           3392
#define MACH_TYPE_GENEVA_B5            3393
#define MACH_TYPE_SPEAR1340            3394
#define MACH_TYPE_REXMAS               3395
#define MACH_TYPE_MSM8960_CDP          3396
#define MACH_TYPE_MSM8960_MDP          3397
#define MACH_TYPE_MSM8960_FLUID        3398
#define MACH_TYPE_MSM8960_APQ          3399
#define MACH_TYPE_HELIOS_V2            3400
#define MACH_TYPE_MIF10P               3401
#define MACH_TYPE_IAM28                3402
#define MACH_TYPE_PICASSO              3403
#define MACH_TYPE_MR301A               3404
#define MACH_TYPE_NOTLE                3405
#define MACH_TYPE_EELX2                3406
#define MACH_TYPE_MOON                 3407
#define MACH_TYPE_RUBY                 3408
#define MACH_TYPE_GOLDENGATE           3409
#define MACH_TYPE_CTBU_GEN2            3410
#define MACH_TYPE_KMP_AM17_01          3411
#define MACH_TYPE_WTPLUG               3412
#define MACH_TYPE_MX27SU2              3413
#define MACH_TYPE_NB31                 3414
#define MACH_TYPE_HJSDU                3415
#define MACH_TYPE_TD3_REV1             3416
#define MACH_TYPE_EAG_CI4000           3417
#define MACH_TYPE_NET5BIG_NAND_V2      3418
#define MACH_TYPE_CPX2                 3419
#define MACH_TYPE_NET2BIG_NAND_V2      3420
#define MACH_TYPE_ECUV5                3421
#define MACH_TYPE_HSGX6D               3422
#define MACH_TYPE_DAWAD7               3423
#define MACH_TYPE_SAM9REPEATER         3424
#define MACH_TYPE_GT_I5700             3425
#define MACH_TYPE_CTERA_PLUG_C2        3426
#define MACH_TYPE_MARVELCT             3427
#define MACH_TYPE_AG11005              3428
#define MACH_TYPE_OMAP_BLAZE           3429
#define MACH_TYPE_VANGOGH              3430
#define MACH_TYPE_MATRIX505            3431
#define MACH_TYPE_OCE_NIGMA            3432
#define MACH_TYPE_T55                  3433
#define MACH_TYPE_BIO3K                3434
#define MACH_TYPE_EXPRESSCT            3435
#define MACH_TYPE_CARDHU               3436
#define MACH_TYPE_ARUBA                3437
#define MACH_TYPE_BONAIRE              3438
#define MACH_TYPE_NUC700EVB            3439
#define MACH_TYPE_NUC710EVB            3440
#define MACH_TYPE_NUC740EVB            3441
#define MACH_TYPE_NUC745EVB            3442
#define MACH_TYPE_TRANSCEDE            3443
#define MACH_TYPE_MORA                 3444
#define MACH_TYPE_NDA_EVM              3445
#define MACH_TYPE_TIMU                 3446
#define MACH_TYPE_EXPRESSH             3447
#define MACH_TYPE_VERIDIS_A300         3448
#define MACH_TYPE_DM368_LEOPARD        3449
#define MACH_TYPE_OMAP_MCOP            3450
#define MACH_TYPE_TRITIP               3451
#define MACH_TYPE_SM1K                 3452
#define MACH_TYPE_MONCH                3453
#define MACH_TYPE_CURACAO              3454
#define MACH_TYPE_ORIGEN               3455
#define MACH_TYPE_EPC10                3456
#define MACH_TYPE_SGH_I740             3457
#define MACH_TYPE_TUNA                 3458
#define MACH_TYPE_MX51_TULIP           3459
#define MACH_TYPE_MX51_ASTER7          3460
#define MACH_TYPE_ACRO37XBRD           3461
#define MACH_TYPE_ELKE                 3462
#define MACH_TYPE_SBC6000X             3463
#define MACH_TYPE_R1801E               3464
#define MACH_TYPE_H1600                3465
#define MACH_TYPE_MINI210              3466
#define MACH_TYPE_MINI8168             3467
#define MACH_TYPE_PC7308               3468
#define MACH_TYPE_GE863                3469
#define MACH_TYPE_KMM2M01              3470
#define MACH_TYPE_MX51EREBUS           3471
#define MACH_TYPE_WM8650REFBOARD       3472
#define MACH_TYPE_TUXRAIL              3473
#define MACH_TYPE_ARTHUR               3474
#define MACH_TYPE_DOORBOY              3475
#define MACH_TYPE_XARINA               3476
#define MACH_TYPE_ROVERX7              3477
#define MACH_TYPE_SDVR                 3478
#define MACH_TYPE_ACER_MAYA            3479
#define MACH_TYPE_PICO                 3480
#define MACH_TYPE_CWMX233              3481
#define MACH_TYPE_CWAM1808             3482
#define MACH_TYPE_CWDM365              3483
#define MACH_TYPE_MX51_MORAY           3484
#define MACH_TYPE_THALES_CBC           3485
#define MACH_TYPE_BLUEPOINT            3486
#define MACH_TYPE_DIR665               3487
#define MACH_TYPE_ACMEROVER1           3488
#define MACH_TYPE_SHOOTER_CT           3489
#define MACH_TYPE_BLISS                3490
#define MACH_TYPE_BLISSC               3491
#define MACH_TYPE_THALES_ADC           3492
#define MACH_TYPE_UBISYS_P9D_EVP       3493
#define MACH_TYPE_ATDGP318             3494
#define MACH_TYPE_DMA210U              3495
#define MACH_TYPE_EM_T3                3496
#define MACH_TYPE_HTX3250              3497
#define MACH_TYPE_G50                  3498
#define MACH_TYPE_ECO5                 3499
#define MACH_TYPE_WINTERGRASP          3500
#define MACH_TYPE_PURO                 3501
#define MACH_TYPE_SHOOTER_K            3502
#define MACH_TYPE_NSPIRE               3503
#define MACH_TYPE_MICKXX               3504
#define MACH_TYPE_LXMB                 3505
#define MACH_TYPE_TMDXSCBP6616X        3506
#define MACH_TYPE_ADAM                 3507
#define MACH_TYPE_B1004                3508
#define MACH_TYPE_OBOEA                3509
#define MACH_TYPE_A1015                3510
#define MACH_TYPE_ROBIN_VBDT30         3511
#define MACH_TYPE_TEGRA_ENTERPRISE     3512
#define MACH_TYPE_RFL108200_MK10       3513
#define MACH_TYPE_RFL108300_MK16       3514
#define MACH_TYPE_ROVER_V7             3515
#define MACH_TYPE_MIPHONE              3516
#define MACH_TYPE_FEMTOBTS             3517
#define MACH_TYPE_MONOPOLI             3518
#define MACH_TYPE_BOSS                 3519
#define MACH_TYPE_DAVINCI_DM368_VTAM   3520
#define MACH_TYPE_CLCON                3521
#define MACH_TYPE_NOKIA_RM696          3522
#define MACH_TYPE_TAHITI               3523
#define MACH_TYPE_FIGHTER              3524
#define MACH_TYPE_SGH_I710             3525
#define MACH_TYPE_INTEGREPROSCB        3526
#define MACH_TYPE_MONZA                3527
#define MACH_TYPE_MX6Q_SABREAUTO       3529
#define MACH_TYPE_GMA01X               3530
#define MACH_TYPE_SBC51                3531
#define MACH_TYPE_FIT                  3532
#define MACH_TYPE_STEELHEAD            3533
#define MACH_TYPE_PANTHER              3534
#define MACH_TYPE_MSM8960_LIQUID       3535
#define MACH_TYPE_LEXIKONCT            3536
#define MACH_TYPE_NS2816_STB           3537
#define MACH_TYPE_SEI_MM2_LPC3250      3538
#define MACH_TYPE_CMIMX53              3539
#define MACH_TYPE_SANDWICH             3540
#define MACH_TYPE_CHIEF                3541
#define MACH_TYPE_POGO_E02             3542
#define MACH_TYPE_MIKRAP_X168          3543
#define MACH_TYPE_HTCMOZART            3544
#define MACH_TYPE_HTCGOLD              3545
#define MACH_TYPE_MT72XX               3546
#define MACH_TYPE_MX51_IVY             3547
#define MACH_TYPE_MX51_LVD             3548
#define MACH_TYPE_OMAP3_WISER2         3549
#define MACH_TYPE_DREAMPLUG            3550
#define MACH_TYPE_COBAS_C_111          3551
#define MACH_TYPE_COBAS_U_411          3552
#define MACH_TYPE_HSSD                 3553
#define MACH_TYPE_IOM35X               3554
#define MACH_TYPE_PSOM_OMAP            3555
#define MACH_TYPE_IPHONE_2G            3556
#define MACH_TYPE_IPHONE_3G            3557
#define MACH_TYPE_IPOD_TOUCH_1G        3558
#define MACH_TYPE_PHAROS_TPC           3559
#define MACH_TYPE_MX53_HYDRA           3560
#define MACH_TYPE_NS2816_DEV_BOARD     3561
#define MACH_TYPE_IPHONE_3GS           3562
#define MACH_TYPE_IPHONE_4             3563
#define MACH_TYPE_IPOD_TOUCH_4G        3564
#define MACH_TYPE_DRAGON_E1100         3565
#define MACH_TYPE_TOPSIDE              3566
#define MACH_TYPE_IRISIII              3567
#define MACH_TYPE_DETO_MACARM9         3568
#define MACH_TYPE_ETI_D1               3569
#define MACH_TYPE_SOM3530SDK           3570
#define MACH_TYPE_OC_ENGINE            3571
#define MACH_TYPE_APQ8064_SIM          3572
#define MACH_TYPE_ALPS                 3575
#define MACH_TYPE_TNY_T3730            3576
#define MACH_TYPE_GERYON_NFE           3577
#define MACH_TYPE_NS2816_REF_BOARD     3578
#define MACH_TYPE_SILVERSTONE          3579
#define MACH_TYPE_MTT2440              3580
#define MACH_TYPE_YNICDB               3581
#define MACH_TYPE_BCT                  3582
#define MACH_TYPE_TUSCAN               3583
#define MACH_TYPE_XBT_SAM9G45          3584
#define MACH_TYPE_ENBW_CMC             3585
#define MACH_TYPE_APQ8060_DRAGON       3586
#define MACH_TYPE_CH104MX257           3587
#define MACH_TYPE_OPENPRI              3588
#define MACH_TYPE_AM335XEVM            3589
#define MACH_TYPE_PICODMB              3590
#define MACH_TYPE_WALUIGI              3591
#define MACH_TYPE_PUNICAG7             3592
#define MACH_TYPE_IPAD_1G              3593
#define MACH_TYPE_APPLETV_2G           3594
#define MACH_TYPE_MACH_ECOG45          3595
#define MACH_TYPE_AIT_CAM_ENC_4XX      3596
#define MACH_TYPE_RUNNYMEDE            3597
#define MACH_TYPE_PLAY                 3598
#define MACH_TYPE_HW90260              3599
#define MACH_TYPE_TAGH                 3600
#define MACH_TYPE_FILBERT              3601
#define MACH_TYPE_GETINGE_NETCOMV3     3602
#define MACH_TYPE_CW20                 3603
#define MACH_TYPE_CINEMA               3604
#define MACH_TYPE_CINEMA_TEA           3605
#define MACH_TYPE_CINEMA_COFFEE        3606
#define MACH_TYPE_CINEMA_JUICE         3607
#define MACH_TYPE_THEPAD               3608
#define MACH_TYPE_MX53_MIRAGE2         3609
#define MACH_TYPE_MX53_EFIKASB         3610
#define MACH_TYPE_STM_B2000            3612
#define MACH_TYPE_M28EVK               3613
#define MACH_TYPE_PDA                  3614
#define MACH_TYPE_MERAKI_MR58          3615
#define MACH_TYPE_KOTA2                3616
#define MACH_TYPE_LETCOOL              3617
#define MACH_TYPE_MX27IAT              3618
#define MACH_TYPE_APOLLO_TD            3619
#define MACH_TYPE_ARENA                3620
#define MACH_TYPE_GSNGATEWAY           3621
#define MACH_TYPE_LF2000               3622
#define MACH_TYPE_BONITO               3623
#define MACH_TYPE_ASYMPTOTE            3624
#define MACH_TYPE_BST2BRD              3625
#define MACH_TYPE_TX335S               3626
#define MACH_TYPE_PELCO_TESLA          3627
#define MACH_TYPE_RRHTESTPLAT          3628
#define MACH_TYPE_VIDTONIC_PRO         3629
#define MACH_TYPE_PL_APOLLO            3630
#define MACH_TYPE_PL_PHOENIX           3631
#define MACH_TYPE_M28CU3               3632
#define MACH_TYPE_VVBOX_HD             3633
#define MACH_TYPE_COREWARE_SAM9260_    3634
#define MACH_TYPE_MARMADUKE            3635
#define MACH_TYPE_AMG_XLCORE_CAMERA    3636
#define MACH_TYPE_OMAP3_EGF            3637
#define MACH_TYPE_SMDK4212             3638
#define MACH_TYPE_DNP9200              3639
#define MACH_TYPE_TF101                3640
#define MACH_TYPE_OMAP3SILVIO          3641
#define MACH_TYPE_PICASSO2             3642
#define MACH_TYPE_VANGOGH2             3643
#define MACH_TYPE_OLPC_XO_1_75         3644
#define MACH_TYPE_GX400                3645
#define MACH_TYPE_GS300                3646
#define MACH_TYPE_ACER_A9              3647
#define MACH_TYPE_VIVOW_EVM            3648
#define MACH_TYPE_VELOCE_CXQ           3649
#define MACH_TYPE_VELOCE_CXM           3650
#define MACH_TYPE_P1852                3651
#define MACH_TYPE_NAXY100              3652
#define MACH_TYPE_TAISHAN              3653
#define MACH_TYPE_TOUCHLINK            3654
#define MACH_TYPE_STM32F103ZE          3655
#define MACH_TYPE_STM_NMHDK_FLI7610    3657
#define MACH_TYPE_TOP28X               3658
#define MACH_TYPE_OKL4VP_MICROVISOR    3659
#define MACH_TYPE_POP                  3660
#define MACH_TYPE_LAYER                3661
#define MACH_TYPE_TRONDHEIM            3662
#define MACH_TYPE_EVA                  3663
#define MACH_TYPE_TRUST_TAURUS         3664
#define MACH_TYPE_NS2816_HUASHAN       3665
#define MACH_TYPE_NS2816_YANGCHENG     3666
#define MACH_TYPE_P852                 3667
#define MACH_TYPE_FLEA3                3668
#define MACH_TYPE_BOWFIN               3669
#define MACH_TYPE_MV88DE3100           3670
#define MACH_TYPE_PIA_AM35X            3671
#define MACH_TYPE_CEDAR                3672
#define MACH_TYPE_PICASSO_E            3673
#define MACH_TYPE_SAMSUNG_E60          3674
#define MACH_TYPE_MDM9615              3675
#define MACH_TYPE_SDVR_MINI            3676
#define MACH_TYPE_OMAP3_IJ3K           3677
#define MACH_TYPE_MODASMC1             3678
#define MACH_TYPE_APQ8064_RUMI3        3679
#define MACH_TYPE_MATRIX506            3680
#define MACH_TYPE_MSM9615_MTP          3681
#define MACH_TYPE_DM36X_SPAWNDC        3682
#define MACH_TYPE_SFF792               3683
#define MACH_TYPE_AM335XIAEVM          3684
#define MACH_TYPE_G3C2440              3685
#define MACH_TYPE_TION270              3686
#define MACH_TYPE_W22Q7ARM02           3687
#define MACH_TYPE_OMAP_CAT             3688
#define MACH_TYPE_AT91SAM9N12EK        3689
#define MACH_TYPE_MORRISON             3690
#define MACH_TYPE_SVDU                 3691
#define MACH_TYPE_LPP01                3692
#define MACH_TYPE_UBC283               3693
#define MACH_TYPE_ZEPPELIN             3694
#define MACH_TYPE_MOTUS                3695
#define MACH_TYPE_NEOMAINBOARD         3696
#define MACH_TYPE_DEVKIT3250           3697
#define MACH_TYPE_DEVKIT7000           3698
#define MACH_TYPE_FMC_UIC              3699
#define MACH_TYPE_FMC_DCM              3700
#define MACH_TYPE_BATWM                3701
#define MACH_TYPE_ATLAS6CB             3702
#define MACH_TYPE_QUATTROF             3703
#define MACH_TYPE_QUATTROU             3704
#define MACH_TYPE_BLUE                 3705
#define MACH_TYPE_COLORADO             3706
#define MACH_TYPE_POPC                 3707
#define MACH_TYPE_PROMWAD_JADE         3708
#define MACH_TYPE_AMP                  3709
#define MACH_TYPE_GNET_AMP             3710
#define MACH_TYPE_TOQUES               3711
#define MACH_TYPE_APX4DEVKIT           3712
#define MACH_TYPE_DCT_STORM            3713
#define MACH_TYPE_Z3                   3714
#define MACH_TYPE_OWL                  3715
#define MACH_TYPE_COGENT_CSB1741       3716
#define MACH_TYPE_OMAP3                3717
#define MACH_TYPE_ADILLUSTRA610        3718
#define MACH_TYPE_ECAFE_NA04           3719
#define MACH_TYPE_POPCT                3720
#define MACH_TYPE_OMAP3_HELENA         3721
#define MACH_TYPE_ACH                  3722
#define MACH_TYPE_MODULE_DTB           3723
#define MACH_TYPE_RACKBOX              3724
#define MACH_TYPE_OSLO_ELISABETH       3725
#define MACH_TYPE_TT01                 3726
#define MACH_TYPE_MSM8930_CDP          3727
#define MACH_TYPE_MSM8930_MTP          3728
#define MACH_TYPE_MSM8930_FLUID        3729
#define MACH_TYPE_LTU11                3730
#define MACH_TYPE_AM1808_SPAWNCO       3731
#define MACH_TYPE_FLX6410              3732
#define MACH_TYPE_MX6Q_QSB             3733
#define MACH_TYPE_MX53_PLT424          3734
#define MACH_TYPE_JASMINE              3735
#define MACH_TYPE_L138_OWLBOARD_PLUS   3736
#define MACH_TYPE_WR21                 3737
#define MACH_TYPE_PEABOY               3739
#define MACH_TYPE_MX28_PLATO           3740
#define MACH_TYPE_KACOM2               3741
#define MACH_TYPE_SLCO                 3742
#define MACH_TYPE_IMX51PICO            3743
#define MACH_TYPE_GLINK1               3744
#define MACH_TYPE_DIAMOND              3745
#define MACH_TYPE_D9000                3746
#define MACH_TYPE_W5300E01             3747
#define MACH_TYPE_IM6000               3748
#define MACH_TYPE_MX51_FRED51          3749
#define MACH_TYPE_STM32F2              3750
#define MACH_TYPE_VILLE                3751
#define MACH_TYPE_PTIP_MURNAU          3752
#define MACH_TYPE_PTIP_CLASSIC         3753
#define MACH_TYPE_MX53GRB              3754
#define MACH_TYPE_GAGARIN              3755
#define MACH_TYPE_MSM7X27A_QRD1        3756
#define MACH_TYPE_NAS2BIG              3757
#define MACH_TYPE_SUPERFEMTO           3758
#define MACH_TYPE_TEUFEL               3759
#define MACH_TYPE_DINARA               3760
#define MACH_TYPE_VANQUISH             3761
#define MACH_TYPE_ZIPABOX1             3762
#define MACH_TYPE_U9540                3763
#define MACH_TYPE_JET                  3764
#define MACH_TYPE_SMDK4412             3765
#define MACH_TYPE_ELITE                3766
#define MACH_TYPE_SPEAR320_HMI         3767
#define MACH_TYPE_ONTARIO              3768
#define MACH_TYPE_MX6Q_SABRELITE       3769
#define MACH_TYPE_VC200                3770
#define MACH_TYPE_MSM7625A_FFA         3771
#define MACH_TYPE_MSM7625A_SURF        3772
#define MACH_TYPE_BENTHOSSBP           3773
#define MACH_TYPE_SMDK5210             3774
#define MACH_TYPE_EMPQ2300             3775
#define MACH_TYPE_MINIPOS              3776
#define MACH_TYPE_OMAP5_SEVM           3777
#define MACH_TYPE_SHELTER              3778
#define MACH_TYPE_OMAP3_DEVKIT8500     3779
#define MACH_TYPE_EDGETD               3780
#define MACH_TYPE_COPPERYARD           3781
#define MACH_TYPE_EDGE                 3782
#define MACH_TYPE_EDGE_U               3783
#define MACH_TYPE_EDGE_TD              3784
#define MACH_TYPE_WDSS                 3785
#define MACH_TYPE_DL_PB25              3786
#define MACH_TYPE_DSS11                3787
#define MACH_TYPE_CPA                  3788
#define MACH_TYPE_APTP2000             3789
#define MACH_TYPE_MARZEN               3790
#define MACH_TYPE_ST_TURBINE           3791
#define MACH_TYPE_GTL_IT3300           3792
#define MACH_TYPE_MX6_MULE             3793
#define MACH_TYPE_V7PXA_DT             3794
#define MACH_TYPE_V7MMP_DT             3795
#define MACH_TYPE_DRAGON7              3796
#define MACH_TYPE_KROME                3797
#define MACH_TYPE_ORATISDANTE          3798
#define MACH_TYPE_FATHOM               3799
#define MACH_TYPE_DNS325               3800
#define MACH_TYPE_SARNEN               3801
#define MACH_TYPE_UBISYS_G1            3802
#define MACH_TYPE_MX53_PF1             3803
#define MACH_TYPE_ASANTI               3804
#define MACH_TYPE_VOLTA                3805
#define MACH_TYPE_S5P6450              3806
#define MACH_TYPE_KNIGHT               3807
#define MACH_TYPE_BEAGLEBONE           3808
#define MACH_TYPE_BECKER               3809
#define MACH_TYPE_FC360                3810
#define MACH_TYPE_PMI2_XLS             3811
#define MACH_TYPE_TARANTO              3812
#define MACH_TYPE_PLUTUX               3813
#define MACH_TYPE_IPMP_MEDCOM          3814
#define MACH_TYPE_ABSOLUT              3815
#define MACH_TYPE_AWPB3                3816
#define MACH_TYPE_NFP32XX_DT           3817
#define MACH_TYPE_DL_PB53              3818
#define MACH_TYPE_ACU_II               3819
#define MACH_TYPE_AVALON               3820
#define MACH_TYPE_SPHINX               3821
#define MACH_TYPE_TITAN_T              3822
#define MACH_TYPE_HARVEST_BORIS        3823
#define MACH_TYPE_MACH_MSM7X30_M3S     3824
#define MACH_TYPE_SMDK5250             3825
#define MACH_TYPE_IMXT_LITE            3826
#define MACH_TYPE_IMXT_STD             3827
#define MACH_TYPE_IMXT_LOG             3828
#define MACH_TYPE_IMXT_NAV             3829
#define MACH_TYPE_IMXT_FULL            3830
#define MACH_TYPE_AG09015              3831
#define MACH_TYPE_DP1ARM9              3833
#define MACH_TYPE_PICASSO_M            3834
#define MACH_TYPE_VIDEO_GADGET         3835
#define MACH_TYPE_MTT_OM3X             3836
#define MACH_TYPE_MX6Q_ARM2            3837
#define MACH_TYPE_PICOSAM9G45          3838
#define MACH_TYPE_VPM_DM365            3839
#define MACH_TYPE_BONFIRE              3840
#define MACH_TYPE_MT2P2D               3841
#define MACH_TYPE_SIGPDA01             3842
#define MACH_TYPE_CN27                 3843
#define MACH_TYPE_MX25_CWTAP           3844
#define MACH_TYPE_APF28                3845
#define MACH_TYPE_PELCO_MAXWELL        3846
#define MACH_TYPE_GE_PHOENIX           3847
#define MACH_TYPE_EMPC_A500            3848
#define MACH_TYPE_IMS_ARM9             3849
#define MACH_TYPE_MINI2416             3850
#define MACH_TYPE_MINI2450             3851
#define MACH_TYPE_MINI310              3852
#define MACH_TYPE_SPEAR_HURRICANE      3853
#define MACH_TYPE_MT7208               3854
#define MACH_TYPE_LPC178X              3855
#define MACH_TYPE_FARLEYS              3856
#define MACH_TYPE_EFM32GG_DK3750       3857
#define MACH_TYPE_ZEUS_BOARD           3858
#define MACH_TYPE_CC51                 3859
#define MACH_TYPE_FXI_C210             3860
#define MACH_TYPE_MSM8627_CDP          3861
#define MACH_TYPE_MSM8627_MTP          3862
#define MACH_TYPE_ARMADILLO800EVA      3863
#define MACH_TYPE_PRIMOU               3864
#define MACH_TYPE_PRIMOC               3865
#define MACH_TYPE_PRIMOCT              3866
#define MACH_TYPE_A9500                3867
#define MACH_TYPE_PULSE_TD             3868
#define MACH_TYPE_PLUTO                3869
#define MACH_TYPE_ACFX100              3870
#define MACH_TYPE_MSM8625_RUMI3        3871
#define MACH_TYPE_VALENTE              3872
#define MACH_TYPE_CRFS_RFEYE           3873
#define MACH_TYPE_RFEYE                3874
#define MACH_TYPE_PHIDGET_SBC3         3875
#define MACH_TYPE_TCW_MIKA             3876
#define MACH_TYPE_IMX28_EGF            3877
#define MACH_TYPE_VALENTE_WX           3878
#define MACH_TYPE_HUANGSHANS           3879
#define MACH_TYPE_BOSPHORUS1           3880
#define MACH_TYPE_PRIMA                3881
#define MACH_TYPE_M3_SKT               3882
#define MACH_TYPE_M3_REF               3883
#define MACH_TYPE_EVITA_ULK            3884
#define MACH_TYPE_MERISC600            3885
#define MACH_TYPE_DOLAK                3886
#define MACH_TYPE_SBC53                3887
#define MACH_TYPE_ELITE_ULK            3888
#define MACH_TYPE_POV2                 3889
#define MACH_TYPE_IPOD_TOUCH_2G        3890
#define MACH_TYPE_DA850_PQAB           3891
#define MACH_TYPE_FERMI                3892
#define MACH_TYPE_CCARDWMX28           3893
#define MACH_TYPE_CCARDMX28            3894
#define MACH_TYPE_FS20_FCM2050         3895
#define MACH_TYPE_KINETIS              3896
#define MACH_TYPE_KAI                  3897
#define MACH_TYPE_BCTHB2               3898
#define MACH_TYPE_INELS3_CU            3899
#define MACH_TYPE_JUNIPER              3900
#define MACH_TYPE_DA850_APOLLO         3901
#define MACH_TYPE_TRACNAS              3902
#define MACH_TYPE_MITYARM335X          3903
#define MACH_TYPE_XCGZ7X               3904
#define MACH_TYPE_CUBOX                3905
#define MACH_TYPE_TERMINATOR           3906
#define MACH_TYPE_EYE03                3907
#define MACH_TYPE_KOTA3                3908
#define MACH_TYPE_MX5                  3909
#define MACH_TYPE_PSCPE                3910
#define MACH_TYPE_AKT1100              3911
#define MACH_TYPE_PCAAXL2              3912
#define MACH_TYPE_PRIMODD_CT           3913
#define MACH_TYPE_NSBC                 3914
#define MACH_TYPE_MESON2_SKT           3915
#define MACH_TYPE_MESON2_REF           3916
#define MACH_TYPE_CCARDWMX28JS         3917
#define MACH_TYPE_CCARDMX28JS          3918
#define MACH_TYPE_INDICO               3919
#define MACH_TYPE_MSM8960DT            3920
#define MACH_TYPE_PRIMODS              3921
#define MACH_TYPE_BELUGA_M1388         3922
#define MACH_TYPE_PRIMOTD              3923
#define MACH_TYPE_VARAN_MASTER         3924
#define MACH_TYPE_PRIMODD              3925
#define MACH_TYPE_JETDUO               3926
#define MACH_TYPE_MX53_UMOBO           3927
#define MACH_TYPE_TRATS                3928
#define MACH_TYPE_STARCRAFT            3929
#define MACH_TYPE_QSEVEN_TEGRA2        3930
#define MACH_TYPE_LICHEE_SUN4I_DEVBD   3931
#define MACH_TYPE_MOVENOW              3932
#define MACH_TYPE_GOLF_U               3933
#define MACH_TYPE_MSM7627A_EVB         3934
#define MACH_TYPE_RAMBO                3935
#define MACH_TYPE_GOLFU                3936
#define MACH_TYPE_MANGO310             3937
#define MACH_TYPE_DNS343               3938
#define MACH_TYPE_VAR_SOM_OM44         3939
#define MACH_TYPE_NAON                 3940
#define MACH_TYPE_VP4000               3941
#define MACH_TYPE_IMPCARD              3942
#define MACH_TYPE_SMOOVCAM             3943
#define MACH_TYPE_COBHAM3725           3944
#define MACH_TYPE_COBHAM3730           3945
#define MACH_TYPE_COBHAM3703           3946
#define MACH_TYPE_QUETZAL              3947
#define MACH_TYPE_APQ8064_CDP          3948
#define MACH_TYPE_APQ8064_MTP          3949
#define MACH_TYPE_APQ8064_FLUID        3950
#define MACH_TYPE_APQ8064_LIQUID       3951
#define MACH_TYPE_MANGO210             3952
#define MACH_TYPE_MANGO100             3953
#define MACH_TYPE_MANGO24              3954
#define MACH_TYPE_MANGO64              3955
#define MACH_TYPE_NSA320               3956
#define MACH_TYPE_ELV_CCU2             3957
#define MACH_TYPE_TRITON_X00           3958
#define MACH_TYPE_TRITON_1500_2000     3959
#define MACH_TYPE_POGOPLUGV4           3960
#define MACH_TYPE_VENUS_CL             3961
#define MACH_TYPE_VULCANO_G20          3962
#define MACH_TYPE_SGS_I9100            3963
#define MACH_TYPE_STSV2                3964
#define MACH_TYPE_CSB1724              3965
#define MACH_TYPE_OMAPL138_LCDK        3966
#define MACH_TYPE_JEWEL_DD             3967
#define MACH_TYPE_PVD_MX25             3968
#define MACH_TYPE_MESON6_SKT           3969
#define MACH_TYPE_MESON6_REF           3970
#define MACH_TYPE_PXM                  3971
#define MACH_TYPE_S3                   3972
#define MACH_TYPE_POGOPLUGV3           3973
#define MACH_TYPE_MLP89626             3974
#define MACH_TYPE_IOMEGAHMNDCE         3975
#define MACH_TYPE_POGOPLUGV3PCI        3976
#define MACH_TYPE_BNTV250              3977
#define MACH_TYPE_MX53_QSEVEN          3978
#define MACH_TYPE_GTL_IT1100           3979
#define MACH_TYPE_MX6Q_SABRESD         3980
#define MACH_TYPE_MT4                  3981
#define MACH_TYPE_JUMBO_D              3982
#define MACH_TYPE_JUMBO_I              3983
#define MACH_TYPE_FS20_DMP             3984
#define MACH_TYPE_DNS320               3985
#define MACH_TYPE_MX28BACOS            3986
#define MACH_TYPE_TL80                 3987
#define MACH_TYPE_POLATIS_NIC_1001     3988
#define MACH_TYPE_TELY                 3989
#define MACH_TYPE_U8520                3990
#define MACH_TYPE_MANTA                3991
#define MACH_TYPE_SPEAR_EM_S900        3992
#define MACH_TYPE_MPQ8064_CDP          3993
#define MACH_TYPE_MPQ8064_STB          3994
#define MACH_TYPE_MPQ8064_DTV          3995
#define MACH_TYPE_DM368SOM             3996
#define MACH_TYPE_GPRISB2              3997
#define MACH_TYPE_CHAMMID              3998
#define MACH_TYPE_SEOUL2               3999
#define MACH_TYPE_OMAP4_NOOKTABLET     4000
#define MACH_TYPE_AALTO                4001
#define MACH_TYPE_METRO                4002
#define MACH_TYPE_CYDM3730             4003
#define MACH_TYPE_TQMA53               4004
#define MACH_TYPE_MSM7627A_QRD3        4005
#define MACH_TYPE_MX28_CANBY           4006
#define MACH_TYPE_TIGER                4007
#define MACH_TYPE_PCATS_9307_TYPE_A    4008
#define MACH_TYPE_PCATS_9307_TYPE_O    4009
#define MACH_TYPE_PCATS_9307_TYPE_R    4010
#define MACH_TYPE_STREAMPLUG           4011
#define MACH_TYPE_ICECHICKEN_DEV       4012
#define MACH_TYPE_HEDGEHOG             4013
#define MACH_TYPE_YUSEND_OBC           4014
#define MACH_TYPE_IMXNINJA             4015
#define MACH_TYPE_OMAP4_JAROD          4016
#define MACH_TYPE_ECO5_PK              4017
#define MACH_TYPE_QJ2440               4018
#define MACH_TYPE_MX6Q_MERCURY         4019
#define MACH_TYPE_CM6810               4020
#define MACH_TYPE_OMAP4_TORPEDO        4021
#define MACH_TYPE_NSA310               4022
#define MACH_TYPE_TMX536               4023
#define MACH_TYPE_KTT20                4024
#define MACH_TYPE_DRAGONIX             4025
#define MACH_TYPE_LUNGCHING            4026
#define MACH_TYPE_BULOGICS             4027
#define MACH_TYPE_MX535_SX             4028
#define MACH_TYPE_NGUI3250             4029
#define MACH_TYPE_SALUTEC_DAC          4030
#define MACH_TYPE_LOCO                 4031
#define MACH_TYPE_CTERA_PLUG_USI       4032
#define MACH_TYPE_SCEPTER              4033
#define MACH_TYPE_SGA                  4034
#define MACH_TYPE_P_81_J5              4035
#define MACH_TYPE_P_81_O4              4036
#define MACH_TYPE_MSM8625_SURF         4037
#define MACH_TYPE_CARALLON_SHARK       4038
#define MACH_TYPE_LSGCICAM             4039
#define MACH_TYPE_ORDOG                4040
#define MACH_TYPE_PUENTE_IO            4041
#define MACH_TYPE_MSM8625_EVB          4042
#define MACH_TYPE_EV_AM1707            4043
#define MACH_TYPE_EV_AM1707E2          4044
#define MACH_TYPE_EV_AM3517E2          4045
#define MACH_TYPE_CALABRIA             4046
#define MACH_TYPE_EV_IMX287            4047
#define MACH_TYPE_ERAU                 4048
#define MACH_TYPE_SICHUAN              4049
#define MACH_TYPE_WIRMA3               4050
#define MACH_TYPE_DAVINCI_DA850        4051
#define MACH_TYPE_OMAP138_TRUNARC      4052
#define MACH_TYPE_BCM4761              4053
#define MACH_TYPE_PICASSO_E2           4054
#define MACH_TYPE_PICASSO_MF           4055
#define MACH_TYPE_MIRO                 4056
#define MACH_TYPE_AT91SAM9G20EWON3     4057
#define MACH_TYPE_YOYO                 4058
#define MACH_TYPE_WINDJKL              4059
#define MACH_TYPE_MONARUDO             4060
#define MACH_TYPE_BATAN                4061
#define MACH_TYPE_TADAO                4062
#define MACH_TYPE_BASO                 4063
#define MACH_TYPE_MAHON                4064
#define MACH_TYPE_VILLEC2              4065
#define MACH_TYPE_ASI1230              4066
#define MACH_TYPE_ALASKA               4067
#define MACH_TYPE_SWARCO_SHDSL2        4068
#define MACH_TYPE_OXRTU                4069
#define MACH_TYPE_OMAP5_PANDA          4070
#define MACH_TYPE_MX28XDI              4071
#define MACH_TYPE_C8000                4072
#define MACH_TYPE_BJE_DISPLAY3_5       4073
#define MACH_TYPE_PICOMOD7             4074
#define MACH_TYPE_PICOCOM5             4075
#define MACH_TYPE_QBLISSA8             4076
#define MACH_TYPE_ARMSTONEA8           4077
#define MACH_TYPE_NETDCU14             4078
#define MACH_TYPE_AT91SAM9X5_EPIPHAN   4079
#define MACH_TYPE_P2U                  4080
#define MACH_TYPE_DORIS                4081
#define MACH_TYPE_J49                  4082
#define MACH_TYPE_VDSS2E               4083
#define MACH_TYPE_VC300                4084
#define MACH_TYPE_NS115_PAD_TEST       4085
#define MACH_TYPE_NS115_PAD_REF        4086
#define MACH_TYPE_NS115_PHONE_TEST     4087
#define MACH_TYPE_NS115_PHONE_REF      4088
#define MACH_TYPE_GOLFC                4089
#define MACH_TYPE_XEROX_OLYMPUS        4090
#define MACH_TYPE_MX6SL_ARM2           4091
#define MACH_TYPE_CSB1701_CSB1726      4092
#define MACH_TYPE_AT91SAM9XEEK         4093
#define MACH_TYPE_EBV210               4094
#define MACH_TYPE_MSM7627A_QRD7        4095
#define MACH_TYPE_SVTHIN               4096
#define MACH_TYPE_DUOVERO              4097
#define MACH_TYPE_CHUPACABRA           4098
#define MACH_TYPE_SCORPION             4099
#define MACH_TYPE_DAVINCI_HE_HMI10     4100
#define MACH_TYPE_TOPKICK              4101
#define MACH_TYPE_M3_AUGUESTRUSH       4102
#define MACH_TYPE_IPC335X              4103
#define MACH_TYPE_SUN4I                4104
#define MACH_TYPE_IMX233_OLINUXINO     4105
#define MACH_TYPE_K2_WL                4106
#define MACH_TYPE_K2_UL                4107
#define MACH_TYPE_K2_CL                4108
#define MACH_TYPE_MINBARI_W            4109
#define MACH_TYPE_MINBARI_M            4110
#define MACH_TYPE_K035                 4111
#define MACH_TYPE_ARIEL                4112
#define MACH_TYPE_ARIELSAARC           4113
#define MACH_TYPE_ARIELDKB             4114
#define MACH_TYPE_ARMADILLO810         4115
#define MACH_TYPE_TAM335X              4116
#define MACH_TYPE_GROUPER              4117
#define MACH_TYPE_MPCSA21_9G20         4118
#define MACH_TYPE_M6U_CPU              4119
#define MACH_TYPE_DAVINCI_DP10         4120
#define MACH_TYPE_GINKGO               4121
#define MACH_TYPE_CGT_QMX6             4122
#define MACH_TYPE_PROFPGA              4123
#define MACH_TYPE_ACFX100OC            4124
#define MACH_TYPE_ACFX100NB            4125
#define MACH_TYPE_CAPRICORN            4126
#define MACH_TYPE_PISCES               4127
#define MACH_TYPE_ARIES                4128
#define MACH_TYPE_CANCER               4129
#define MACH_TYPE_LEO                  4130
#define MACH_TYPE_VIRGO                4131
#define MACH_TYPE_SAGITTARIUS          4132
#define MACH_TYPE_DEVIL                4133
#define MACH_TYPE_BALLANTINES          4134
#define MACH_TYPE_OMAP3_PROCERUSVPU    4135
#define MACH_TYPE_MY27                 4136
#define MACH_TYPE_SUN6I                4137
#define MACH_TYPE_SUN5I                4138
#define MACH_TYPE_MX512_MX             4139
#define MACH_TYPE_KZM9G                4140
#define MACH_TYPE_VDSTBN               4141
#define MACH_TYPE_CFA10036             4142
#define MACH_TYPE_CFA10049             4143
#define MACH_TYPE_PCM051               4144
#define MACH_TYPE_VYBRID_VF7XX         4145
#define MACH_TYPE_VYBRID_VF6XX         4146
#define MACH_TYPE_VYBRID_VF5XX         4147
#define MACH_TYPE_VYBRID_VF4XX         4148
#define MACH_TYPE_ARIA_G25             4149
#define MACH_TYPE_BCM21553             4150
#define MACH_TYPE_SMDK5410             4151
#define MACH_TYPE_LPC18XX              4152
#define MACH_TYPE_ORATISPARTY          4153
#define MACH_TYPE_QSEVEN               4154
#define MACH_TYPE_GMV_GENERIC          4155
#define MACH_TYPE_TH_LINK_ETH          4156
#define MACH_TYPE_TN_MUNINN            4157
#define MACH_TYPE_RAMPAGE              4158
#define MACH_TYPE_VISSTRIM_MV10        4159
#define MACH_TYPE_MONACO_TDU           4160
#define MACH_TYPE_MONACO_UL            4161
#define MACH_TYPE_ENRC2_U              4162
#define MACH_TYPE_EVITA_UL             4163
#define MACH_TYPE_MX28_WILMA           4164
#define MACH_TYPE_MONACO_U             4165
#define MACH_TYPE_MSM8625_FFA          4166
#define MACH_TYPE_VPU101               4167
#define MACH_TYPE_OPERA_UL             4168
#define MACH_TYPE_BAILEYS              4169
#define MACH_TYPE_FAMILYBOX            4170
#define MACH_TYPE_ENSEMBLE_MX35        4171
#define MACH_TYPE_SC_SPS_1             4172
#define MACH_TYPE_UCSIMPLY_SAM9260     4173
#define MACH_TYPE_UNICORN              4174
#define MACH_TYPE_M9G45A               4175
#define MACH_TYPE_MTWEBIF              4176
#define MACH_TYPE_PLAYSTONE            4177
#define MACH_TYPE_CHELSEA              4178
#define MACH_TYPE_BAYERN               4179
#define MACH_TYPE_MITWO                4180
#define MACH_TYPE_MX25_NOAH            4181
#define MACH_TYPE_STM_B2020            4182
#define MACH_TYPE_ANNAX_SRC            4183
#define MACH_TYPE_IONICS_STRATUS       4184
#define MACH_TYPE_HUGO                 4185
#define MACH_TYPE_EM300                4186
#define MACH_TYPE_MMP3_QSEVEN          4187
#define MACH_TYPE_BOSPHORUS2           4188
#define MACH_TYPE_TT2200               4189
#define MACH_TYPE_OCELOT3              4190
#define MACH_TYPE_TEK_COBRA            4191
#define MACH_TYPE_PROTOU               4192
#define MACH_TYPE_MSM8625_EVT          4193
#define MACH_TYPE_MX53_SELLWOOD        4194
#define MACH_TYPE_SOMIQ_AM35           4195
#define MACH_TYPE_SOMIQ_AM37           4196
#define MACH_TYPE_K2_PLC_CL            4197
#define MACH_TYPE_TC2                  4198
#define MACH_TYPE_DULEX_J              4199
#define MACH_TYPE_STM_B2044            4200
#define MACH_TYPE_DELUXE_J             4201
#define MACH_TYPE_MANGO2443            4202
#define MACH_TYPE_CP2DCG               4203
#define MACH_TYPE_CP2DTG               4204
#define MACH_TYPE_CP2DUG               4205
#define MACH_TYPE_VAR_SOM_AM33         4206
#define MACH_TYPE_PEPPER               4207
#define MACH_TYPE_MANGO2450            4208
#define MACH_TYPE_VALENTE_WX_C9        4209
#define MACH_TYPE_MINITV               4210
#define MACH_TYPE_U8540                4211
#define MACH_TYPE_IV_ATLAS_I_Z7E       4212
#define MACH_TYPE_COGENT_CSB1733       4213
#define MACH_TYPE_MACH_TYPE_SKY        4214
#define MACH_TYPE_BLUESKY              4215
#define MACH_TYPE_NGROUTER             4216
#define MACH_TYPE_MX53_DENETIM         4217
#define MACH_TYPE_OPAL                 4218
#define MACH_TYPE_GNET_US3GREF         4219
#define MACH_TYPE_GNET_NC3G            4220
#define MACH_TYPE_GNET_GE3G            4221
#define MACH_TYPE_ADP2                 4222
#define MACH_TYPE_TQMA28               4223
#define MACH_TYPE_KACOM3               4224
#define MACH_TYPE_RRHDEMO              4225
#define MACH_TYPE_PROTODUG             4226
#define MACH_TYPE_LAGO                 4227
#define MACH_TYPE_KTT30                4228
#define MACH_TYPE_TS43XX               4229
#define MACH_TYPE_MX6Q_DENSO           4230
#define MACH_TYPE_COMSAT_GSMUMTS8      4231
#define MACH_TYPE_DREAMX               4232
#define MACH_TYPE_THUNDERSTONEM        4233
#define MACH_TYPE_YOYOPAD              4234
#define MACH_TYPE_YOYOPATIENT          4235
#define MACH_TYPE_A10L                 4236
#define MACH_TYPE_MQ60                 4237
#define MACH_TYPE_LINKSTATION_LSQL     4238
#define MACH_TYPE_AM3703GATEWAY        4239
#define MACH_TYPE_ACCIPITER            4240
#define MACH_TYPE_P1853                4241
#define MACH_TYPE_MAGNIDUG             4242
#define MACH_TYPE_HYDRA                4243
#define MACH_TYPE_SUN3I                4244
#define MACH_TYPE_STM_B2078            4245
#define MACH_TYPE_AT91SAM9263DESKV2    4246
#define MACH_TYPE_DELUXE_R             4247
#define MACH_TYPE_P_98_V               4248
#define MACH_TYPE_P_98_C               4249
#define MACH_TYPE_DAVINCI_AM18XX_OMN   4250
#define MACH_TYPE_SOCFPGA_CYCLONE5     4251
#define MACH_TYPE_CABATUIN             4252
#define MACH_TYPE_YOYOPAD_FT           4253
#define MACH_TYPE_DAN2400EVB           4254
#define MACH_TYPE_DAN3400EVB           4255
#define MACH_TYPE_EDM_SF_IMX6          4256
#define MACH_TYPE_EDM_CF_IMX6          4257
#define MACH_TYPE_VPOS3XX              4258
#define MACH_TYPE_VULCANO_9X5          4259
#define MACH_TYPE_SPMP8000             4260
#define MACH_TYPE_CATALINA             4261
#define MACH_TYPE_RD88F5181L_FE        4262
#define MACH_TYPE_MX535_MX             4263
#define MACH_TYPE_ARMADILLO840         4264
#define MACH_TYPE_SPC9000BASEBOARD     4265
#define MACH_TYPE_IRIS                 4266
#define MACH_TYPE_PROTODCG             4267
#define MACH_TYPE_PALMTREE             4268
#define MACH_TYPE_NOVENA               4269
#define MACH_TYPE_MA_UM                4270
#define MACH_TYPE_MA_AM                4271
#define MACH_TYPE_EMS348               4272
#define MACH_TYPE_CM_FX6               4273
#define MACH_TYPE_ARNDALE              4274
#define MACH_TYPE_Q5XR5                4275
#define MACH_TYPE_WILLOW               4276
#define MACH_TYPE_OMAP3621_ODYV3       4277
#define MACH_TYPE_OMAPL138_PRESONUS    4278
#define MACH_TYPE_DVF99                4279
#define MACH_TYPE_IMPRESSION_J         4280
#define MACH_TYPE_QBLISSA9             4281
#define MACH_TYPE_ROBIN_HELIVIEW10     4282
#define MACH_TYPE_SUN7I                4283
#define MACH_TYPE_MX6Q_HDMIDONGLE      4284
#define MACH_TYPE_MX6_SID2             4285
#define MACH_TYPE_HELIOS_V3            4286
#define MACH_TYPE_HELIOS_V4            4287
#define MACH_TYPE_Q7_IMX6              4288
#define MACH_TYPE_ODROIDX              4289
#define MACH_TYPE_ROBPRO               4290
#define MACH_TYPE_RESEARCH59IF_MK1     4291
#define MACH_TYPE_BOBSLEIGH            4292
#define MACH_TYPE_DCSHGWT3             4293
#define MACH_TYPE_GLD1018              4294
#define MACH_TYPE_EV10                 4295
#define MACH_TYPE_NITROGEN6X           4296
#define MACH_TYPE_P_107_BB             4297
#define MACH_TYPE_EVITA_UTL            4298
#define MACH_TYPE_FALCONWING           4299
#define MACH_TYPE_DCT3                 4300
#define MACH_TYPE_CPX2E_CELL           4301
#define MACH_TYPE_AMIRO                4302
#define MACH_TYPE_MX6Q_BRASSBOARD      4303
#define MACH_TYPE_DALMORE              4304
#define MACH_TYPE_OMAP3_PORTAL7CP      4305
#define MACH_TYPE_TEGRA_PLUTO          4306
#define MACH_TYPE_MX6SL_EVK            4307
#define MACH_TYPE_M7                   4308
#define MACH_TYPE_PXM2                 4309
#define MACH_TYPE_HABA_KNX_LITE        4310
#define MACH_TYPE_TAI                  4311
#define MACH_TYPE_PROTOTD              4312
#define MACH_TYPE_DST_TONTO            4313
#define MACH_TYPE_DRACO                4314
#define MACH_TYPE_DXR2                 4315
#define MACH_TYPE_RUT                  4316
#define MACH_TYPE_AM180X_WSC           4317
#define MACH_TYPE_DELUXE_U             4318
#define MACH_TYPE_DELUXE_UL            4319
#define MACH_TYPE_AT91SAM9260MEDTHS    4320
#define MACH_TYPE_MATRIX516            4321
#define MACH_TYPE_VID401X              4322
#define MACH_TYPE_HELIOS_V5            4323
#define MACH_TYPE_PLAYPAQ2             4324
#define MACH_TYPE_IGAM                 4325
#define MACH_TYPE_AMICO_I              4326
#define MACH_TYPE_AMICO_E              4327
#define MACH_TYPE_SENTIENT_MM3_CK      4328
#define MACH_TYPE_SMX6                 4329
#define MACH_TYPE_PANGO                4330
#define MACH_TYPE_NS115_STICK          4331
#define MACH_TYPE_BCTRM3               4332
#define MACH_TYPE_DOCTORWS             4333
#define MACH_TYPE_M2601                4334
#define MACH_TYPE_GRIDCO_TRINITY       4335
#define MACH_TYPE_PC3032               4336
#define MACH_TYPE_VGG1111              4337
#define MACH_TYPE_COUNTACH             4338
#define MACH_TYPE_VISSTRIM_SM20        4339
#define MACH_TYPE_A639                 4340
#define MACH_TYPE_SPACEMONKEY          4341
#define MACH_TYPE_ZPDU_STAMP           4342
#define MACH_TYPE_HTC_G7_CLONE         4343
#define MACH_TYPE_FT2080_CORVUS        4344
#define MACH_TYPE_FISLAND              4345
#define MACH_TYPE_ZPDU                 4346
#define MACH_TYPE_URT                  4347
#define MACH_TYPE_CONTI_OVIP           4348
#define MACH_TYPE_OMAPL138_NAGRA       4349
#define MACH_TYPE_DA850_AT3KP1         4350
#define MACH_TYPE_DA850_AT3KP2         4351
#define MACH_TYPE_SURMA                4352
#define MACH_TYPE_STM_B2092            4353
#define MACH_TYPE_MX535_YCR            4354
#define MACH_TYPE_M7_WL                4355
#define MACH_TYPE_M7_U                 4356
#define MACH_TYPE_OMAP3_STNDT_EVM      4357
#define MACH_TYPE_M7_WLV               4358
#define MACH_TYPE_XAM3517              4359
#define MACH_TYPE_A220                 4360
#define MACH_TYPE_ACLIMA_ODIE          4361
#define MACH_TYPE_VIBBLE               4362
#define MACH_TYPE_K2_U                 4363
#define MACH_TYPE_MX53_EGF             4364
#define MACH_TYPE_NOVPEK_IMX53         4365
#define MACH_TYPE_NOVPEK_IMX6X         4366
#define MACH_TYPE_MX25_SMARTBOX        4367
#define MACH_TYPE_EICG6410             4368
#define MACH_TYPE_PICASSO_E3           4369
#define MACH_TYPE_MOTONAVIGATOR        4370
#define MACH_TYPE_VARIOCONNECT2        4371
#define MACH_TYPE_DELUXE_TW            4372
#define MACH_TYPE_KORE3                4374
#define MACH_TYPE_MX6S_DRS             4375
#define MACH_TYPE_CMIMX6               4376
#define MACH_TYPE_ROTH                 4377
#define MACH_TYPE_EQ4UX                4378
#define MACH_TYPE_X1PLUS               4379
#define MACH_TYPE_MODIMX27             4380
#define MACH_TYPE_VIDEON_HDUAC         4381
#define MACH_TYPE_BLACKBIRD            4382
#define MACH_TYPE_RUNMASTER            4383
#define MACH_TYPE_CERES                4384
#define MACH_TYPE_NAD435               4385
#define MACH_TYPE_NS115_PROTO_TYPE     4386
#define MACH_TYPE_FS20_VCC             4387
#define MACH_TYPE_MESON6TV             4388
#define MACH_TYPE_MESON6TV_SKT         4389
#define MACH_TYPE_KEYSTONE             4390
#define MACH_TYPE_PCM052               4391
#define MACH_TYPE_TYPE                 4392
#define MACH_TYPE_QRD_SKUD_PRIME       4393
#define MACH_TYPE_RAINBOWG15           4394
#define MACH_TYPE_GUF_SANTARO          4395
#define MACH_TYPE_SHEEPSHEAD           4396
#define MACH_TYPE_MX6_IWG15M_MXM       4397
#define MACH_TYPE_MX6_IWG15M_Q7        4398
#define MACH_TYPE_AT91SAM9263IF8MIC    4399
#define MACH_TYPE_EXCEL                4400
#define MACH_TYPE_MARCOPOLO            4401
#define MACH_TYPE_MX535_SDCR           4402
#define MACH_TYPE_MX53_CSB2733         4403
#define MACH_TYPE_DIVA                 4404
#define MACH_TYPE_NCR_7744             4405
#define MACH_TYPE_MACALLAN             4406
#define MACH_TYPE_WNR3500              4407
#define MACH_TYPE_PGAVRF               4408
#define MACH_TYPE_HELIOS_V6            4409
#define MACH_TYPE_LCCT                 4410
#define MACH_TYPE_CSNDUG               4411
#define MACH_TYPE_WANDBOARD_IMX6       4412
#define MACH_TYPE_OMAP4_JET            4413
#define MACH_TYPE_TEGRA_ROTH           4414
#define MACH_TYPE_M7DCG                4415
#define MACH_TYPE_M7DUG                4416
#define MACH_TYPE_M7DTG                4417
#define MACH_TYPE_AP42X                4418
#define MACH_TYPE_VAR_SOM_MX6          4419
#define MACH_TYPE_PDLU                 4420
#define MACH_TYPE_HYDROGEN             4421
#define MACH_TYPE_NPA211E              4422
#define MACH_TYPE_ARCADIA              4423
#define MACH_TYPE_ARCADIA_L            4424
#define MACH_TYPE_MSM8930DT            4425
#define MACH_TYPE_KTAM3874             4426
#define MACH_TYPE_CEC4                 4427
#define MACH_TYPE_APE6EVM              4428
#define MACH_TYPE_TX6                  4429
#define MACH_TYPE_OWENSOM              4430
#define MACH_TYPE_CFA10037             4431
#define MACH_TYPE_NATEKS_VOIP          4432
#define MACH_TYPE_EZP1000              4433
#define MACH_TYPE_WGR826V              4434
#define MACH_TYPE_EXUMA                4435
#define MACH_TYPE_FREGATE              4436
#define MACH_TYPE_OSIRISIMX508         4437
#define MACH_TYPE_ST_EXIGO             4438
#define MACH_TYPE_PISMO                4439
#define MACH_TYPE_ATC7                 4440
#define MACH_TYPE_NSPIRECLP            4441
#define MACH_TYPE_NSPIRETP             4442
#define MACH_TYPE_NSPIRECX             4443
#define MACH_TYPE_MAYA                 4444
#define MACH_TYPE_WECCT                4445
#define MACH_TYPE_M2S                  4446
#define MACH_TYPE_MSM8625Q_EVBD        4447
#define MACH_TYPE_TINY210              4448
#define MACH_TYPE_G3                   4449
#define MACH_TYPE_HURRICANE            4450
#define MACH_TYPE_MX6_POD              4451
#define MACH_TYPE_ELONDCN              4452
#define MACH_TYPE_CWMX535              4453
#define MACH_TYPE_M7_WLJ               4454
#define MACH_TYPE_QSP_ARM              4455
#define MACH_TYPE_MSM8625Q_SKUD        4456
#define MACH_TYPE_HTCMONDRIAN          4457
#define MACH_TYPE_WATSON_EAD           4458
#define MACH_TYPE_MITWOA               4459
#define MACH_TYPE_OMAP3_WOLVERINE      4460
#define MACH_TYPE_MAPLETREE            4461
#define MACH_TYPE_MSM8625_FIH_SAE      4462
#define MACH_TYPE_EPC35                4463
#define MACH_TYPE_SMARTRTU             4464
#define MACH_TYPE_RCM101               4465
#define MACH_TYPE_AMX_IMX53_MXX        4466
#define MACH_TYPE_CP3DCG               4467
#define MACH_TYPE_CP3DTG               4468
#define MACH_TYPE_CP3DUG               4469
#define MACH_TYPE_ACER_A12             4470
#define MACH_TYPE_SBC6X                4471
#define MACH_TYPE_U2                   4472
#define MACH_TYPE_SMDK4270             4473
#define MACH_TYPE_PRISCILLAG           4474
#define MACH_TYPE_PRISCILLAC           4475
#define MACH_TYPE_PRISCILLA            4476
#define MACH_TYPE_INNOVA_SHPU_V2       4477
#define MACH_TYPE_M7CDTU               4478
#define MACH_TYPE_MACH_TYPE_DEP2410    4479
#define MACH_TYPE_BCTRE3               4480
#define MACH_TYPE_OMAP_M100            4481
#define MACH_TYPE_FLO                  4482
#define MACH_TYPE_NANOBONE             4483
#define MACH_TYPE_STM_B2105            4484
#define MACH_TYPE_OMAP4_BSC_BAP_V3     4485
#define MACH_TYPE_SS1PAM               4486
#define MACH_TYPE_DLXP_WL              4487
#define MACH_TYPE_PRIMOMINIU           4488
#define MACH_TYPE_MRT_35HD_DUALNAS_E   4489
#define MACH_TYPE_KIWI                 4490
#define MACH_TYPE_HW90496              4491
#define MACH_TYPE_MEP2440              4492
#define MACH_TYPE_COLIBRI_T30          4493
#define MACH_TYPE_CWV1                 4494
#define MACH_TYPE_NSA325               4495
#define MACH_TYPE_DLXP_UL              4496
#define MACH_TYPE_DPXMTC               4497
#define MACH_TYPE_TT_STUTTGART         4498
#define MACH_TYPE_MIRANDA_APCII        4499
#define MACH_TYPE_MX6Q_MODEROX         4500
#define MACH_TYPE_MUDSKIPPER           4501
#define MACH_TYPE_URANIA               4502
#define MACH_TYPE_STM_B2112            4503
#define MACH_TYPE_GTOU                 4504
#define MACH_TYPE_MX6Q_ATS_PHOENIX     4505
#define MACH_TYPE_STM_B2116            4506
#define MACH_TYPE_MYTHOLOGY            4507
#define MACH_TYPE_FC360V1              4508
#define MACH_TYPE_GPS_SENSOR           4509
#define MACH_TYPE_GAZELLE              4510
#define MACH_TYPE_MPQ8064_DMA          4511
#define MACH_TYPE_WEMS_ASD01           4512
#define MACH_TYPE_APALIS_T30           4513
#define MACH_TYPE_MX6Q_QSBC35_C398     4514
#define MACH_TYPE_ARMSTONEA9           4515
#define MACH_TYPE_OMAP_BLAZETABLET     4516
#define MACH_TYPE_AR6MXQ               4517
#define MACH_TYPE_AR6MXS               4518
#define MACH_TYPE_DETO_APOS_MX6        4519
#define MACH_TYPE_GWVENTANA            4520
#define MACH_TYPE_IGEP0033             4521
#define MACH_TYPE_RACA                 4522
#define MACH_TYPE_APPLESODA            4523
#define MACH_TYPE_H52C1_CONCERTO       4524
#define MACH_TYPE_FCMBRD               4525
#define MACH_TYPE_PCAAXS1              4526
#define MACH_TYPE_LS_ORCA              4527
#define MACH_TYPE_PCM051LB             4528
#define MACH_TYPE_MX6S_LP507_GVCI      4529
#define MACH_TYPE_DIDO                 4530
#define MACH_TYPE_SWARCO_ITC3_9G20     4531
#define MACH_TYPE_ROBO_ROADY           4532
#define MACH_TYPE_RSKRZA1              4533
#define MACH_TYPE_SWARCO_SID           4534
#define MACH_TYPE_MX6_IWG15S_SBC       4535
#define MACH_TYPE_MX6Q_CAMARO          4536
#define MACH_TYPE_HB6MXS               4537
#define MACH_TYPE_LAGER                4538
#define MACH_TYPE_LP8X4X               4539
#define MACH_TYPE_TEGRATAB7            4540
#define MACH_TYPE_ANDROMEDA            4541
#define MACH_TYPE_BOOTES               4542
#define MACH_TYPE_NETHMI               4543
#define MACH_TYPE_TEGRATAB             4544
#define MACH_TYPE_SOM5_EVB             4545
#define MACH_TYPE_VENATICORUM          4546
#define MACH_TYPE_STM_B2110            4547
#define MACH_TYPE_ELUX_HATHOR          4548
#define MACH_TYPE_HELIOS_V7            4549
#define MACH_TYPE_XC10V1               4550
#define MACH_TYPE_CP2U                 4551
#define MACH_TYPE_IAP_F                4552
#define MACH_TYPE_IAP_G                4553
#define MACH_TYPE_AAE                  4554
#define MACH_TYPE_PEGASUS              4555
#define MACH_TYPE_CYGNUS               4556
#define MACH_TYPE_CENTAURUS            4557
#define MACH_TYPE_MSM8930_QRD8930      4558
#define MACH_TYPE_QUBY_TIM             4559
#define MACH_TYPE_ZEDI3250A            4560
#define MACH_TYPE_GRUS                 4561
#define MACH_TYPE_APOLLO3              4562
#define MACH_TYPE_COWON_R7             4563
#define MACH_TYPE_TONGA3               4564
#define MACH_TYPE_P535                 4565
#define MACH_TYPE_SA3874I              4566
#define MACH_TYPE_MX6_NAVICO_COM       4567
#define MACH_TYPE_PROXMOBIL2           4568
#define MACH_TYPE_UBINUX1              4569
#define MACH_TYPE_ISTOS                4570
#define MACH_TYPE_BENVOLIO4            4571
#define MACH_TYPE_ECO5_BX2             4572
#define MACH_TYPE_EUKREA_CPUIMX28SD    4573
#define MACH_TYPE_DOMOTAB              4574
#define MACH_TYPE_PFLA03               4575
#define MACH_TYPE_ET_CPU_301_16        4576
#define MACH_TYPE_SKYWALKER            4577
#define MACH_TYPE_SCORPIUS             4578
#define MACH_TYPE_CAPRICORNUS          4579
#define MACH_TYPE_LYRA                 4580
#define MACH_TYPE_GATERO               4581
#define MACH_TYPE_GATERO01             4582
#define MACH_TYPE_Z4DTG                4583
#define MACH_TYPE_LUPUS                4584
#define MACH_TYPE_LEAP101              4585
#define MACH_TYPE_CM_T335              4586
#define MACH_TYPE_PNA                  4587
#define MACH_TYPE_ECOFOREST_CPU2013    4588
#define MACH_TYPE_APQ8064_DMA          4589
#define MACH_TYPE_MX53_ARMOUR          4590
#define MACH_TYPE_EUROFUNK_AEPL3       4591
#define MACH_TYPE_EUROFUNK_MHLS3       4592
#define MACH_TYPE_EUROFUNK_E1IF        4593
#define MACH_TYPE_LEPUS                4594
#define MACH_TYPE_BORA                 4595
#define MACH_TYPE_ADS4011              4596
#define MACH_TYPE_BEAVER               4597
#define MACH_TYPE_IMX233_IUNGO         4598
#define MACH_TYPE_CEPHEUS              4599
#define MACH_TYPE_CETUS                4600
#define MACH_TYPE_CHAMAELEON           4601
#define MACH_TYPE_ARDBEG               4602
#define MACH_TYPE_IXORA                4603
#define MACH_TYPE_JUGLANS              4604
#define MACH_TYPE_CANISMAJOR           4605
#define MACH_TYPE_AT91SAM9263MIB       4606
#define MACH_TYPE_COSINO_9G35          4607
#define MACH_TYPE_TINY4412             4608
#define MACH_TYPE_BALLOON4             4609
#define MACH_TYPE_PGG                  4610
#define MACH_TYPE_XXSQ701              4611
#define MACH_TYPE_MX6_NAVICO_RDR       4612
#define MACH_TYPE_PHANTOM              4613
#define MACH_TYPE_CANISMINORH          4614
#define MACH_TYPE_CARINA               4615
#define MACH_TYPE_E1859                4616
#define MACH_TYPE_ARMSTONEA5           4617
#define MACH_TYPE_PICOCOMA5            4618
#define MACH_TYPE_NETDCUA5             4619
#define MACH_TYPE_MOLLY                4620
#define MACH_TYPE_MASERATI             4621
#define MACH_TYPE_MX53_IDEBX           4622
#define MACH_TYPE_MX53_C2CB            4623
#define MACH_TYPE_MIPSEE               4624
#define MACH_TYPE_SEEKLOP              4625
#define MACH_TYPE_AUDISEE              4626
#define MACH_TYPE_TX48                 4627
#define MACH_TYPE_TL7689_PAD_REF       4628
#define MACH_TYPE_TL7689_PAD_TEST      4629
#define MACH_TYPE_TL7689_PHONE_REF     4630
#define MACH_TYPE_TL7689_PHONE_TEST    4631
#define MACH_TYPE_SWARCO_SCC_WKS       4632
#define MACH_TYPE_ACCORDO2             4633
#define MACH_TYPE_TRIZEPS7             4634
#define MACH_TYPE_F100                 4635
#define MACH_TYPE_ARMADILLO410         4636
#define MACH_TYPE_TINY2416             4637
#define MACH_TYPE_TINY2451             4638
#define MACH_TYPE_MINI2451             4639
#define MACH_TYPE_TINY5250             4640
#define MACH_TYPE_TINY3358             4641
#define MACH_TYPE_T6_UL                4642
#define MACH_TYPE_T6_U                 4643
#define MACH_TYPE_T6_ULA               4644
#define MACH_TYPE_T6_WL                4645
#define MACH_TYPE_T6_WHL               4646
#define MACH_TYPE_CIRCINUS             4647
#define MACH_TYPE_SOCPK255             4648
#define MACH_TYPE_SOCPRV270            4649
#define MACH_TYPE_SOCPRC270            4650
#define MACH_TYPE_MACH_CP5DTU          4651
#define MACH_TYPE_CP5DTU               4652
#define MACH_TYPE_CP5DUG               4653
#define MACH_TYPE_CP5DWG               4654
#define MACH_TYPE_AM335X_EGF           4655
#define MACH_TYPE_AZM9G45              4656
#define MACH_TYPE_AZM335X              4657
#define MACH_TYPE_LYNBRD               4658
#define MACH_TYPE_AM35X_EGF            4659
#define MACH_TYPE_SEVULCAN             4660
#define MACH_TYPE_AX8008M              4661
#define MACH_TYPE_AX8008MR             4662
#define MACH_TYPE_XYNIX                4663
#define MACH_TYPE_OMAP3621_ODYV4       4664
#define MACH_TYPE_MX6_CAMERONET        4665
#define MACH_TYPE_OMAP4_DART           4666
#define MACH_TYPE_MX6Q_ENZO            4667
#define MACH_TYPE_EV_IMX287MICRO       4668
#define MACH_TYPE_EV_IMX287MINI        4669
#define MACH_TYPE_MX53_CEC2            4670
#define MACH_TYPE_HELIOS_V8            4671
#define MACH_TYPE_HELIOS_V9            4672
#define MACH_TYPE_COGNAC               4673
#define MACH_TYPE_ZEST                 4674
#define MACH_TYPE_GC3                  4675
#define MACH_TYPE_DAD_MEDIA            4676
#define MACH_TYPE_HTOUCH               4677
#define MACH_TYPE_SPT7500BASEBOARD     4678
#define MACH_TYPE_OMAP4_DART_EVM       4679
#define MACH_TYPE_MX53_TLV             4680
#define MACH_TYPE_PDAK2H               4681
#define MACH_TYPE_MATRIX513            4682
#define MACH_TYPE_LIVEBOX01            4683
#define MACH_TYPE_CEVRZA1L             4684
#define MACH_TYPE_B1010                4685
#define MACH_TYPE_FWTMK1               4686
#define MACH_TYPE_GRENADA              4687
#define MACH_TYPE_HASSEL               4688
#define MACH_TYPE_ODROIDXU             4689
#define MACH_TYPE_ODROIDU2             4690
#define MACH_TYPE_NAIAD                4691
#define MACH_TYPE_HARRIER              4692
#define MACH_TYPE_PCL052               4693
#define MACH_TYPE_LIBRA2404            4694
#define MACH_TYPE_MX6_LEMONBOARD       4695
#define MACH_TYPE_MX6_ATLAS            4696
#define MACH_TYPE_ELECSYS_Z2           4697
#define MACH_TYPE_ELECSYS_Z4           4698
#define MACH_TYPE_IPQ806X_DB149        4699
#define MACH_TYPE_PULSAR               4700
#define MACH_TYPE_SCALANCEM            4701
#define MACH_TYPE_NA11                 4702
#define MACH_TYPE_IPQ806X_DB147        4703
#define MACH_TYPE_IPQ806X_AP148        4704
#define MACH_TYPE_AMLTD_IMX6           4705
#define MACH_TYPE_PIA_AM335X           4706
#define MACH_TYPE_BLADE                4707
#define MACH_TYPE_MATISSE              4708
#define MACH_TYPE_IKEBANA              4709
#define MACH_TYPE_LF3000               4710
#define MACH_TYPE_CARALLON_STINGRAY    4711
#define MACH_TYPE_MENSA                4712
#define MACH_TYPE_CES_COREBOARD        4713
#define MACH_TYPE_VYBRID_IWG16M_UMXM   4714
#define MACH_TYPE_LOKI                 4715
#define MACH_TYPE_PCM053               4716
#define MACH_TYPE_SMM200               4717
#define MACH_TYPE_M507                 4718
#define MACH_TYPE_ORSOC_ARMSOC_8695    4719
#define MACH_TYPE_AM335X_ZY            4720
#define MACH_TYPE_ARRAKIS              4721
#define MACH_TYPE_SXLT                 4722
#define MACH_TYPE_YLCM                 4723
#define MACH_TYPE_EAGLE6D              4724
#define MACH_TYPE_LCU1                 4725
#define MACH_TYPE_MX6DL_IWG15M_Q7      4726
#define MACH_TYPE_SBCPHYFLEXAM335      4727
#define MACH_TYPE_SBCPHYCARDAM335      4728
#define MACH_TYPE_SBCPHYFLEXIMX6       4729
#define MACH_TYPE_HOMESERVERSTICK      4730
#define MACH_TYPE_ECXEC                4731
#define MACH_TYPE_HH300                4732
#define MACH_TYPE_CPUCA8               4733
#define MACH_TYPE_A0057_LSEMBEDDEDPC   4734
#define MACH_TYPE_IPROC                4735
#define MACH_TYPE_NEMESIS_NFE          4736
#define MACH_TYPE_MABV3X25             4737
#define MACH_TYPE_OCTANT               4738
#define MACH_TYPE_MSM7X27_THUNDER      4739
#define MACH_TYPE_MAXIM                4740
#define MACH_TYPE_TELEMATICCTRLUNIT    4741
#define MACH_TYPE_MX6Q_JCDBOX          4742
#define MACH_TYPE_CKB_1808             4743
#define MACH_TYPE_CKB_3352             4744
#define MACH_TYPE_HIKIRK               4745
#define MACH_TYPE_DNS320L              4746
#define MACH_TYPE_STM_B2120            4747
#define MACH_TYPE_STM_B2089            4748
#define MACH_TYPE_COLIBRI_VF50         4749
#define MACH_TYPE_COLIBRI_VF61         4750
#define MACH_TYPE_SYNERGY2             4751
#define MACH_TYPE_PCM051_HMI           4752
#define MACH_TYPE_TEK2                 4753
#define MACH_TYPE_DUCKBILL             4754
#define MACH_TYPE_MX50_SEISMIC         4755
#define MACH_TYPE_TWOFACE              4756
#define MACH_TYPE_T10                  4757
#define MACH_TYPE_LIB1313              4758
#define MACH_TYPE_HIMX                 4759
#define MACH_TYPE_VCM30_T30            4760
#define MACH_TYPE_CORNERVIEW           4761
#define MACH_TYPE_P01600               4762
#define MACH_TYPE_AXEL                 4763
#define MACH_TYPE_IMX6_ANDY            4764
#define MACH_TYPE_NSA220               4765
#define MACH_TYPE_TI8168HSC1           4766
#define MACH_TYPE_DORY                 4767
#define MACH_TYPE_ECV4                 4768
#define MACH_TYPE_WEBBG3FLIGHT         4769
#define MACH_TYPE_SBC_PHYCORE_AM335X   4770
#define MACH_TYPE_TSC                  4771
#define MACH_TYPE_IMX6_CLOUS           4772
#define MACH_TYPE_C1                   4773
#define MACH_TYPE_VCM30T30             4774
#define MACH_TYPE_IMX6_EMSYM_BLURR     4775
#define MACH_TYPE_PDIS_M               4776
#define MACH_TYPE_MX6Q_REX             4777
#define MACH_TYPE_SWARCO_FR_ANYBUS     4778
#define MACH_TYPE_SHMAC                4779
#define MACH_TYPE_CKB_RZA1H            4780
#define MACH_TYPE_AZETI_SP_NG01        4781
#define MACH_TYPE_E6210                4782
#define MACH_TYPE_MH9001               4783
#define MACH_TYPE_STM_B2147            4784
#define MACH_TYPE_OMAP5_VARSOM         4785
#define MACH_TYPE_CUBEA5               4786
#define MACH_TYPE_CP5                  4787
#define MACH_TYPE_FORNAX               4788
#define MACH_TYPE_ICU                  4789
#define MACH_TYPE_COMUS3               4790
#define MACH_TYPE_LIBRA4344            4791
#define MACH_TYPE_LIBRA4644            4792
#define MACH_TYPE_PAVO                 4793
#define MACH_TYPE_XL824                4794
#define MACH_TYPE_XL850                4795
#define MACH_TYPE_MX6_PICO_ITX         4796
#define MACH_TYPE_AMICO_S              4797
#define MACH_TYPE_AMICO_P              4798
#define MACH_TYPE_MINNOW               4799
#define MACH_TYPE_DAVINCI_DM365_ZY     4800
#define MACH_TYPE_PAVO_2               4801
#define MACH_TYPE_IAVS                 4802
#define MACH_TYPE_RANA                 4803
#define MACH_TYPE_MERAKI_MS26          4804
#define MACH_TYPE_VP2_REFRESH          4805
#define MACH_TYPE_MCB1800              4806
#define MACH_TYPE_MX6Q_DEVONIT_TC3     4807
#define MACH_TYPE_UC81XX               4808
#define MACH_TYPE_UC84XX               4809
#define MACH_TYPE_IPQ806X_AP145        4810
#define MACH_TYPE_IPQ806X_DB149_MMC    4811
#define MACH_TYPE_IPQ806X_AP145_MMC    4812
#define MACH_TYPE_E3QT                 4813
#define MACH_TYPE_U222                 4814
#define MACH_TYPE_UFO878               4815
#define MACH_TYPE_GEKKO                4816
#define MACH_TYPE_MINI2440ARM          4817
#define MACH_TYPE_MPCSB2_9G20          4818
#define MACH_TYPE_TL7689_PAD_706       4819
#define MACH_TYPE_TDA7                 4820
#define MACH_TYPE_CUBOXI               4821
#define MACH_TYPE_TIBIDABO             4822
#define MACH_TYPE_T216MINI             4823
#define MACH_TYPE_HERA_IMX6            4824
#define MACH_TYPE_GRIDPOINT_EC1K       4825
#define MACH_TYPE_LIBRA4404            4826
#define MACH_TYPE_MI_MOCHA             4827
#define MACH_TYPE_BCM2835              4828
#define MACH_TYPE_NFP6XXX              4829
#define MACH_TYPE_TETRA                4830
#define MACH_TYPE_NECO                 4831
#define MACH_TYPE_PROTONEX_VPM402      4832
#define MACH_TYPE_MX6Q_SAVAGE          4833
#define MACH_TYPE_MX6Q_SOMB            4834
#define MACH_TYPE_FILI_DL              4835
#define MACH_TYPE_ADAPT_SDRDC          4836
#define MACH_TYPE_DS_QUARTZ            4837
#define MACH_TYPE_ULTRAFLEX            4838
#define MACH_TYPE_APQ8064_ADP_2        4839
#define MACH_TYPE_BEAN                 4840
#define MACH_TYPE_BALDR                4841
#define MACH_TYPE_CCIMX6ADPT           4842
#define MACH_TYPE_TS4900               4843
#define MACH_TYPE_ZEPLUG               4844
#define MACH_TYPE_MSM8X60_DUPLICITY    4845
#define MACH_TYPE_CTERA_2BAY_A         4846
#define MACH_TYPE_AM335X_BAP_V3_1      4847
#define MACH_TYPE_XPECT01              4848
#define MACH_TYPE_ESI23                4849
#define MACH_TYPE_MX6DL_SBC35_C398     4850
#define MACH_TYPE_MX6SOLO_SBC35_C398   4851
#define MACH_TYPE_KSP5012              4852
#define MACH_TYPE_MX6Q_ZEUS            4853
#define MACH_TYPE_INNOVA_MATRIX        4854
#define MACH_TYPE_RF6XXR               4855
#define MACH_TYPE_PECORINO             4856
#define MACH_TYPE_MHPLAY_W             4857
#define MACH_TYPE_PELCO_DRAGONFLY      4858
#define MACH_TYPE_VSM_CHAMHIGH         4859
#define MACH_TYPE_HACHIKO              4860
#define MACH_TYPE_TL7689_PHONE_IN260   4861
#define MACH_TYPE_CWMX6                4862
#define MACH_TYPE_HD3                  4863
#define MACH_TYPE_UHD4                 4864
#define MACH_TYPE_BULPRINT_BOARD       4865
#define MACH_TYPE_PELCO_SPECTRAHD2     4866
#define MACH_TYPE_VISTEONV2X           4867
#define MACH_TYPE_PHIDGET_VINTSBC      4868
#define MACH_TYPE_LMU7030              4869
#define MACH_TYPE_ECC2                 4870
#define MACH_TYPE_CDS_CTS              4871
#define MACH_TYPE_AXELLITE             4872
#define MACH_TYPE_ARNIE                4873
#define MACH_TYPE_AGATEWAY             4874
#define MACH_TYPE_PICOMODA9            4875
#define MACH_TYPE_P_137_I6             4876
#define MACH_TYPE_VVDN_MCAM            4877
#define MACH_TYPE_MX6_INSIGHT          4878
#define MACH_TYPE_VIPRINET_200         4879
#define MACH_TYPE_ELLYPTO              4880
#define MACH_TYPE_G7P                  4881
#define MACH_TYPE_YSE5250              4882
#define MACH_TYPE_NG500                4883
#define MACH_TYPE_DTSC02               4884
#define MACH_TYPE_MX6DL_SBB            4885
#define MACH_TYPE_APALIS_IMX6Q         4886
#define MACH_TYPE_WOMBAT6              4887
#define MACH_TYPE_BALTO                4888
#define MACH_TYPE_TNGSBL               4889
#define MACH_TYPE_H6061                4890
#define MACH_TYPE_XA300                4891
#define MACH_TYPE_PELCO_WOOFF          4892
#define MACH_TYPE_PELCO_EVM            4893
#define MACH_TYPE_MX6Q_IMXB            4894
#define MACH_TYPE_SMARTTAB_V55         4895
#define MACH_TYPE_SMARTTAB_V11A        4896
#define MACH_TYPE_SMARTTAB_V71A        4897
#define MACH_TYPE_NOVASOM5             4898
#define MACH_TYPE_CCIMX6SBC            4899
#define MACH_TYPE_INTOUCH              4900
#define MACH_TYPE_MX6S_HAWTHORNE       4901
#define MACH_TYPE_SEAH                 4902
#define MACH_TYPE_AM335X_EC3           4903
#define MACH_TYPE_EMBEST_MARS          4904
#define MACH_TYPE_MX6DL_VIKITOUCH      4905
#define MACH_TYPE_IX2_NG               4906
#define MACH_TYPE_PEKQSD               4907
#define MACH_TYPE_PTEKN                4908
#define MACH_TYPE_APQ8064_ADP2_ES2     4909
#define MACH_TYPE_GHIIMX6              4910
#define MACH_TYPE_M3000                4911
#define MACH_TYPE_TCW101               4912
#define MACH_TYPE_IPQ806X_AP148_1XX    4913
#define MACH_TYPE_HNS_ACADIA           4914
#define MACH_TYPE_MX6S_VIKITOUCH       4915
#define MACH_TYPE_CM_QS600             4916
#define MACH_TYPE_IPQ806X_DB149_2XX    4917
#define MACH_TYPE_EAG_UGW400           4918
#define MACH_TYPE_SK_GRANT_OEM         4919
#define MACH_TYPE_KNOBLOCH_TXT         4920
#define MACH_TYPE_MX6SL_SHD            4921
#define MACH_TYPE_HIMX0294             4922
#define MACH_TYPE_MX6Q_TTJ500          4923
#define MACH_TYPE_CONTI_SGM358         4924
#define MACH_TYPE_DENSOJ6REF           4925
#define MACH_TYPE_KEVIN                4926
#define MACH_TYPE_VVDN_TOII            4927
#define MACH_TYPE_PENGWYN              4928
#define MACH_TYPE_XARINA_ENTRY         4929
#define MACH_TYPE_CONTI_MRNEVO         4930
#define MACH_TYPE_NSA310S              4931
#define MACH_TYPE_POWERECU             4932
#define MACH_TYPE_Q7M120               4933
#define MACH_TYPE_H6829                4934
#define MACH_TYPE_AG13008              4935
#define MACH_TYPE_IPQ806X_STORM        4936
#define MACH_TYPE_DM3725_GSOM          4937
#define MACH_TYPE_HP_PRIME             4938
#define MACH_TYPE_FIRESTORM            4939
#define MACH_TYPE_WINGZ                4940
#define MACH_TYPE_ANDROMED             4941
#define MACH_TYPE_SCM120               4942
#define MACH_TYPE_CM_3G                4943
#define MACH_TYPE_IPA400               4944
#define MACH_TYPE_HYDRA_MKII           4945
#define MACH_TYPE_AXM2                 4946
#define MACH_TYPE_CALOPUS              4947
#define MACH_TYPE_BCTRM3S              4948
#define MACH_TYPE_DM385LB              4949
#define MACH_TYPE_SURMA_MKII           4950
#define MACH_TYPE_OMAP4_SKHU_HCAM      4951
#define MACH_TYPE_SCMCON               4952
#define MACH_TYPE_KLK_IMX6S_G          4953
#define MACH_TYPE_AM335XMX             4954
#define MACH_TYPE_DMVA2_BTFU_WCAM      4955
#define MACH_TYPE_UXC                  4956
#define MACH_TYPE_ELARM_A              4957
#define MACH_TYPE_EMPC_AIMX6           4958
#define MACH_TYPE_BCTRE2G2             4959
#define MACH_TYPE_DMD                  4960
#define MACH_TYPE_DISCOVERY            4961
#define MACH_TYPE_RELIAGATE_10_20      4962
#define MACH_TYPE_MX6Q_DSA2LS          4963
#define MACH_TYPE_MX6SL_ECT5           4964
#define MACH_TYPE_COBHAM_MDC3          4965
#define MACH_TYPE_TS_WAV               4966
#define MACH_TYPE_XIN_GIGE_CAM         4967
#define MACH_TYPE_ASAIIOTG             4968
#define MACH_TYPE_DAU                  4969
#define MACH_TYPE_SOCFPGA_ARRIA5       4970
#define MACH_TYPE_IPQ806X_AP160        4971
#define MACH_TYPE_IPQ806X_AP161        4972
#define MACH_TYPE_GEMX6                4973
#define MACH_TYPE_EFUSA9               4974
#define MACH_TYPE_DYNACOR_10_20        4975
#define MACH_TYPE_BLUELIGHTNING        4976
#define MACH_TYPE_SILVERBULLET         4977
#define MACH_TYPE_MX6_MAEXLE           4978
#define MACH_TYPE_PAYTEC_EPT           4979
#define MACH_TYPE_ATLASCOPCO_ITMK2     4980
#define MACH_TYPE_ATLASCOPCO_FLEXDRV   4981
#define MACH_TYPE_ATLASCOPCO_FLEXIT    4982
#define MACH_TYPE_PCDON                4983
#define MACH_TYPE_DM8168_IWG12M_Q7     4984
#define MACH_TYPE_RTM9431              4985
#define MACH_TYPE_ARM11_CAR            4986
#define MACH_TYPE_VIDEOPHONE           4987
#define MACH_TYPE_MPFA                 4988
#define MACH_TYPE_PS10                 4989
#define MACH_TYPE_HGATEWAY             4990
#define MACH_TYPE_IPQ806X_AP160_2      4991
#define MACH_TYPE_ECP5COM              4992
#define MACH_TYPE_H6064                4993
#define MACH_TYPE_MX6X_MX              4994
#define MACH_TYPE_MAJIC5422            4995
#define MACH_TYPE_EMINDS               4996
#define MACH_TYPE_TI8168TOII           4997
#define MACH_TYPE_VXR10                4998
#define MACH_TYPE_DS5                  4999
#define MACH_TYPE_DS3                  5000
#define MACH_TYPE_NOKIAN97             5001
#define MACH_TYPE_TECNINT_ODBC         5002
#define MACH_TYPE_C111                 5003
#define MACH_TYPE_ML300DU              5004
#define MACH_TYPE_YAK                  5005
#define MACH_TYPE_NSA221               5006
#define MACH_TYPE_GINKGOP              5007
#define MACH_TYPE_MANGO                5008
#define MACH_TYPE_AMBS2E               5009
#define MACH_TYPE_AMBS3L               5010
#define MACH_TYPE_DRA7XX_EVM           5011
#define MACH_TYPE_DENSODRA74XMID       5012
#define MACH_TYPE_MILD                 5013
#define MACH_TYPE_YLCM_MK2             5014
#define MACH_TYPE_DS_CB                5015
#define MACH_TYPE_EMPEROR              5016
#define MACH_TYPE_ARTPEC               5017
#define MACH_TYPE_DCIM                 5018
#define MACH_TYPE_WS1XX                5019
#define MACH_TYPE_IPQ806X_AK01_1XX     5020
#define MACH_TYPE_MGWACE_DEC           5021
#define MACH_TYPE_W6000                5022
#define MACH_TYPE_WATSON_FIB_PLUGIN    5023
#define MACH_TYPE_MX6Q_TINYREX         5024
#define MACH_TYPE_MX6S_TINYREX         5025
#define MACH_TYPE_MX6Q_MODEROS         5026
#define MACH_TYPE_AFI                  5027
#define MACH_TYPE_RCPRO                5028
#define MACH_TYPE_ONBOX                5029
#define MACH_TYPE_EXYNOS4412           5030
#define MACH_TYPE_EXYNOS4413           5031
#define MACH_TYPE_PELCO_DF20_EVT       5032
#define MACH_TYPE_LION_DUG             5033
#define MACH_TYPE_LIONP_DUG            5034
#define MACH_TYPE_ESSE                 5035
#define MACH_TYPE_ILLINOIS             5036
#define MACH_TYPE_TI8168KSIPOLARIS     5037
#define MACH_TYPE_YSE_BOARD            5038
#define MACH_TYPE_PELCO_HWE0_EVT       5039
#define MACH_TYPE_PELCO_S2E_EVM        5040
#define MACH_TYPE_PELCO_DRAGONFLY20    5041
#define MACH_TYPE_PELCO_HAWKEYE        5042
#define MACH_TYPE_ARM                  5043
#define MACH_TYPE_TCAM                 5044
#define MACH_TYPE_MX6Q_HOBBY           5045
#define MACH_TYPE_H6067                5046
#define MACH_TYPE_DENSODRA72XLOW       5047
#define MACH_TYPE_MX6_UNETBIT          5048
#define MACH_TYPE_BT_OAK               5049
#define MACH_TYPE_BT500                5050
#define MACH_TYPE_FARWATER_GEO         5051
#define MACH_TYPE_YT2                  5052
#define MACH_TYPE_EH9000               5053
#define MACH_TYPE_GVPU                 5054
#define MACH_TYPE_CEDEX                5055
#define MACH_TYPE_NT450R5G             5056
#define MACH_TYPE_MSA23XX              5057
#define MACH_TYPE_OMAP3_MOSS           5058
#define MACH_TYPE_KYEONGHAWOO          5059
#define MACH_TYPE_GIRA_IM03            5060
#define MACH_TYPE_EUROFUNK_AIIF        5061
#define MACH_TYPE_BCU1                 5062
#define MACH_TYPE_DIYEFIS6410          5063
#define MACH_TYPE_MX53_TURING          5064
#define MACH_TYPE_MX6X_TURING          5065
#define MACH_TYPE_MX6DL_TURING         5066
#define MACH_TYPE_MX53_INDASH          5067
#define MACH_TYPE_MX6Q_INDASH          5068
#define MACH_TYPE_MX6DL_INDASH         5069
#define MACH_TYPE_RTS_G6               5070
#define MACH_TYPE_KA_TITAN             5071
#define MACH_TYPE_CL_SOM_IMX7          5072
#define MACH_TYPE_VVDN_MGSI_VSIS       5073
#define MACH_TYPE_MX6Q_NANO            5074
#define MACH_TYPE_PDU001               5075
#define MACH_TYPE_CAB_PROYK            5076
#define MACH_TYPE_KLIN                 5077
#define MACH_TYPE_ENMAN_STEUERBOX      5078
#define MACH_TYPE_LS_STINGRAY          5079
#define MACH_TYPE_IPDU                 5080
#define MACH_TYPE_LINDA                5081
#define MACH_TYPE_MX6Q_OPENREX         5082
#define MACH_TYPE_ON100                5083
#define MACH_TYPE_EMINDS_RTU12         5084
#define MACH_TYPE_EMINDS_AVL10         5085
#define MACH_TYPE_MAIN_PLC_LME         5086
#define MACH_TYPE_MSPX                 5087
#define MACH_TYPE_CGW_300              5088
#define MACH_TYPE_MX7D_CICADA          5089
#define MACH_TYPE_VIRT2REAL_DM365      5090
#define MACH_TYPE_DM365_VIRT2REAL      5091
#define MACH_TYPE_H6073                5092
#define MACH_TYPE_GTGATEWAY            5093
#define MACH_TYPE_XARINA_STANDARD      5094
#define MACH_TYPE_NOVASOMS             5095
#define MACH_TYPE_NOVASOMP             5096
#define MACH_TYPE_NOVASOMU             5097
#define MACH_TYPE_MX6Q_MPBD            5098
#define MACH_TYPE_NCR_1930             5099
#define MACH_TYPE_UAP301               5100
#define MACH_TYPE_URT02                5101
#define MACH_TYPE_ATC8                 5102
#define MACH_TYPE_IOT_GATEWAY          5103
#define MACH_TYPE_HSM_PHOENIX          5104
#define MACH_TYPE_MISSOURI             5105
#define MACH_TYPE_REMARKABLE           5106
#define MACH_TYPE_FA0113               5107
#define MACH_TYPE_INNOVA_STATNETTAWM   5108
#define MACH_TYPE_TEGRA3               5109
#define MACH_TYPE_MALI400              5110
#define MACH_TYPE_MALI450              5111
#define MACH_TYPE_NASM25               5112
#define MACH_TYPE_TOMATO               5113
#define MACH_TYPE_OMAP3_MRC3D          5114
#endif
